@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.soaccounts.inc.php,v 1.11.2.2 2005/01/28 22:18:39 ak703 Exp $ */
+	/* $Id: class.soaccounts.inc.php 21491 2006-04-30 12:26:59Z ralfbecker $ */
 
 	class soaccounts
 	{
@@ -20,31 +20,18 @@
 		function add_user($userData)
 		{
 			$userData['account_expires']	= $userData['expires'];
-
-
+			//$userData['account_email'] 	= $userData['email'];
+			
 			if($userData['email'] != "")
 			{
 				$userData['account_email'] = $userData['email'];
 			}
-					
-			$GLOBALS['phpgw']->db->lock(
-				Array(
-					'phpgw_accounts',
-					'phpgw_nextid',
-					'phpgw_preferences',
-					'phpgw_sessions',
-					'phpgw_acl',
-					'phpgw_applications',
-					'phpgw_app_sessions',
-					'phpgw_hooks'
-				)
-			);
-
-			$GLOBALS['phpgw']->accounts->create($userData);
-
-			$userData['account_id'] = $GLOBALS['phpgw']->accounts->name2id($userData['account_lid']);
 			
-			$apps = CreateObject('phpgwapi.applications',$userData['account_id']);
+			if (!($userData['account_id'] = $GLOBALS['egw']->accounts->create($userData)))
+			{
+				return false;
+			}
+			$apps =& CreateObject('phpgwapi.applications',$userData['account_id']);
 			$apps->read_installed_apps();
 			// Read Group Apps
 			if ($userData['account_groups'])
@@ -89,7 +76,7 @@
 
 			if ($userData['changepassword'])
 			{
-				$GLOBALS['phpgw']->acl->add_repository('preferences','changepassword',$userData['account_id'],1);
+				$GLOBALS['egw']->acl->add_repository('preferences','changepassword',$userData['account_id'],1);
 			}
 			// Assign user to groups
 			if ($userData['account_groups'])
@@ -97,15 +84,13 @@
 				$c_acct_groups = count($userData['account_groups']);
 				for ($i=0;$i<$c_acct_groups;$i++)
 				{
-					$GLOBALS['phpgw']->acl->add_repository('phpgw_group',$userData['account_groups'][$i],$userData['account_id'],1);
+					$GLOBALS['egw']->acl->add_repository('phpgw_group',$userData['account_groups'][$i],$userData['account_id'],1);
 				}
 			}
 
 			$apps->account_apps = array(array());
 			$apps_after = array(array());
 
-			$GLOBALS['phpgw']->db->unlock();
-
 			return $userData['account_id'];
 		}
 	}
