@@ -13,7 +13,7 @@
 	* option) any later version.                                               *
 	\**************************************************************************/
 
-	/* $Id: class.uicategories.inc.php,v 1.47 2004/05/29 10:16:51 ralfbecker Exp $ */
+	/* $Id: class.uicategories.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class uicategories
 	{
@@ -36,30 +36,30 @@
 
 		function uicategories()
 		{
-			if ($GLOBALS['phpgw']->acl->check('global_categories_access',1,'admin'))
+			if ($GLOBALS['egw']->acl->check('global_categories_access',1,'admin'))
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php');
+				$GLOBALS['egw']->redirect_link('/index.php');
 			}
 
-			$this->bo			= CreateObject('admin.bocategories');
-			$this->template		= $GLOBALS['phpgw']->template;
-			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
+			$this->bo			=& CreateObject('admin.bocategories');
+			$this->template		= $GLOBALS['egw']->template;
+			$this->nextmatchs	=& CreateObject('phpgwapi.nextmatchs');
 
-			$this->acl_search = !$GLOBALS['phpgw']->acl->check('global_categories_access',2,'admin');
-			$this->acl_add    = !$GLOBALS['phpgw']->acl->check('global_categories_access',4,'admin');
-			$this->acl_view   = !$GLOBALS['phpgw']->acl->check('global_categories_access',8,'admin');
-			$this->acl_edit   = !$GLOBALS['phpgw']->acl->check('global_categories_access',16,'admin');
-			$this->acl_delete = !$GLOBALS['phpgw']->acl->check('global_categories_access',32,'admin');
-			$this->acl_add_sub= !$GLOBALS['phpgw']->acl->check('global_categories_access',64,'admin');
+			$this->acl_search = !$GLOBALS['egw']->acl->check('global_categories_access',2,'admin');
+			$this->acl_add    = !$GLOBALS['egw']->acl->check('global_categories_access',4,'admin');
+			$this->acl_view   = !$GLOBALS['egw']->acl->check('global_categories_access',8,'admin');
+			$this->acl_edit   = !$GLOBALS['egw']->acl->check('global_categories_access',16,'admin');
+			$this->acl_delete = !$GLOBALS['egw']->acl->check('global_categories_access',32,'admin');
+			$this->acl_add_sub= !$GLOBALS['egw']->acl->check('global_categories_access',64,'admin');
 
-			if(!@is_object($GLOBALS['phpgw']->js))
+			if(!@is_object($GLOBALS['egw']->js))
 			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
-			$GLOBALS['phpgw']->js->validate_file('jscode','openwindow','admin');
+			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 
 			$this->appname = get_var('appname',array('GET','POST'));
-			$GLOBALS['phpgw_info']['flags']['app_header'] = $GLOBALS['phpgw_info']['apps'][$this->appname ? $this->appname : 'admin']['title'];
+			$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps'][$this->appname ? $this->appname : 'admin']['title'];
 
 			$this->start		= $this->bo->start;
 			$this->query		= $this->bo->query;
@@ -68,7 +68,7 @@
 			$this->cat_id		= $this->bo->cat_id;
 			if($this->debug) { $this->_debug_sqsof(); }
 
-			$dir = dir(PHPGW_SERVER_ROOT.'/phpgwapi/images');
+			$dir = dir(EGW_SERVER_ROOT.'/phpgwapi/images');
 			while($file = $dir->read())
 			{
 				if (preg_match('/\\.(png|gif|jpe?g)$/i',$file))
@@ -78,7 +78,7 @@
 			}
 			$dir->close();
 			sort($this->icons);
-			$this->img_url = $GLOBALS['phpgw_info']['server']['webserver_url'].'/phpgwapi/images/';
+			$this->img_url = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/images/';
 		}
 
 		function _debug_sqsof()
@@ -141,12 +141,12 @@
 
 			if ($_POST['add'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+				$GLOBALS['egw']->redirect_link('/index.php',$link_data);
 			}
 
 			if ($_POST['done'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+				$GLOBALS['egw']->redirect_link('/admin/index.php');
 			}
 
 			$this->template->set_file(array('cat_list_t' => 'listcats.tpl'));
@@ -160,14 +160,14 @@
 				$this->template->set_block('cat_list_t','search','searchhandle');
 			}
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] .= ' - '.lang('Global categories');
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw_info']['flags']['app_header'] .= ' - '.lang('Global categories');
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 			$this->set_langs();
 			$this->template->set_var('query',$this->query);
 
 			$link_data['menuaction'] = 'admin.uicategories.index';
-			$this->template->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$link_data));
+			$this->template->set_var('action_url',$GLOBALS['egw']->link('/index.php',$link_data));
 
 			if(!$start)
 			{
@@ -193,19 +193,29 @@
 
 				if ($data['color'])
 				{
-					$this->template->set_var('tr_color',$data['color']);
+					$this->template->set_var('td_color',$data['color']);
 					$gray = (hexdec(substr($data['color'],1,2))+hexdec(substr($data['color'],3,2))+hexdec(substr($data['color'],5,2)))/3;
 				}
+				
+
 				else
 				{
-					$this->nextmatchs->template_alternate_row_color($this->template);
+					$this->template->set_var('td_color','');
+					//$this->nextmatchs->template_alternate_row_color($this->template);
 					$gray = 255;
 				}
+
+				//else
+				//{
+					$this->nextmatchs->template_alternate_row_color($this->template);
+					$gray = 255;
+				// }
+				
 				$this->template->set_var('color',$gray < 128 ? 'style="color: white;"' : '');
 
 				$id = $cat['id'];
 				$level = $cat['level'];
-				$cat_name = $GLOBALS['phpgw']->strip_html($cat['name']);
+				$cat_name = $GLOBALS['egw']->strip_html($cat['name']);
 
 				if ($level > 0)
 				{
@@ -214,7 +224,7 @@
 					$cat_name = $spaceset . $cat_name;
 				}
 
-				$descr = $GLOBALS['phpgw']->strip_html($cat['description']);
+				$descr = $GLOBALS['egw']->strip_html($cat['description']);
 				if (!$descr) { $descr = '&nbsp;'; }
 
 				if ($level == 0)
@@ -243,7 +253,7 @@
 					$link_data['menuaction'] = 'admin.uicategories.edit';
 					$link_data['cat_parent'] = $id;
 					unset($link_data['cat_id']);
-					$this->template->set_var('add_sub','<a href="'.$GLOBALS['phpgw']->link('/index.php',$link_data).'">'.
+					$this->template->set_var('add_sub','<a href="'.$GLOBALS['egw']->link('/index.php',$link_data).'">'.
 						lang('Add sub').'</a>');
 				}
 				if ($this->appname && $cat['app_name'] == $this->appname)
@@ -264,7 +274,7 @@
 				if ($show_edit_del && $this->acl_edit)
 				{
 					$link_data['menuaction'] = 'admin.uicategories.edit';
-					$this->template->set_var('edit','<a href="'.$GLOBALS['phpgw']->link('/index.php',$link_data).'">'.
+					$this->template->set_var('edit','<a href="'.$GLOBALS['egw']->link('/index.php',$link_data).'">'.
 						lang('Edit').'</a>');
 				}
 				else
@@ -274,7 +284,7 @@
 				if ($show_edit_del && $this->acl_delete)
 				{
 					$link_data['menuaction'] = 'admin.uicategories.delete';
-					$this->template->set_var('delete','<a href="'.$GLOBALS['phpgw']->link('/index.php',$link_data).'">'.
+					$this->template->set_var('delete','<a href="'.$GLOBALS['egw']->link('/index.php',$link_data).'">'.
 						lang('Delete').'</a>');
 				}
 				else
@@ -284,15 +294,19 @@
 
 				$data = unserialize($cat['data']);
 				$icon = $data['icon'];
-				$dir_img = $GLOBALS['phpgw_info']['server']['webserver_url'] . SEP . 'phpgwapi' . SEP . 'images' . SEP;
-				$this->template->set_var('icon', "<img src='". $dir_img . $icon  ."'>");
+				$dir_img = $GLOBALS['egw_info']['server']['webserver_url'] . SEP . 'phpgwapi' . SEP . 'images' . SEP;
+				
+				if (strlen($icon) > 0)
+						$this->template->set_var('icon', "<img src='". $dir_img . $icon  ."'>");
+				else
+						$this->template->set_var('icon', "&nbsp;");
 
 				$this->template->fp('list','cat_list',True);
 			}
 			$link_data['menuaction'] = 'admin.uicategories.edit';
 			unset($link_data['cat_id']);
 			unset($link_data['cat_parent']);
-			$this->template->set_var('add_action',$GLOBALS['phpgw']->link('/index.php',$link_data));
+			$this->template->set_var('add_action',$GLOBALS['egw']->link('/index.php',$link_data));
 
 			$this->save_sessiondata();
 			$this->template->pfp('out','cat_list_t',True);
@@ -320,12 +334,12 @@
 
 			if (!$this->acl_add && $cat_parent == 0 || !$this->acl_add_sub && $cat_parent != 0)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php');
+				$GLOBALS['egw']->redirect_link('/index.php');
 			}
 			if ($_POST['cancel'] || $this->cat_id && !$this->acl_edit || $this->cat_id &&
 				(!$this->acl_add && $cat_parent == 0 || !$this->acl_add_sub && $cat_parent != 0))
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+				$GLOBALS['egw']->redirect_link('/index.php',$link_data);
 			}
 
 			if ($_POST['save'])
@@ -348,16 +362,16 @@
 				$error = $this->bo->check_values($values);
 				if (is_array($error))
 				{
-					$this->template->set_var('message',$GLOBALS['phpgw']->common->error_list($error));
+					$this->template->set_var('message',$GLOBALS['egw']->common->error_list($error));
 				}
 				else
 				{
 					$this->cat_id = $this->bo->save_cat($values);
-					$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+					$GLOBALS['egw']->redirect_link('/index.php',$link_data);
 				}
 			}
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] .= ' - '.($this->cat_id ? lang('Edit global category'):lang('Add global category'));
+			$GLOBALS['egw_info']['flags']['app_header'] .= ' - '.($this->cat_id ? lang('Edit global category'):lang('Add global category'));
 
 			$this->set_langs();
 
@@ -385,30 +399,34 @@
 
 			$link_data['menuaction']	= 'admin.uicategories.edit';
 			$link_data['cat_id']		= $this->cat_id; 
-			$this->template->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$link_data));
+			$this->template->set_var('action_url',$GLOBALS['egw']->link('/index.php',$link_data));
 
 			if ($this->acl_delete)
 			{
 				$link_data['menuaction'] = 'admin.uicategories.delete';
 
-				$this->template->set_var('delete','<form method="POST" action="' . $GLOBALS['phpgw']->link('/index.php',$link_data)
+				$this->template->set_var('delete','<form method="POST" action="' . $GLOBALS['egw']->link('/index.php',$link_data)
 					. '"><input type="submit" value="' . lang('Delete') .'"></form>');
 			}
 			else
 			{
 				$this->template->set_var('delete','&nbsp;');
 			}
-			$this->template->set_var('cat_name',$GLOBALS['phpgw']->strip_html($cat['name']));
-			$this->template->set_var('cat_description',$GLOBALS['phpgw']->strip_html($cat['description']));
+			$this->template->set_var('cat_name',$GLOBALS['egw']->strip_html($cat['name']));
+			$this->template->set_var('cat_description',$GLOBALS['egw']->strip_html($cat['description']));
 			$this->template->set_var('category_list',$this->bo->cats->formatted_list(array('selected' => $cat['parent'],'self' => $this->cat_id)));
 
-			if (!is_object($GLOBALS['phpgw']->html))
+			if (!is_object($GLOBALS['egw']->html))
 			{
-				$GLOBALS['phpgw']->html = CreateObject('phpgwapi.html');
+				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
 			}
-			$this->template->set_var('color',$GLOBALS['phpgw']->html->inputColor('cat_data[color]',$cat['data']['color'],lang('Click to select a color')));
+			$this->template->set_var('color',$GLOBALS['egw']->html->inputColor('cat_data[color]',$cat['data']['color'],lang('Click to select a color')));
+
+			//$options = '<option value=""'.(!$cat['data']['icon'] ? ' selected="1"':'').'>'.lang('none')."</options>\n";
+
+			$options = '';
+			$options = '<option value="">'.lang('none')."</options>\n";
 
-			$options = '<option value=""'.(!$cat['data']['icon'] ? ' selected="1"':'').'>'.lang('none')."</options>\n";
 			foreach ($this->icons as $icon)
 			{
 				$options .= '<option value="'.$icon.'"'.($icon == $cat['data']['icon'] ? ' selected="1"':'').'>'.
@@ -443,7 +461,7 @@
 			}
 			$this->template->set_var('hidden_vars',$hidden_vars);
 
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
 			$this->template->pfp('out','form');
@@ -453,7 +471,7 @@
 		{
 			if (!$this->acl_delete)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php');
+				$GLOBALS['egw']->redirect_link('/index.php');
 			}
 			$link_data = array
 			(
@@ -463,7 +481,7 @@
 
 			if (!$this->cat_id || $_POST['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+				$GLOBALS['egw']->redirect_link('/index.php',$link_data);
 			}
 
 			if ($_POST['confirm'])
@@ -476,7 +494,7 @@
 				{
 					$this->bo->delete($this->cat_id,False);
 				}
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+				$GLOBALS['egw']->redirect_link('/index.php',$link_data);
 			}
 			$this->template->set_file(array('category_delete' => 'delete_cat.tpl'));
 
@@ -496,13 +514,13 @@
 				'cat_id'   => $this->cat_id
 			));
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] .= ' - '.lang('Delete category');
-			if(!@is_object($GLOBALS['phpgw']->js))
+			$GLOBALS['egw_info']['flags']['app_header'] .= ' - '.lang('Delete category');
+			if(!@is_object($GLOBALS['egw']->js))
 			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
-			$GLOBALS['phpgw']->js->validate_file('jscode','openwindow','admin');
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
 			$hidden_vars = '<input type="hidden" name="cat_id" value="' . $this->cat_id . '">' . "\n";
@@ -550,7 +568,7 @@
 
 				$link_data['menuaction'] = 'admin.uicategories.delete';
 				$link_data['cat_id'] = $this->cat_id;
-				$this->template->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$link_data));
+				$this->template->set_var('action_url',$GLOBALS['egw']->link('/index.php',$link_data));
 				$this->template->set_var('lang_yes',lang('Yes'));
 				$this->template->set_var('lang_no',lang('No'));
 				$this->template->pfp('out','category_delete');
