@@ -8,13 +8,13 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: hook_preferences.inc.php,v 1.21.2.1 2004/07/21 14:15:28 alpeb Exp $ */
+	/* $Id: hook_preferences.inc.php 19419 2005-10-14 16:24:39Z ralfbecker $ */
 
 	$file = array(
-		'Import Bookmarks' => $GLOBALS['phpgw']->link('/index.php','menuaction=bookmarks.ui.import'),
-		'Export Bookmarks' => $GLOBALS['phpgw']->link('/index.php','menuaction=bookmarks.ui.export'),
-		'Grant Access'  => $GLOBALS['phpgw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$appname),
-		'Edit Categories' => $GLOBALS['phpgw']->link('/index.php','menuaction=preferences.uicategories.index&cats_app=' . $appname . '&cats_level=True&global_cats=True')
+		'Import Bookmarks' => $GLOBALS['egw']->link('/index.php','menuaction=bookmarks.ui.import'),
+		'Export Bookmarks' => $GLOBALS['egw']->link('/index.php','menuaction=bookmarks.ui.export'),
+		'Grant Access'  => $GLOBALS['egw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$appname),
+		'Edit Categories' => $GLOBALS['egw']->link('/index.php','menuaction=preferences.uicategories.index&cats_app=' . $appname . '&cats_level=True&global_cats=True')
 	);
 	display_section('bookmarks','Bookmarks',$file);
 ?>
