@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
 	* eGroupWare                                                               *
-	* http://www.egroupware.orgvv                                              *
+	* http://www.egroupware.org                                                *
 	* --------------------------------------------                             *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
@@ -9,8 +9,16 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: default_records.inc.php,v 1.8 2004/01/25 21:36:17 reinerj Exp $ */
+	/* $Id: default_records.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$oProc->query("DELETE FROM phpgw_config WHERE config_app='bookmarks'");
-	$oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('bookmarks','mail_footer','\n\n--\nThis was sent from eGroupWare\nhttp://www.egroupware.org\n')");
-?>
+	foreach(array(
+		'mail_footer' => '\n\n--\nThis was sent from eGroupWare\nhttp://www.egroupware.org\n',
+	) as $name => $value)
+	{
+		$oProc->insert($GLOBALS['egw_setup']->config_table,array(
+			'config_value' => $value,
+		),array(
+			'config_app' => 'bookmarks',
+			'config_name' => $name,
+		),__FILE__,__LINE__);
+	}
