@@ -10,7 +10,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.bocalupdate.inc.php 22175 2006-07-28 16:32:00Z ralfbecker $ */
+/* $Id: class.bocalupdate.inc.php 22790 2006-11-04 18:37:05Z jaytraxx $ */
 
 require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.bocal.inc.php');
 
@@ -48,7 +48,16 @@ define('MSG_DISINVITE',7);
 
 class bocalupdate extends bocal
 {
-	var $debug=false;
+	/**
+	 * name of method to debug or level of debug-messages:
+	 *	False=Off as higher as more messages you get ;-)
+	 *	1 = function-calls incl. parameters to general functions like search, read, write, delete
+	 *	2 = function-calls to exported helper-functions like check_perms
+	 *	4 = function-calls to exported conversation-functions like date2ts, date2array, ...
+	 *	5 = function-calls to private functions
+	 * @var mixed
+	 */
+	var $debug;
 	
 	/**
 	 * @var string/boolean $log_file filename to enable the login or false for no update-logging
@@ -409,8 +418,8 @@ class bocalupdate extends bocal
 		}
 		$version = $GLOBALS['egw_info']['apps']['calendar']['version'];
 
-		// ignore events in the past
-		if($old_event != False && $this->date2ts($old_event['start']) < $this->now_su)
+		// ignore events in the past (give a tolerance of 10 seconds for the script)
+		if($old_event != False && $this->date2ts($old_event['start']) < ($this->now_su - 10))
 		{
 			return False;
 		}
@@ -802,7 +811,7 @@ class bocalupdate extends bocal
 		{
 			$link = ($GLOBALS['egw_info']['server']['enforce_ssl'] || $_SERVER['HTTPS'] ? 'https://' : 'http://').
 				($GLOBALS['egw_info']['server']['hostname'] ? $GLOBALS['egw_info']['server']['hostname'] : $_SERVER['HTTP_HOST']).
-				$details['link'];
+				$link;
 		}
 		$event_arr['link']['data'] = $details['link'] = $link;
 		$dis = array();
