@@ -9,7 +9,7 @@
 	*  Free Software Foundation; either version 2 of the License.              *
 	\**************************************************************************/
 
-	/* $Id: class.boical.inc.php 22335 2006-08-24 09:46:46Z lkneschke $ */
+	/* $Id: class.boical.inc.php 22835 2006-11-13 08:34:39Z lkneschke $ */
 
 	require_once EGW_SERVER_ROOT.'/calendar/inc/class.bocalupdate.inc.php';
 	require_once EGW_SERVER_ROOT.'/phpgwapi/inc/horde/Horde/iCalendar.php';
@@ -571,7 +571,7 @@
 								}
 								break;
 	 						case 'TRANSP':
-	 							if($version = '1.0') {
+	 							if($version == '1.0') {
 	 								$vcardData['non_blocking'] = $attributes['value'] == 1;
 	 							} else {
 									$vcardData['non_blocking'] = $attributes['value'] == 'TRANSPARENT';
@@ -788,6 +788,15 @@
 							break;
 					}
 					break;
+
+				//Syncevolution compatibility	
+				case 'patrick ohly':
+					$this->supportedFields = $defaultFields + array(
+						'participants' => 'participants',
+						'owner'        => 'owner',
+						'category'     => 'category',
+					);
+					break;
 					
 				case 'file':	// used outside of SyncML, eg. by the calendar itself ==> all possible fields
 					$this->supportedFields = $defaultFields + array(
