@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.holidaycalc_JP.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.holidaycalc_JP.inc.php 22710 2006-10-23 05:02:00Z ralfbecker $ */
 
 	/**
 	 * Calculations for calendar JP holidays
@@ -21,7 +21,7 @@
 	 */
 	class holidaycalc
 	{
-		function calculate_date($holiday, &$holidays, $year, &$i)
+		function calculate_date($holiday, &$holidays, $year)
 		{
 			static	$cached_month;
 			static	$cached_day;
