@@ -10,7 +10,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.uiviews.inc.php 22361 2006-08-29 06:42:01Z ralfbecker $ */
+/* $Id: class.uiviews.inc.php 23119 2006-12-25 12:58:03Z ralfbecker $ */
 
 include_once(EGW_INCLUDE_ROOT . '/calendar/inc/class.uical.inc.php');
 
@@ -797,7 +797,13 @@ class uiviews extends uical
 		if ($this->debug > 1 || $this->debug==='dayColWidget') $this->bo->debug_message('uiviews::dayColWidget(%1,%2,left=%3,width=%4,)',False,$day_ymd,$events,$left,$width);
 
 		$day_start = $this->bo->date2ts((string)$day_ymd);
-
+		
+		// if daylight saving is switched on or off, correct $day_start
+		// gives correct times after 2am, times between 0am and 2am are wrong
+		if(($daylight_diff = $day_start + 12*HOUR_s - ($this->bo->date2ts($day_ymd."T120000"))))
+		{
+			$day_start -= $daylight_diff;
+		}
 		// sorting the event into columns with none-overlapping events, the events are already sorted by start-time
 		$eventCols = $col_ends = array();
 		foreach($events as $event)
@@ -1235,7 +1241,8 @@ class uiviews extends uical
 			{
 				foreach($event['participants'] as $sort => $status)
 				{
-					if (isset($sort2label[$sort]))
+					// only show if participant has not rejected or user wants to see rejections
+					if (isset($sort2label[$sort]) && ($status != 'R' || $this->bo->cal_prefs['show_rejected']))
 					{
 						$rows[$sort][] =& $events[$key];
 					}
