@@ -9,8 +9,18 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: default_records.inc.php,v 1.1 2004/03/22 07:44:54 ralfbecker Exp $ */
+	/* $Id: default_records.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	// enable auto-loading of holidays from localhost by default
-	$oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('phpgwapi','auto_load_holidays','True')");
-	$oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('phpgwapi','holidays_url_path','localhost')");
+	foreach(array(
+		'auto_load_holidays' => 'True',
+		'holidays_url_path'  => 'localhost',
+	) as $name => $value)
+	{
+		$oProc->insert($GLOBALS['egw_setup']->config_table,array(
+			'config_value' => $value,
+		),array(
+			'config_app' => 'phpgwapi',
+			'config_name' => $name,
+		),__FILE__,__LINE__);
+	}
