@@ -9,16 +9,16 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php,v 1.3 2003/11/02 01:00:58 lkneschke Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
 	$_GET['menuaction']     = 'emailadmin.ui.listProfiles';
 
-	$phpgw_info = array();
-	$phpgw_info['flags'] = array
-	(
-		'currentapp' => 'emailadmin',
-		'noheader'   => True,
-		'nonavbar'   => True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp' => 'emailadmin',
+			'noheader'   => True,
+			'nonavbar'   => True,
+		),
 	);
 	include('../header.inc.php');
 
