@@ -10,11 +10,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.etemplate.inc.php,v 1.7 2004/01/27 16:58:17 reinerj Exp $ */
+	/* $Id: class.etemplate.inc.php 19711 2005-11-09 20:50:45Z ralfbecker $ */
 
-	$ui = ''; // html UI, which UI to use, should come from api and be in $GLOBALS['phpgw']???
+	$ui = ''; // html UI, which UI to use, should come from api and be in $GLOBALS['egw']???
 	if ($_ENV['DISPLAY'] && isset($_SERVER['_']))
 	{
 		$ui = '_gtk';
 	}
-	include_once(PHPGW_INCLUDE_ROOT . "/etemplate/inc/class.uietemplate$ui.inc.php");
+	include_once(EGW_INCLUDE_ROOT . "/etemplate/inc/class.uietemplate$ui.inc.php");
