@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.nextmatch_widget.inc.php 22883 2006-12-05 10:11:26Z ralfbecker $ */
+	/* $Id: class.nextmatch_widget.inc.php 23933 2007-05-25 12:27:38Z ralfbecker $ */
 
 	/**
 	 * eTemplate Extension: Widget that show only a certain number of data-rows and allows to modifiy the rows shown (scroll).
@@ -198,7 +198,7 @@
 			}
 			if (!isset($value['cat_app'])) $value['cat_app'] = $app;	// if no cat_app set, use the app from the get_rows func
 
-			$max = $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
+			$max = (int)$GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 			$row_options = array();
 			foreach(array(5,12,25,50,100,200,500,999) as $n)
 			{
@@ -215,7 +215,7 @@
 			if (!isset($value['num_rows'])) $value['num_rows'] = $max;
 			if ($value['num_rows'] != $max)
 			{
-				$GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'] = $max = $value['num_rows'];
+				$GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'] = $max = (int)$value['num_rows'];
 			}				
 			if (!is_object($obj) || !method_exists($obj,$method))
 			{
@@ -388,7 +388,8 @@
 			{
 				$loop = true;	// num_rows changed
 			}
-			$max = $value['num_rows'] ? $value['num_rows'] : $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
+			$value['num_rows'] = (int) $value['num_rows'];
+			$max = $value['num_rows'] ? $value['num_rows'] : (int)$GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 
 			if ($value['start_search'] || $value['search'] != $old_value['search'] ||
 				isset($value['cat_id']) && $value['cat_id'] != $old_value['cat_id'] ||
