@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.select_widget.inc.php 22883 2006-12-05 10:11:26Z ralfbecker $ */
+	/* $Id: class.select_widget.inc.php 23570 2007-04-06 12:15:59Z ralfbecker $ */
 
 	/**
 	 * eTemplate Extension: several select-boxes with predefined eGW specific content
@@ -237,7 +237,7 @@
 					}
 					foreach((array)$categories->return_sorted_array(0,False,'','','',!$type) as $cat)
 					{
-						$s = str_repeat('&nbsp;',$cat['level']) . $GLOBALS['egw']->strip_html($cat['name']);
+						$s = str_repeat('&nbsp;',$cat['level']) . stripslashes($cat['name']);
 
 						if ($cat['app_name'] == 'phpgw' || $cat['owner'] == '-1')
 						{
