@@ -10,14 +10,13 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.xul_io.inc.php,v 1.26.2.1 2004/08/21 08:00:58 ralfbecker Exp $ */
-
+	/* $Id: class.xul_io.inc.php 20839 2006-03-27 12:23:49Z ralfbecker $ */
 
 	if (!function_exists('var2xml'))
 	{
-		if (file_exists(PHPGW_API_INC.'class.xmltool.inc.php'))
+		if (file_exists(EGW_API_INC.'class.xmltool.inc.php'))
 		{
-			include_once(PHPGW_API_INC.'class.xmltool.inc.php');
+			include_once(EGW_API_INC.'class.xmltool.inc.php');
 		}
 		else
 		{
@@ -25,6 +24,16 @@
 		}
 	}
 
+	/**
+	 * XUL/XML Import & Export for eTemplates
+	 *
+	 * used only internaly
+	 *
+	 * @package etemplate
+	 * @subpackage api
+	 * @author RalfBecker-AT-outdoor-training.de
+	 * @license GPL
+	 */
 	class xul_io
 	{
 		var $widget2xul;
@@ -33,7 +42,10 @@
 
 		function xul_io()
 		{
-         $this->attr2xul = array(	// how to translate attr, common to all widgets
+			/**
+			 * @var array $attr2xul how to translate attr, common to all widgets
+			 */
+			$this->attr2xul = array(
 				'name' => 'id',
 				'help' => 'statustext',
 				'span' => 'span,class',
@@ -42,7 +54,10 @@
 				'readonly' => 'readonly=true',
 				'size' => 'options'
 			);
-			$this->widget2xul = array(	// how to translate widget-names and widget-spec. attr.
+			/**
+			 * @var array $widget2xul how to widget-names and widget-spec. attr., not set ones are identical
+			 */
+			$this->widget2xul = array(
 				'label' => array(
 					'.name' => 'description',
 					'label' => 'value'
@@ -64,7 +79,7 @@
 				'float' => array(
 					'.name' => 'textbox',
 					'.set' => 'type=float',
-					'size' => 'min,max,size'
+					'size' => 'min,max,size,precision'
 				),
 				'select' => array(
 					'.name' => 'menulist,menupopup',
@@ -74,7 +89,7 @@
 					'size'  => 'rows,options'
 				),
 				'template' => array(
-					'.name' => 'grid',
+					'.name' => 'template',
 					'size'  => 'content'
 				),
 				'image'   => array(
@@ -92,35 +107,37 @@
 					'size' => 'style,plugins',
 				),
 			);
+			/**
+			 * @var array $xul2widget how to xul-widget names to our internal ones, not set ones are identical
+			 */
 			$this->xul2widget = array(
 				'menulist' => 'select',
 				'listbox' => 'select',
+				'menupopup' => 'select',
 				'description' => 'label'
 			);
 		}
 
+		/**
+		 * sets an attribute in the xml object representing a widget
+		 *
+		 * @param object &$widget widget to set the attribute in
+		 * @param string $attr comma delimited attr = default-value pairs, eg. "type=int,min=0"
+		 * @param array $val array with values to set
+		 */
 		function set_attributes(&$widget,$attr,$val)
 		{
-			$this->set_attributes2($widget,$attr,$val,$dummy);
-		}
-
-		function set_attributes2(&$widget,$attr,$val,&$spanned)
-		{
-			if ($attr != '')
+			if ($attr != '' && !is_numeric($attr))
 			{
 				$attrs = explode(',',$attr);
 
 				if (count($attrs))
 				{
-					$vals = count($attrs) > 1 ? split(',',$val,count($attrs)) : array($val);
-					while (list($n,$attr) = each($attrs))
+					$vals = count($attrs) > 1 ? explode(',',$val,count($attrs)) : array($val);
+					foreach($attrs as $n => $attr)
 					{
 						if (($val = $vals[$n]) != '')
 						{
-							if ($attr == 'span')
-							{
-								$spanned = $val == 'all' ? 999 : $val - 1;
-							}
 							list($attr,$set) = explode('=',$attr);
 							$widget->set_attribute($attr,$set != '' ? $set : $val);
 						}
@@ -129,48 +146,57 @@
 			}
 		}
 
-		function cell2widget($cell,&$spanned,$etempl,&$root,&$embeded_too)
+		/**
+		 * add a widget to a parent
+		 *
+		 * @param object &$parent parten to add the widget
+		 * @param array $cell widget to add
+		 * @param array &$embeded_too already embeded eTemplates
+		 * @return object reference (!) the the xml object representing the widget, so other children can be added
+		 */
+		function &add_widget(&$parent,$cell,&$embeded_too)
 		{
 			$type = $cell['type'];
 			if (is_array($type))
 			{
 				list(,$type) = each($type);
 			}
+			if (!$type) $cell['type'] = $type = 'hugo';
 			if (substr($type,0,6) == 'select')
 			{
 				$type = $cell['size'] > 1 ? 'select-multi' : 'select';
 			}
 			$widgetattr2xul = isset($this->widget2xul[$type]) ? $this->widget2xul[$type] : array();
 			$type = isset($widgetattr2xul['.name']) ? $widgetattr2xul['.name'] : $type;
-			list($parent,$child,$child2) = explode(',',$type);
-			$widget = new xmlnode($parent);
+			list($type,$child,$child2) = explode(',',$type);
+			$widget =& new xmlnode($type);
 			$attr_widget = &$widget;
 			if ($child)
 			{
-				$child = new xmlnode($child);
-				$attr_widget = &$child;
+				$child =& new xmlnode($child);
+				if ($type != 'tabbox') $attr_widget = &$child;
 			}
 			if ($child2)
 			{
-				$child2 = new xmlnode($child2);
+				$child2 =& new xmlnode($child2);
 			}
 			if (isset($widgetattr2xul['.set']))	// set default-attr for type
 			{
 				$attrs = explode(',',$widgetattr2xul['.set']);
-				while (list(,$attr) = each($attrs))
+				foreach($attrs as $attr)
 				{
 					list($attr,$val) = explode('=',$attr);
 					$widget->set_attribute($attr,$val);
 				}
 			}
-			switch ($parent)
+			switch ($type)
 			{
 			case 'nextmatch':
 				list($tpl) = explode(',',$cell['size']);
-				$embeded = new etemplate($tpl,$etempl->as_array());
+				$embeded =& new etemplate($tpl,$this->load_via);
 				if ($embeded_too)
 				{
-					$this->etempl2grid($embeded,$root,$embeded_too);
+					$this->add_etempl($embeded,$embeded_too);
 				}
 				$cell['size'] = $embeded->name;
 				unset($embeded);
@@ -181,20 +207,21 @@
 				$names  = explode('|',$cell['name']);   unset($cell['name']);
 				for ($n = 0; $n < count($labels); ++$n)
 				{
-					$tab = new xmlnode('tab');
+					$tab =& new xmlnode('tab');
 					$tab->set_attribute('label',$labels[$n]);
 					$tab->set_attribute('statustext',$helps[$n]);
 					$child->add_node($tab);
 
-					$embeded = new etemplate($names[$n],$etempl->as_array());
+					$embeded =& new etemplate($names[$n],$this->load_via);
 					if ($embeded_too)
 					{
-						$this->etempl2grid($embeded,$root,$embeded_too);
+						$this->add_etempl($embeded,$embeded_too);
 					}
-					$grid = new xmlnode('grid');
-					$grid->set_attribute('id',$embeded->name);
-					$child2->add_node($grid);
+					$template =& new xmlnode('template');
+					$template->set_attribute('id',$embeded->name);
+					$child2->add_node($template);
 					unset($embeded);
+					unset($template);
 				}
 				break;
 			case 'menulist':	// id,options belongs to the 'menupopup' child
@@ -210,31 +237,47 @@
 					$attr_widget->set_attribute('type',$cell['type']);
 				}
 				break; 
+			case 'groupbox':
+				if ($cell['label'])
+				{
+					$caption =& new xmlnode('caption');
+					$caption->set_attribute('label',$cell['label']);
+					$widget->add_node($caption);
+					unset($cell['label']);
+				}
+				// fall-through
 			case 'vbox':
 			case 'hbox':
-				list($anz,$options) = split(',',$cell['size'],2);
+			case 'box':
+			case 'deck':
+				list($anz,$orient,$options) = split(',',$cell['size'],2);
 				for ($n = 1; $n <= $anz; ++$n)
 				{
-					$widget->add_node($this->cell2widget($cell[$n],$no_span,$etempl,$root,$embeded_too));
+					$this->add_widget($widget,$cell[$n],$embeded_too);
 					unset($cell[$n]);
 				}
+				$cell['orient'] = $orient;
 				$cell['size'] = $options;
 				break;
 
-			case 'grid':
+			case 'template':
 				if ($cell['name'][0] != '@' && $embeded_too)
 				{
-					$embeded = new etemplate();
-					if ($embeded->read($name=$embeded->expand_name($cell['name'],0,0),'default','default',0,'',$etempl->as_array()))
+					$templ =& new etemplate();
+					if ($templ->read(boetemplate::expand_name($cell['name'],0,0),'default','default',0,'',$this->load_via))
 					{
-						$this->etempl2grid($embeded,$root,$embeded_too);
+						$this->add_etempl($templ,$embeded_too);
 					}
-					$cell['name'] = $embeded->name;
-					unset($embeded);
+					$cell['name'] = $templ->name;
+					unset($templ);
 				}
 				break;
+
+			case 'grid':
+				$this->add_grid($parent,$cell,$embeded_too);
+				return;	// grid is already added
 			}
-			while (list($attr,$val) = each($cell))
+			foreach($cell as $attr => $val)
 			{
 				if (is_array($val))	// correct old buggy etemplates
 				{
@@ -248,7 +291,7 @@
 				{
 					$attr = $this->attr2xul[$attr];
 				}
-				$this->set_attributes2($attr_widget,$attr,$val,$spanned);
+				$this->set_attributes($attr_widget,$attr,$val);
 			}
 			if ($child)
 			{
@@ -258,10 +301,64 @@
 			{
 				$widget->add_node($child2);
 			}
-			return $widget;
+			$parent->add_node($widget);
 		}
 
-		function etempl2grid($etempl,&$root,&$embeded_too)
+		/**
+		 * add a grid to $parent (xml object)
+		 *
+		 * @param object &$parent where to add the grid
+		 * @param array $grid grid to add
+		 * @param array &embeded_too array with already embeded eTemplates
+		 */
+		function add_grid(&$parent,$grid,&$embeded_too)
+		{
+			$xul_grid =& new xmlnode('grid');
+			$this->set_attributes($xul_grid,'width,height,border,class,spacing,padding,overflow',$grid['size']);
+
+			$xul_columns =& new xmlnode('columns');
+			$xul_rows =& new xmlnode('rows');
+
+			reset($grid['data']);
+			list(,$opts) = each ($grid['data']); // read over options-row
+			while (list($r,$row) = each ($grid['data']))
+			{
+				$xul_row =& new xmlnode('row');
+				$this->set_attributes($xul_row,'class,valign',$opts["c$r"]);
+				$this->set_attributes($xul_row,'height,disabled',$opts["h$r"]);
+
+				$spanned = 0;
+				foreach($row as $c => $cell)
+				{
+					if ($r == '1')	// write columns only once in the first row
+					{
+						$xul_column =& new xmlnode('column');
+						$this->set_attributes($xul_column,'width,disabled',$opts[$c]);
+						$xul_columns->add_node($xul_column);
+					}
+					if ($spanned-- > 1)
+					{
+						continue;	// spanned cells are not written
+					}
+					$this->add_widget($xul_row,$cell,$embeded_too);
+					
+					$spanned = $cell['span'] == 'all' ? 999 : $cell['span'];
+				}
+				$xul_rows->add_node($xul_row);
+			}
+			$xul_grid->add_node($xul_columns);
+			$xul_grid->add_node($xul_rows);
+
+			$parent->add_node($xul_grid);
+		}
+
+		/**
+		 * add / embed an eTemplate into the global $xul_overlay object (used by export)
+		 *
+		 * @param object &$etempl eTemplate to embed
+		 * @param array &embeded_too array with already embeded templates
+		 */
+		function add_etempl(&$etempl,&$embeded_too)
 		{
 			if (is_array($embeded_too))
 			{
@@ -276,106 +373,64 @@
 			}
 			$embeded_too[$etempl->name] = True;
 			
-			$xul_grid = new xmlnode('grid');
-			$xul_grid->set_attribute('id',$etempl->name);
-			$xul_grid->set_attribute('template',$etempl->template);
-			$xul_grid->set_attribute('lang',$etempl->lang);
-			$xul_grid->set_attribute('group',$etempl->group);
-			$xul_grid->set_attribute('version',$etempl->version);
-			$this->set_attributes($xul_grid,'width,height,border,class,spacing,padding',$etempl->size);
-
-			$xul_columns = new xmlnode('columns');
-			$xul_rows = new xmlnode('rows');
-
-			reset($etempl->data);
-			list(,$opts) = each ($etempl->data); // read over options-row
-			while (list($r,$row) = each ($etempl->data))
+			$template =& new xmlnode('template');
+			$template->set_attribute('id',$etempl->name);
+			$template->set_attribute('template',$etempl->template);
+			$template->set_attribute('lang',$etempl->lang);
+			$template->set_attribute('group',$etempl->group);
+			$template->set_attribute('version',$etempl->version);
+			
+			foreach($etempl->children as $child)
 			{
-				$xul_row = new xmlnode('row');
-				$this->set_attributes($xul_row,'class,valign',$opts["c$r"]);
-				$this->set_attributes($xul_row,'height,disabled',$opts["h$r"]);
-
-				$spanned = 0;
-				while (list($c,$cell) = each($row))
-				{
-					if ($r == '1')	// write columns only once in the first row
-					{
-						$xul_column = new xmlnode('column');
-						$this->set_attributes($xul_column,'width,disabled',$opts[$c]);
-						$xul_columns->add_node($xul_column);
-					}
-					if ($spanned)
-					{
-						--$spanned;
-						continue;	// spanned cells are not written
-					}
-					$xul_row->add_node($this->cell2widget($cell,$spanned,$etempl,$root,$embeded_too));
-				}
-				$xul_rows->add_node($xul_row);
+				$this->add_widget($template,$child,$embeded_too);
 			}
-			$xul_grid->add_node($xul_columns);
-			$xul_grid->add_node($xul_rows);
-
 			if ($etempl->style != '')
 			{
-				$styles = new xmlnode('styles');
+				$styles =& new xmlnode('styles');
 				$styles->set_value($etempl->style);
-				$xul_grid->add_node($styles);
+				$template->add_node($styles);
 			}
-			$root->add_node($xul_grid);
-
-			return '';
+			$this->xul_overlay->add_node($template);
 		}
 
+		/**
+		 * create an XML representation of an eTemplate
+		 *
+		 * @param object $etempl eTemplate object to export
+		 * @return string the XML 
+		 */
 		function export($etempl)
 		{
 			if ($this->debug)
 			{
 				echo "<p>etempl->data = "; _debug_array($etempl->data);
 			}
-			$doc = new xmldoc();
+			$doc =& new xmldoc();
 			$doc->add_comment('$'.'Id$');
 
-			$xul_overlay = new xmlnode('overlay');
+			$this->xul_overlay =& new xmlnode('overlay');	// global for all add_etempl calls
+			$this->load_via = $etempl->as_array();
 
 			$embeded_too = True;
-			$this->etempl2grid($etempl,$xul_overlay,$embeded_too);
+			$this->add_etempl($etempl,$embeded_too);
 
-			$doc->add_root($xul_overlay);
+			$doc->add_root($this->xul_overlay);
 			$xml = $doc->export_xml();
 
-			//if ($this->debug)
+			if ($this->debug)
 			{
 				echo "<pre>\n" . htmlentities($xml) . "\n</pre>\n";
 			}
 			return $xml;
 		}
 
-		function add_cell(&$etempl,$cell,&$box,&$col,$node_level)
-		{
-			if (!isset($box[$node_level-1]))
-			{
-				list($spanned) = explode(',',$cell['span']);
-				$spanned = $spanned == 'all' ? $etempl->cols - $col : $spanned;
-
-				$etempl->data[$etempl->rows][$etempl->num2chrs($col++)] = $cell;
-
-			/*	if ($attr['type'] == 'template' && !empty($attr['name']) && $attr['name'][0] != '@')
-				{
-					$etempl->data[$etempl->rows][$etempl->num2chrs($col++)]['obj'] = new etemplate($attr['name']);
-				} */
-				while (--$spanned > 0)
-				{
-					$etempl->data[$etempl->rows][$etempl->num2chrs($col++)] = $etempl->empty_cell();
-				}
-			}
-			else
-			{
-				$pcell = &$box[$node_level-1];
-				$pcell[++$pcell['anz']] = $cell;
-			}
-		}
-
+		/**
+		 * create an eTemplate from it's XML representation
+		 *
+		 * @param object &$etempl eTemplate object to set
+		 * @param string $data the XML 
+		 * @param array/string array with names of imported templates or error-message
+		 */
 		function import(&$etempl,$data)
 		{
 			if ($this->debug)
@@ -391,7 +446,7 @@
 			if (!$ok || !is_array($vals))
 			{
 				$err = 'Error Line '.xml_get_current_line_number($parser).', Column '.xml_get_current_column_number($parser).
-				       ': '.xml_error_string(xml_get_error_code($parser));
+							 ': '.xml_error_string(xml_get_error_code($parser));
 			}
 			xml_parser_free($parser);
 
@@ -399,8 +454,14 @@
 			{
 				return $err;
 			}
-			while (list($n,$node) = each($vals))
+			$parents = array();
+			$parent = null;
+			foreach($vals as $n => $node)
 			{
+				if ($this->debug)
+				{
+					echo "<h1>$n</h1><pre>".print_r($node,true)."</pre>";
+				}
 				$type = $node['type'];
 				$tag = $node['tag'];
 				$attr = is_array($node['attributes']) ? $node['attributes'] : array();
@@ -412,10 +473,6 @@
 				{
 					$attr['size'] = $attr['options']; unset($attr['options']);
 				}
-				if ($tag == 'grid' && $type == 'complete' && !is_array($tab_attr))
-				{
-					$tag = 'template';
-				}
 				if ($tag != 'textbox' && !isset($attr['type']))
 				{
 					$attr['type'] = $this->xul2widget[$tag] ? $this->xul2widget[$tag] : $tag;
@@ -428,37 +485,76 @@
 				{
 					case 'overlay':
 						break;
+					case 'template':
 					case 'grid':
-						if ($type != 'close' && is_array($tab_attr))
+						if ($type != 'open' && is_array($tab_attr))	// templates/grids in a tabpanel
 						{
 							$tab_names[] = $attr['name'];
 							break;
 						}
-						if ($node['level'] > 2)	// level 1 is the overlay
+						if ($tag == 'template' && $type != 'complete' && $node['level'] > 2)	// level 1 is the overlay
 						{
-							return "Can't import nested $node[tag]'s !!!";
+							return "Can't import nested $tag's !!!";
 						}
-						if ($type != 'open')
+						switch ($type)
 						{
-							break;
+							case 'close':
+								if (!count($parents) || $parent['.is_root'])	// templ import complet => save it
+								{
+									unset($parent['.is_root']);
+									unset($parent); $parents = array();
+									$etempl->fix_old_template_format(); 	// set the depricated compat vars
+									// save tmpl to the cache, as the file may contain more then one tmpl
+									$cname = ($etempl->template == '' ? 'default' : $etempl->template).'/'.$etempl->name.
+													 ($etempl->lang == '' ? '' : '.'.$etempl->lang);
+									$GLOBALS['egw_info']['etemplate']['cache'][$cname] = $etempl->as_array(1);
+									if ($this->debug)
+									{
+										$etempl->echo_tmpl();
+									}
+									$imported[] = $etempl->name;
+								}
+								else
+								{
+									// poping the last used parent from the end of the parents array (array_pop does not work with references)
+									$parent = &$parents[count($parents)-1];
+									unset($parents[count($parents)-1]);
+								}
+								break;
+							case 'open':
+								if (($is_root = is_null($parent)))	// starting a new templ
+								{
+									$etempl->init($attr);
+									$etempl->children = array();	// init adds one grid by default
+									$parent = &$etempl->children;
+								}
+								if ($tag == 'grid')
+								{
+									$size = '';
+									foreach(array('overflow','padding','spacing','class','border','height','width') as $opt)
+									{
+										$size = $attr[$opt] . ($size != '' ? ",$size" : '');
+									}
+									$grid = array(	// empty grid
+										'type' => 'grid',
+										'data' => array(),
+										'cols' => 0,
+										'rows' => 0,
+										'size' => $size,
+									);
+									if ($is_root) $grid['.is_root'] = true;	// we need to remember we have no template as parent 
+									soetemplate::add_child($parent,$grid);
+									$parents[count($parents)] = &$parent;
+									$parent = &$grid;
+									unset($grid);
+								}
+								break;
+							case 'complete':	// reference to an other template
+								$attr['type'] = 'template';	// might be grid in old xet-files
+								soetemplate::add_child($parent,$attr);
+								unset($attr);
+								break;
 						}
-						if ($grid_started)	// more than one grid in the file --> place it into the cache
-						{
-							$cname = ($etempl->template == '' ? 'default' : $etempl->template).'/'.$etempl->name.
-							         ($etempl->lang == '' ? '' : '.'.$etempl->lang);
-							$imported[] = $etempl->name;
-							$GLOBALS['phpgw_info']['etemplate']['cache'][$cname] = $etempl->as_array(1);
-						}
-						$grid_started = True;
-						$etempl->init($attr);
-						$size_opts = array('padding','spacing','class','border','height','width');
-						for ($size = ''; list(,$opt) = each($size_opts); )
-						{
-							$size = $attr[$opt] . ($size != '' ? ",$size" : '');
-						}
-						$etempl->size = $size;
-						$etempl->cols = $etempl->rows = 0;
-						$etempl->data = array();
 						break;
 					case 'columns':
 					case 'rows':
@@ -468,7 +564,7 @@
 						{
 							return 'place widgets in <row> and not in <column> !!!';
 						}
-						$etempl->data[0][$etempl->num2chrs($etempl->cols++)] = $attr['width'] .
+						$parent['data'][0][$etempl->num2chrs($parent['cols']++)] = $attr['width'] .
 							($attr['disabled'] ? ','.$attr['disabled'] : '');
 						break;
 					case 'row':
@@ -476,10 +572,9 @@
 						{
 							break;
 						}
-						$r = ++$etempl->rows;
-						$col = 0;
-						$etempl->data[0]["c$r"] = $attr['class'] . ($attr['valign'] ? ','.$attr['valign'] : '');
-						$etempl->data[0]["h$r"] = $attr['height'] .
+						$nul = null; soetemplate::add_child($parent,$nul);	// null =& new row
+						$parent['data'][0]['c'.$parent['rows']] = $attr['class'] . ($attr['valign'] ? ','.$attr['valign'] : '');
+						$parent['data'][0]['h'.$parent['rows']] = $attr['height'] .
 							($attr['disabled'] ? ','.$attr['disabled'] : '');
 						break;
 					case 'styles':
@@ -500,7 +595,7 @@
 							$tab_attr['span'] .= $tab_attr['class'] ? ','.$tab_attr['class'] : '';
 							unset($tab_attr['class']);
 							
-							$this->add_cell($etempl,$tab_attr,$box,$col,$node['level']);
+							soetemplate::add_child($parent,$tab_attr);
 							unset($tab_attr);
 						}
 						break;
@@ -529,28 +624,42 @@
 						}
 						else
 						{
-							$this->add_cell($etempl,$menulist_attr,$box,$col,$node['level']);
+							soetemplate::add_child($parent,$menulist_attr);
 							unset($menulist_attr);
 						}
 						break; 
 					case 'vbox':
 					case 'hbox':
-						if ($type == 'open')
+					case 'deck':
+					case 'groupbox':
+					case 'box':
+						if ($type != 'close')	// open or complete
 						{
-							$box[$node['level']] = $attr;
+							$attr['size'] = '0'.($attr['orient'] || $attr['size'] ? ','.$attr['orient'].
+								($attr['size'] ? ','.$attr['size'] : '') : '');
+							soetemplate::add_child($parent,$attr);
+							$parents[count($parents)] = &$parent;	// $parents[] does not always the same - strange
+							$parent = &$attr;
+							unset($attr);
 						}
-						else
+						if ($type != 'open')	// close or complete
 						{
-							$cell = &$box[$node['level']];
-							$cell['size'] = $cell['anz'] . ($cell['size'] != '' ? ','.$cell['size'] : '');
-							unset($cell['anz']);
-							$this->add_cell($etempl,$cell,$box,$col,$node['level']);
-							unset($box[$node['level']]);
+							// poping the last used parent from the end of the parents array (array_pop does not work with references)
+							$parent = &$parents[count($parents)-1];
+							unset($parents[count($parents)-1]);
 						}
 						break;
+					case 'caption':	// caption of (group)box
+						if ($parent['type'] == 'groupbox')
+						{
+							$parent['label'] = $attr['label'];
+						}
+						break;
+					// the following labels create automaticaly a child-entry in their parent
 					case 'textbox':
 						if ($attr['multiline'])
 						{
+							unset($attr['multiline']);
 							$attr['type'] = 'textarea';
 							$attr['size'] = $attr['rows'] . ($attr['cols'] ? ','.$attr['cols'] : '');
 							unset($attr['cols']);
@@ -603,18 +712,17 @@
 						{
 							break;
 						}
-						$this->add_cell($etempl,$attr,$box,$col,$node['level']);
+						soetemplate::add_child($parent,$attr);
+						unset($attr);
 						break;
 				}
+				if ($this->debug)
+				{
+					echo "<b>parent</b><pre>".print_r($parent,true)."</pre>";
+					echo "<b>parents</b><pre>".print_r($parents,true)."</pre>";
+					echo "<b>children</b><pre>".print_r($etempl->children,true)."</pre>";
+				}
 			}
-			if ($this->debug)
-			{
-				_debug_array($etempl->data);
-			}
-			$imported[] = $etempl->name;
-
 			return $imported;
 		}
 	}
-
-?>
