@@ -10,13 +10,15 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.5 2004/01/27 16:58:15 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp'	=> 'etemplate',
-		'noheader'		=> True,
-		'nonavbar'		=> True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp'	=> 'etemplate',
+			'noheader'		=> True,
+			'nonavbar'		=> True,
+		),
 	);
 	include('../header.inc.php');
 
-	$GLOBALS['phpgw']->redirect_link('/index.php','menuaction=etemplate.editor.edit');
+	$GLOBALS['egw']->redirect_link('/index.php','menuaction=etemplate.editor.edit');
