@@ -10,14 +10,16 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: process_exec.php,v 1.5 2004/01/27 16:58:15 reinerj Exp $ */
+	/* $Id: process_exec.php 20295 2006-02-15 12:31:25Z  $ */
 
 	list($app) = explode('.',$_GET['menuaction']);
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp'	=> $app,
-		'noheader'		=> True,
-		'nonavbar'		=> True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp'	=> $app,
+			'noheader'		=> True,
+			'nonavbar'		=> True,
+		),
 	);
 	include('../header.inc.php');
 
