@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bocompose.inc.php 19571 2005-11-03 09:17:37Z lkneschke $ */
+	/* $Id: class.bocompose.inc.php 23186 2007-01-03 08:01:43Z ralfbecker $ */
 
 	class bocompose
 	{
@@ -294,7 +294,7 @@
 			#_debug_array($bodyParts);
 			for($i=0; $i<count($bodyParts); $i++)
 			{
-				if(!empty($this->sessionData['body'])) $$this->sessionData['body'] .= "\n\n";
+				if(!empty($this->sessionData['body'])) $this->sessionData['body'] .= "\n\n";
 				// add line breaks to $bodyParts
 				$newBody	= $this->botranslation->convert($bodyParts[$i]['body'], $bodyParts[$i]['charSet']);
 				#print "<pre>".$newBody."</pre><hr>";
