@@ -1,9 +1,9 @@
 <?php
 	/***************************************************************************\
-	* phpGroupWare - FeLaMiMail                                                 *
+	* eGroupWare - FeLaMiMail                                                   *
 	* http://www.linux-at-work.de                                               *
 	* http://www.phpgw.de                                                       *
-	* http://www.phpgroupware.org                                               *
+	* http://www.egroupware.org                                                 *
 	* Written by : Lars Kneschke [lkneschke@linux-at-work.de]                   *
 	* -------------------------------------------------                         *
 	* This program is free software; you can redistribute it and/or modify it   *
@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.uisieve.inc.php,v 1.11.2.1 2004/07/31 15:48:53 lkneschke Exp $ */
+	/* $Id: class.uisieve.inc.php 20054 2005-11-30 08:29:45Z ralfbecker $ */
 
 	class uisieve
 	{
@@ -29,23 +29,21 @@
 			'listScripts'		=> True,
 			'updateRules'		=> True,
 			'updateVacation'	=> True,
-			'saveVacation'		=> True
+			'saveVacation'		=> True,
+			'selectFolder'		=> True,
 		);
 
 		function uisieve()
 		{
-			$this->displayCharset	= $GLOBALS['phpgw']->translation->charset();
+			$this->displayCharset	= $GLOBALS['egw']->translation->charset();
 
-			$this->t 		= CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
+			$this->t 		=& CreateObject('phpgwapi.Template',EGW_APP_TPL);
+ 			$this->botranslation	=& CreateObject('phpgwapi.translation');
 
-			$this->bopreferences    = CreateObject('felamimail.bopreferences');
+			$this->bopreferences    =& CreateObject('felamimail.bopreferences');
 			$this->mailPreferences  = $this->bopreferences->getPreferences();
 			
-			#$this->bopreferences	= CreateObject('felamimail.bopreferences');
-			#$this->mailPreferences	= $this->bopreferences->getPreferences();
-
-			
-			$config 		= CreateObject('phpgwapi.config','felamimail');
+			$config 		=& CreateObject('phpgwapi.config','felamimail');
 			$config->read_repository();
 			$this->felamimailConfig	= $config->config_data;
 			unset($config);
@@ -56,14 +54,14 @@
 			$sievePort		= $this->mailPreferences["imapSievePort"];
 			$username		= $this->mailPreferences['username'];
 			$password		= $this->mailPreferences['key'];
-			$this->sieve		= CreateObject('felamimail.SieveSession',$sieveHost, $sievePort, $username, $password);
+			$this->sieve		=& CreateObject('felamimail.SieveSession',$sieveHost, $sievePort, $username, $password);
 			if(!$this->sieve->start())
 			{
-				print "bad thing!!<br>";
+				print "bad thing: ".$this->sieve->errstr."!!<br>";
 			}
 			
-			$this->rowColor[0] = $GLOBALS['phpgw_info']["theme"]["bg01"];
-			$this->rowColor[1] = $GLOBALS['phpgw_info']["theme"]["bg02"];
+			$this->rowColor[0] = $GLOBALS['egw_info']["theme"]["bg01"];
+			$this->rowColor[1] = $GLOBALS['egw_info']["theme"]["bg02"];
 
 		}
 		
@@ -71,8 +69,20 @@
 		{
 			if($scriptName = get_var('newScriptName',Array('POST')))
 			{
-				$script	= CreateObject('felamimail.Script',$scriptName);
+				$script	=& CreateObject('felamimail.Script',$scriptName);
 				$script->updateScript($this->sieve);
+
+				// always activate and then edit the first script added
+				if ($this->sieve->listscripts() && count($this->sieve->scriptlist) == 1)
+				{
+					if ($this->sieve->activatescript($scriptName))
+					{
+						$GLOBALS['egw']->redirect_link('/index.php',array(
+							'menuaction' => 'felamimail.uisieve.editScript',
+							'scriptname' => $scriptName,
+						));
+					}
+				}
 			}
 			
 			$this->listScripts();
@@ -93,7 +103,7 @@
 					/* we could display the full output here */
 				}
 			}
-                    
+										
 			$this->listScripts();
 		}
 		
@@ -225,6 +235,7 @@
 			}
 		}
 
+		// RalfBecker: that does obviously nothing
 		function deactivateScript()
 		{
 			$scriptName = get_var('scriptname',array('GET'));
@@ -240,7 +251,7 @@
 				#	/* we could display the full output here */
 				#}
 			}
-                    
+										
 			$this->listScripts();
 		}
 		
@@ -277,32 +288,26 @@
 
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['phpgw']->js))
-			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
-			}
 			if(preg_match('/^(vacation|filter)$/',get_var('editmode',array('GET'))))
 				$editMode	= get_var('editmode',array('GET'));
 			else
 				$editMode	= 'filter';
 
-			$GLOBALS['phpgw']->js->validate_file('tabs','tabs');
-#			switch($_GET['menuaction'])
-#			{
-#				case 'felamimail.uisieve.editScript':
-#				case 'felamimail.uisieve.editRule':
-#				case 'felamimail.uisieve.updateRules':
-					$GLOBALS['phpgw']->js->validate_file('jscode','editProfile','felamimail');
-					$GLOBALS['phpgw']->js->set_onload("javascript:initAll('$editMode');");
-#					
-#					break;
-#			}
-			$GLOBALS['phpgw']->common->phpgw_header();
+			if(!@is_object($GLOBALS['egw']->js))
+			{
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
+			}
+			$GLOBALS['egw']->js->validate_file('tabs','tabs');
+			$GLOBALS['egw']->js->validate_file('jscode','editProfile','felamimail');
+			$GLOBALS['egw']->js->set_onload("javascript:initAll('$editMode');");
+			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 		}
 		
 		function displayRule($_scriptName, $_ruleID, $_ruleData)
 		{
+			#_debug_array($_ruleData);
 			// display the header
 			$this->display_app_header();
 
@@ -316,52 +321,59 @@
 				'menuaction'	=> 'felamimail.uisieve.editRule',
 				'scriptname'	=> $_scriptName
 			);
-			$this->t->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('action_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			$linkData = array
 			(
 				'menuaction'	=> 'felamimail.uisieve.editScript',
 				'scriptname'	=> $_scriptName
 			);
-			$this->t->set_var('url_back',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('url_back',$GLOBALS['egw']->link('/index.php',$linkData));
+
+			$linkData = array
+			(
+				'menuaction'	=> 'felamimail.uisieve.selectFolder',
+				'scriptname'	=> $_scriptName
+			);
+			$this->t->set_var('folder_select_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			
 			if(is_array($_ruleData))
 			{
-			if($_ruleData['continue']) 
-				$this->t->set_var('continue_checked','checked');
-			if($_ruleData['keep']) 
-				$this->t->set_var('keep_checked','checked');
-			if($_ruleData['regexp']) 
-				$this->t->set_var('regexp_checked','checked');
-			$this->t->set_var('anyof_selected'.intval($_ruleData['anyof']),'selected');
-			$this->t->set_var('value_from',$_ruleData['from']);
-			$this->t->set_var('value_to',$_ruleData['to']);
-			$this->t->set_var('value_subject',$_ruleData['subject']);
-			$this->t->set_var('gthan_selected'.intval($_ruleData['gthan']),'selected');
-			$this->t->set_var('value_size',$_ruleData['size']);
-			$this->t->set_var('value_field',$_ruleData['field']);
-			$this->t->set_var('value_field_val',$_ruleData['field_val']);
-			$this->t->set_var('checked_action_'.$_ruleData['action'],'checked');
-			$this->t->set_var('value_'.$_ruleData['action'],$_ruleData['action_arg']);
+				if($_ruleData['continue']) 
+					$this->t->set_var('continue_checked','checked');
+				if($_ruleData['keep']) 
+					$this->t->set_var('keep_checked','checked');
+				if($_ruleData['regexp']) 
+					$this->t->set_var('regexp_checked','checked');
+				$this->t->set_var('anyof_selected'.intval($_ruleData['anyof']),'selected');
+				$this->t->set_var('value_from',$_ruleData['from']);
+				$this->t->set_var('value_to',$_ruleData['to']);
+				$this->t->set_var('value_subject',$_ruleData['subject']);
+				$this->t->set_var('gthan_selected'.intval($_ruleData['gthan']),'selected');
+				$this->t->set_var('value_size',$_ruleData['size']);
+				$this->t->set_var('value_field',$_ruleData['field']);
+				$this->t->set_var('value_field_val',$_ruleData['field_val']);
+				$this->t->set_var('checked_action_'.$_ruleData['action'],'checked');
+				$this->t->set_var('value_'.$_ruleData['action'],$_ruleData['action_arg']);
+				if($_ruleData['action'] == 'folder')
+				{
+					$this->t->set_var('folderName',$_ruleData['action_arg']);
+				}
 			}
 			$this->t->set_var('value_ruleID',$_ruleID);
 			
-			$bofelamimail		= CreateObject('felamimail.bofelamimail',$this->displayCharset);
-			$connectionStatus	= $bofelamimail->openConnection();
-			$folders = $bofelamimail->getFolderList(false);
-			#if($connectionStatus == 'True')
-			#{
-			#	$this->bofelamimail->closeConnection();
-			#}
+			#$bofelamimail		=& CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			#$uiwidgets		=& CreateObject('felamimail.uiwidgets');
+			#$connectionStatus	= $bofelamimail->openConnection();
+			#$folders = $bofelamimail->getFolderObjects(false);
 			
-			#_debug_array($folders);
-			foreach($folders as $folderName => $folderDisplayName)
-			{
-				$this->t->set_var('folderName',$folderName);
-				$this->t->set_var('folderDisplayName',$folderDisplayName);
-				$this->t->parse("folder_rows", 'folder', true); 
-			}
+			#foreach($folders as $folderName => $folderDisplayName)
+			#{
+			#	$this->t->set_var('folderName',$folderName);
+			#	$this->t->set_var('folderDisplayName',$folderDisplayName);
+			#	$this->t->parse("folder_rows", 'folder', true); 
+			#}
 			
 			// translate most of the parts
 			$this->translate();
@@ -398,6 +410,13 @@
 				$newRule[regexp]	= get_var('regexp',array('POST'));
 				$newRule[unconditional]	= '0';		// what's this???
 				
+				$newRule[flg] = 0 ;
+				if( $newRule['continue'] ) { $newRule[flg] += 1; }
+				if( $newRule['gthan'] )    { $newRule[flg] += 2; }
+				if( $newRule['anyof'] )    { $newRule[flg] += 4; }
+				if( $newRule['keep'] )     { $newRule[flg] += 8; }
+				if( $newRule['regexp'] )   { $newRule[flg] += 128; }
+				
 				switch(get_var('action',array('POST')))
 				{
 					case 'reject':
@@ -419,7 +438,7 @@
 						$newRule[action]	= 'discard';
 						break;
 				}
-				
+
 				if($newRule[action])
 				{
 					$this->rules[$ruleID] = $newRule;
@@ -460,13 +479,13 @@
 				else
 				{
 					$this->listScripts();
-					$GLOBALS['phpgw']->common->phpgw_exit();
+					$GLOBALS['egw']->common->egw_exit();
 				}
 			}
 
-			$uiwidgets	= CreateObject('felamimail.uiwidgets',PHPGW_APP_TPL);
-			$script		= CreateObject('felamimail.Script',$scriptName);
-			$boemailadmin	= CreateObject('emailadmin.bo');
+			$uiwidgets	=& CreateObject('felamimail.uiwidgets',EGW_APP_TPL);
+			$script		=& CreateObject('felamimail.Script',$scriptName);
+			$boemailadmin	=& CreateObject('emailadmin.bo');
 			
 
 			if($this->sieve->getscript($scriptName))
@@ -474,7 +493,8 @@
 				$this->scriptToEdit 	= $scriptName;
 				if (!$script->retrieveRules($this->sieve))
 				{
-					print "can't receive script<br>";
+					//print "can't receive script<br>";
+					$this->rules = $this->vacations = array();
 				}
 				else
 				{
@@ -487,10 +507,10 @@
 				#print "Unable to change active script!<br>";
 				/* we could display the full output here */
 				$this->listScripts();
-				$GLOBALS['phpgw']->common->phpgw_exit();
+				$GLOBALS['egw']->common->egw_exit();
 			}
 
-                    	$this->saveSessionData();
+											$this->saveSessionData();
 
 			// display the header
 			$this->display_app_header();
@@ -511,7 +531,7 @@
 				);
 				foreach ($listOfImages as $image)
 				{
-					$this->t->set_var('url_'.$image,$GLOBALS['phpgw']->common->image('felamimail',$image));
+					$this->t->set_var('url_'.$image,$GLOBALS['egw']->common->image('felamimail',$image));
 				}
 			
 				$linkData = array
@@ -520,7 +540,7 @@
 					'scriptname'	=> $scriptName,
 					'ruletype'	=> 'filter'
 				);
-				$this->t->set_var('url_add_rule',$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$this->t->set_var('url_add_rule',$GLOBALS['egw']->link('/index.php',$linkData));
 
 				$linkData = array
 				(
@@ -528,7 +548,7 @@
 					'scriptname'	=> $scriptName,
 					'ruletype'	=> 'vacation'
 				);
-				$this->t->set_var('url_add_vacation_rule',$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$this->t->set_var('url_add_vacation_rule',$GLOBALS['egw']->link('/index.php',$linkData));
 
 				foreach ($this->rules as $ruleID => $rule)
 				{
@@ -542,7 +562,7 @@
 						$this->t->set_var('ruleCSS','sieveRowInActive');
 					}
 					
-					$this->t->set_var('filter_text',$this->buildRule($rule));
+					$this->t->set_var('filter_text',htmlspecialchars($this->buildRule($rule),ENT_QUOTES,$GLOBALS['egw']->translation->charset()));
 					$this->t->set_var('ruleID',$ruleID);
 
 					$linkData = array
@@ -551,7 +571,7 @@
 						'ruleID'	=> $ruleID,
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('url_edit_rule',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('url_edit_rule',$GLOBALS['egw']->link('/index.php',$linkData));
 
 					$linkData = array
 					(
@@ -559,7 +579,7 @@
 						'ruleID'	=> $ruleID,
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('url_increase',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('url_increase',$GLOBALS['egw']->link('/index.php',$linkData));
 
 					$linkData = array
 					(
@@ -567,14 +587,14 @@
 						'ruleID'	=> $ruleID,
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('url_decrease',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('url_decrease',$GLOBALS['egw']->link('/index.php',$linkData));
 					
 					$linkData = array
 					(
 						'menuaction'	=> 'felamimail.uisieve.updateRules',
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('action_rulelist',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('action_rulelist',$GLOBALS['egw']->link('/index.php',$linkData));
 
 					$this->t->parse('filterrows','filterrow',true);
 				}
@@ -598,7 +618,7 @@
 				}
 				
 				// vacation text
-				$this->t->set_var('vacation_text',$this->vacation['text']);
+				$this->t->set_var('vacation_text',$this->botranslation->convert($this->vacation['text'],'UTF-8'));
 				
 				//vacation days
 				$this->t->set_var('selected_'.$this->vacation['days'],'selected="selected"');
@@ -614,7 +634,7 @@
 				}
 
 				// all local addresses
-				if($emailAddresses = $boemailadmin->getAccountEmailAddress($GLOBALS['phpgw_info']['user']['userid'], $this->felamimailConfig['profileID']))
+				if($emailAddresses = $boemailadmin->getAccountEmailAddress($GLOBALS['egw_info']['user']['userid'], $this->felamimailConfig['profileID']))
 				{
 					foreach($emailAddresses as $addressData)
 					{
@@ -637,27 +657,27 @@
 					'editmode'	=> 'vacation',
 					'scriptname'	=> $scriptName
 				);
-				$this->t->set_var('vacation_action_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$this->t->set_var('vacation_action_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			}
 
-	                $linkData = array
-	                (
-	                        'menuaction'    => 'felamimail.uisieve.saveScript'
-	                );
-			$this->t->set_var('formAction',$GLOBALS['phpgw']->link('/index.php',$linkData));
-	                $linkData = array
-	                (
-	                        'menuaction'    => 'felamimail.uisieve.mainScreen'
-	                );
-			$this->t->set_var('link_newScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
+									$linkData = array
+									(
+													'menuaction'    => 'felamimail.uisieve.saveScript'
+									);
+			$this->t->set_var('formAction',$GLOBALS['egw']->link('/index.php',$linkData));
+									$linkData = array
+									(
+													'menuaction'    => 'felamimail.uisieve.mainScreen'
+									);
+			$this->t->set_var('link_newScript',$GLOBALS['egw']->link('/index.php',$linkData));
 			
 			$linkData = array
 			(
 				'menuaction'	=> 'felamimail.uisieve.listScripts',
 				'scriptname'	=> $scriptName
 			);
-			$this->t->set_var('url_back',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('url_back',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			$this->t->pfp("out","header");
 			
@@ -696,7 +716,7 @@
 			(
 				'menuaction'	=> 'felamimail.uisieve.addScript'
 			);
-			$this->t->set_var('action_add_script',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('action_add_script',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			if($this->sieve->listscripts())
 			{
@@ -710,14 +730,14 @@
 						'menuaction'	=> 'felamimail.uisieve.deleteScript',
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('link_deleteScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('link_deleteScript',$GLOBALS['egw']->link('/index.php',$linkData));
 					
 					$linkData = array
 					(
 						'menuaction'	=> 'felamimail.uisieve.editScript',
 						'scriptname'	=> $scriptName
 					);
-					$this->t->set_var('link_editScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('link_editScript',$GLOBALS['egw']->link('/index.php',$linkData));
 					
 					if($this->sieve->activescript == $scriptName)
 					{
@@ -726,7 +746,9 @@
 							'menuaction'	=> 'felamimail.uisieve.deactivateScript',
 							'scriptname'	=> $scriptName
 						);
-						$this->t->set_var('lang_activate',lang('deactivate script'));
+						// show only active label and no (not working/existing) deactivate link
+						$this->t->set_var('lang_activate',''/*lang('deactivate script')*/);
+						$this->t->set_var('active',lang('active'));
 						$this->t->set_var('ruleCSS','sieveRowActive');
 					}
 					else
@@ -737,9 +759,10 @@
 							'scriptname'	=> $scriptName
 						);
 						$this->t->set_var('lang_activate',lang('activate script'));
+						$this->t->set_var('active','');
 						$this->t->set_var('ruleCSS','sieveRowInActive');
 					}
-					$this->t->set_var('link_activateScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var('link_activateScript',$GLOBALS['egw']->link('/index.php',$linkData));
 
 					$this->t->parse('scriptrows','scriptrow',true);
 				}
@@ -754,166 +777,43 @@
 			$this->sieve->close();
 		}
 		
-/*		function mainScreen()
-		{
-			// display the header
-			$this->display_app_header();
-			
-			// initialize the template
-			$this->t->set_file(array("filterForm" => "sieveForm.tpl"));
-			$this->t->set_block('filterForm','header');
-			$this->t->set_block('filterForm','scriptrow');
-			$this->t->set_block('filterForm','filterrow');
-			
-			// translate most of the parts
-			$this->translate();
-			
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uisieve.addScript'
-			);
-			$this->t->set_var('action_add_script',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-			if($this->sieve->listscripts())
-			{
-				foreach($this->sieve->scriptlist as $scriptID => $scriptName)
-				{
-					$this->t->set_var("scriptnumber",$scriptID);
-					$this->t->set_var("scriptname",$scriptName);
-
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.deleteScript',
-						'scriptname'	=> $scriptName
-					);
-					$this->t->set_var('link_deleteScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.editScript',
-						'scriptname'	=> $scriptName
-					);
-					$this->t->set_var('link_editScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
-					if($this->sieve->activescript == $scriptName)
-					{
-						$linkData = array
-						(
-							'menuaction'	=> 'felamimail.uisieve.deactivateScript',
-							'scriptname'	=> $scriptName
-						);
-						$this->t->set_var('lang_activate',lang('deactivate script'));
-					}
-					else
-					{
-						$linkData = array
-						(
-							'menuaction'	=> 'felamimail.uisieve.activateScript',
-							'scriptname'	=> $scriptName
-						);
-						$this->t->set_var('lang_activate',lang('activate script'));
-					}
-					$this->t->set_var('link_activateScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-					$this->t->parse('scriptrows','scriptrow',true);
-				}
-			}
-			else
-			{
-				$this->t->set_var("scriptrows",'');
-			}
-			if(!empty($this->scriptToEdit))
-			{
-				#$this->t->set_var("editScriptName",$this->scriptToEdit);
-				#$this->t->set_var("scriptContent",$this->scriptContent);
-				$listOfImages = array(
-					'up',
-					'down'
-				);
-				foreach ($listOfImages as $image)
-				{
-					$this->t->set_var('url_'.$image,$GLOBALS['phpgw']->common->image('felamimail',$image));
-				}
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uisieve.editRule'
-				);
-				$this->t->set_var('url_add_rule',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-				foreach ($this->rules as $ruleID => $rule)
-				{
-					$this->t->set_var('filter_status',lang($rule[status]));
-					if($rule[status] == 'ENABLED')
-					{
-						$this->t->set_var('ruleCSS','sieveRowActive');
-					}
-					else
-					{
-						$this->t->set_var('ruleCSS','sieveRowInActive');
-					}
-					
-					$this->t->set_var('filter_text',$this->buildRule($rule));
-					$this->t->set_var('ruleID',$ruleID);
-
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.editRule',
-						'ruleID'	=> $ruleID
-					);
-					$this->t->set_var('url_edit_rule',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.increaseFilter',
-						'ruleID'	=> $ruleID
-					);
-					$this->t->set_var('url_increase',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.decreaseFilter',
-						'ruleID'	=> $ruleID
-					);
-					$this->t->set_var('url_decrease',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uisieve.updateRules'
-					);
-					$this->t->set_var('action_rulelist',$GLOBALS['phpgw']->link('/index.php',$linkData));
-
-					$this->t->parse('filterrows','filterrow',true);
-				}
-			}
-			else
-			{
-				$this->t->set_var("editScriptName",'');
-				$this->t->set_var("scriptContent",'');
-			}
-	                $linkData = array
-	                (
-	                        'menuaction'    => 'felamimail.uisieve.saveScript'
-	                );
-			$this->t->set_var('formAction',$GLOBALS['phpgw']->link('/index.php',$linkData));
-	                $linkData = array
-	                (
-	                        'menuaction'    => 'felamimail.uisieve.mainScreen'
-	                );
-			$this->t->set_var('link_newScript',$GLOBALS['phpgw']->link('/index.php',$linkData));
-			
-			$this->t->pfp("out","header");
-			
-			$this->sieve->close();
-		}
-*/		
 		function restoreSessionData()
 		{
-			$sessionData = $GLOBALS['phpgw']->session->appsession('sieve_session_data');
+			$sessionData = $GLOBALS['egw']->session->appsession('sieve_session_data');
 			
 			$this->rules		= $sessionData['sieve_rules'];
 			$this->scriptToEdit	= $sessionData['sieve_scriptToEdit'];
 		}
 		
+		function selectFolder()
+		{
+			if(!@is_object($GLOBALS['egw']->js))
+			{
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
+			}
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');                        
+			$GLOBALS['egw']->js->validate_file('jscode','editSieveRule','felamimail');
+			$GLOBALS['egw']->common->egw_header();
+
+			$bofelamimail		=& CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			$uiwidgets		=& CreateObject('felamimail.uiwidgets');
+			$connectionStatus	= $bofelamimail->openConnection();
+
+			$folderObjects = $bofelamimail->getFolderObjects(false);
+			$folderTree = $uiwidgets->createHTMLFolder
+			(
+				$folderObjects,
+				'INBOX',
+				lang('IMAP Server'),
+				$mailPreferences['username'].'@'.$mailPreferences['imapServerAddress'],
+				'divFolderTree',
+				false
+			);
+			print '<div id="divFolderTree" style="overflow:auto; width:375px; height:474px; margin-bottom: 0px;padding-left: 0px; padding-top:0px; z-index:100; border : 1px solid Silver;"></div>';
+			print $folderTree;
+		}
+
 		function setMatchType (&$matchstr, $regex = false)
 		{
 			$match = lang('contains');
@@ -973,7 +873,7 @@
 			$sessionData['sieve_rules']		= $this->rules;
 			$sessionData['sieve_scriptToEdit']	= $this->scriptToEdit;
 			
-			$GLOBALS['phpgw']->session->appsession('sieve_session_data','',$sessionData);
+			$GLOBALS['egw']->session->appsession('sieve_session_data','',$sessionData);
 		}
 		
 		function translate()
@@ -1007,10 +907,29 @@
 			$this->t->set_var("lang_script_name",lang('script name'));
 			$this->t->set_var("lang_script_status",lang('script status'));
 			$this->t->set_var("lang_delete_script",lang('delete script'));
+			$this->t->set_var("lang_check_message_against_next_rule_also",lang('check message against next rule also'));
+			$this->t->set_var("lang_keep_a_copy_of_the_message_in_your_inbox",lang('keep a copy of the message in your inbox'));
+			$this->t->set_var("lang_use_regular_expressions",lang('use regular expressions'));
+			$this->t->set_var("lang_match",lang('match'));
+			$this->t->set_var("lang_all_of",lang('all of'));
+			$this->t->set_var("lang_any_of",lang('any of'));
+			$this->t->set_var("lang_if_from_contains",lang('if from contains'));
+			$this->t->set_var("lang_if_to_contains",lang('if to contains'));
+			$this->t->set_var("lang_if_subject_contains",lang('if subject contains'));
+			$this->t->set_var("lang_if_message_size",lang('if message size'));
+			$this->t->set_var("lang_less_than",lang('less than'));
+			$this->t->set_var("lang_greater_than",lang('greater than'));
+			$this->t->set_var("lang_kilobytes",lang('kilobytes'));
+			$this->t->set_var("lang_if_mail_header",lang('if mail header'));
+			$this->t->set_var("lang_file_into",lang('file into'));
+			$this->t->set_var("lang_forward_to_address",lang('forward to address'));
+			$this->t->set_var("lang_send_reject_message",lang('send a reject message'));
+			$this->t->set_var("lang_discard_message",lang('discard message'));
+			$this->t->set_var("lang_select_folder",lang('select folder'));
 
-			$this->t->set_var("bg01",$GLOBALS['phpgw_info']["theme"]["bg01"]);
-			$this->t->set_var("bg02",$GLOBALS['phpgw_info']["theme"]["bg02"]);
-			$this->t->set_var("bg03",$GLOBALS['phpgw_info']["theme"]["bg03"]);
+			$this->t->set_var("bg01",$GLOBALS['egw_info']["theme"]["bg01"]);
+			$this->t->set_var("bg02",$GLOBALS['egw_info']["theme"]["bg02"]);
+			$this->t->set_var("bg03",$GLOBALS['egw_info']["theme"]["bg03"]);
 		}
 		
 		function updateRules()
@@ -1063,7 +982,7 @@
 		function updateScript()
 		{
 			$scriptName		= $this->scriptToEdit;
-			$script			= CreateObject('felamimail.Script',$this->scriptToEdit);
+			$script			=& CreateObject('felamimail.Script',$this->scriptToEdit);
 
 			if(!empty($scriptName))
 			{
@@ -1082,7 +1001,7 @@
 					#print "Unable to change active script!<br>";
 					/* we could display the full output here */
 					$this->listScripts();
-					$GLOBALS['phpgw']->common->phpgw_exit();
+					$GLOBALS['egw']->common->egw_exit();
 				}
 			}
 
@@ -1099,7 +1018,7 @@
 			#phpinfo();exit;
 
 			$scriptName = get_var('scriptname',array('GET'));
- 			$script = CreateObject('felamimail.Script',$scriptName);
+ 			$script =& CreateObject('felamimail.Script',$scriptName);
 
 			if(!empty($scriptName))
 			{
@@ -1118,7 +1037,7 @@
 					#print "Unable to change active script!<br>";
 					/* we could display the full output here */
 					$this->listScripts();
-					$GLOBALS['phpgw']->common->phpgw_exit();
+					$GLOBALS['egw']->common->egw_exit();
 				}
 			}
 
@@ -1126,10 +1045,12 @@
 			{
 				case 'enable':
 				case 'save':
+				case 'disable':
 					$vacation['text']	= get_var('vacation_text',array('POST'));
+					$vacation['text']	= $this->botranslation->convert($vacation['text'],$this->displayCharset,'UTF-8');
 					$vacation['days']	= get_var('days',array('POST'));
 					$vacation['addresses']	= get_var('vacationAddresses',array('POST'));
-					$vacation['status']	= 'on';
+					$vacation['status']	= get_var('vacationRule_action',array('POST')) == 'disable' ? 'off' : 'on';
 					if($this->checkRule($vacation))
 					{
 						$script->vacation	= $vacation;
@@ -1141,22 +1062,6 @@
 					}
 					break;
 				
-				case 'disable':
-					$vacation['text']	= get_var('vacation_text',array('POST'));
-					$vacation['days']	= get_var('days',array('POST'));
-					$vacation['addresses']	= get_var('vacationAddresses',array('POST'));
-					$vacation['status']	= 'off';
-					$script->vacation	= $vacation;
-					if($this->checkRule($vacation))
-					{
-						if (!$script->updateScript($this->sieve)) 
-						{
-							print "update failed<br>";
-							print $script->errstr."<br>";
-						}
-					}
-					break;
-				
 				case 'delete':
 					$script->vacation	= array();
 					if (!$script->updateScript($this->sieve)) 
