@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uifilemanager.inc.php 19410 2005-10-14 10:41:15Z ralfbecker $ */
+	/* $Id: class.uifilemanager.inc.php 22445 2006-09-16 22:12:24Z omgs $ */
 
 	class uifilemanager
 	{
@@ -84,6 +84,8 @@
 		{
 			//			error_reporting(8);
 			$GLOBALS['egw']->browser =& CreateObject('phpgwapi.browser');
+			
+			$this->dateformat=$GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
 
 			$this->now = date('Y-m-d');
 
@@ -723,7 +725,7 @@
 					# Date created
 					if($this->prefs['created'])
 					{
-						$col_data=$files['created'];
+						$col_data=date($this->dateformat,strtotime($files['created']));
 						$this->t->set_var('col_data',$col_data);
 						$this->t->parse('columns','column',True);
 					}
@@ -733,7 +735,7 @@
 					{
 						if($files['modified'] != '0000-00-00')
 						{
-							$col_data=$files['modified'];
+							$col_data=date($this->dateformat,strtotime($files['modified']));
 						}
 						else
 						{
