@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.soinfolog.inc.php 21625 2006-05-22 22:04:36Z ralfbecker $ */
+	/* $Id: class.soinfolog.inc.php 22913 2006-12-08 07:13:36Z ralfbecker $ */
 
 	include_once(EGW_API_INC.'/class.solink.inc.php');
 
@@ -385,9 +385,9 @@
 			//echo "soinfolog::write(,$check_modified) values="; _debug_array($values);
 			$info_id = (int) $values['info_id'];
 
-			if (isset($values['info_responsible']))
+			if (array_key_exists('info_responsible',$values))	// isset($values['info_responsible']) returns false for NULL!
 			{
-				$values['info_responsible'] = count($values['info_responsible']) ? implode(',',$values['info_responsible']) : '0';
+				$values['info_responsible'] = $values['info_responsible'] ? implode(',',$values['info_responsible']) : '0';
 			}
 			$table_def = $this->db->get_table_definitions('infolog',$this->info_table);
 			$to_write = array();
@@ -398,6 +398,9 @@
 					$to_write[$key] = $this->data[$key] = $val;   // update internal data
 				}
 			}
+			// writing no price as SQL NULL (required by postgres)
+			if ($to_write['info_price'] === '') $to_write['info_price'] = NULL;
+
 			if (($this->data['info_id'] = $info_id))
 			{
 				$where = array('info_id' => $info_id);
