@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiinfolog.inc.php 22848 2006-11-15 10:32:03Z ralfbecker $ */
+	/* $Id: class.uiinfolog.inc.php 23695 2007-04-26 12:53:17Z ralfbecker $ */
 
 	include_once(EGW_INCLUDE_ROOT.'/infolog/inc/class.boinfolog.inc.php');
 
@@ -378,7 +378,8 @@
 							if (!($values['msg'] = $this->delete($do_id,$called_as,$called_as ? '' : 'index'))) return;
 							break;
 						case 'close':
-							return $this->close($do_id,$called_as,$do == 'close_subs');
+							$this->close($do_id,$called_as);
+							break;
 						case 'sp':
 							return $this->edit(0,'sp',$do_id,'',$called_as);
 						case 'view':
@@ -477,7 +478,7 @@
 					}
 				}
 			}
-			return $referer ? $this->tmpl->location($referer) : $this->index();
+			if ($referer) $this->tmpl->location($referer);
 		}
 
 		function delete($values=0,$referer='',$called_by='')
