@@ -11,7 +11,7 @@
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
 	
-	/* $Id: class.uimydms.inc.php 22146 2006-07-21 07:00:04Z lkneschke $ */
+	/* $Id: class.uimydms.inc.php 22772 2006-10-29 16:57:56Z lkneschke $ */
 
 	require_once(EGW_SERVER_ROOT.'/mydms/inc/inc.Settings.php');
 	require_once(EGW_SERVER_ROOT.'/mydms/inc/inc.DBAccess.php');
@@ -70,6 +70,7 @@
 			'updateACL'		=> 'true',
 			'updateDocument'	=> 'true',
 			'updateFile'		=> 'true',
+			'setOwner'		=> 'true',
 			'viewDocument'		=> 'true',
 		);
 		
@@ -362,6 +363,7 @@
 				case 'mydms.uimydms.deleteFile':
 				case 'mydms.uimydms.deleteNotification':
 				case 'mydms.uimydms.setDefaultAccess':
+				case 'mydms.uimydms.setOwner':
 				case 'mydms.uimydms.updateACL':
 				case 'mydms.uimydms.updateFile':
 				case 'mydms.uimydms.viewDocument':
@@ -373,6 +375,7 @@
 					$GLOBALS['egw']->js->set_onload('javascript:initTabs();');
 					break;
 				case 'mydms.uimydms.folderChooser':
+					$GLOBALS['egw']->js->validate_file('jscode','mydms','mydms');
 					$GLOBALS['egw']->js->validate_file('jscode','folderChooser','mydms');
 					break;
 			}
@@ -414,6 +417,18 @@
 			}
 		}
 
+		function setOwner()
+		{
+			$documentID	= (int)$_GET['documentid'];
+			$owner		= (int)$_POST['owner'];
+
+			if($documentID && $owner)
+			{
+				$this->bomydms->setOwner($documentID, $owner);
+				$this->viewDocument($documentID);
+			}
+		}
+
 		function translate()
 		{
 			$this->t->set_var('lang_informations',lang('informations'));
@@ -809,7 +824,7 @@
 					{
 						$allUsersOptions[$userObj->getID()] = $userObj->getFullName();
 					}
-					$this->t->set_var('select_ownerid',$GLOBALS['egw']->html->select('owner',$owner->getID(),$allUsersOptions,true,"style=\"width: 300px;\" onchange=\"javascript:document.notify_form.submit();\""));
+					$this->t->set_var('select_ownerid',$GLOBALS['egw']->html->select('owner',$owner->getID(),$allUsersOptions,true,"style=\"width: 300px;\" onchange=\"javascript:document.change_owner.submit();\""));
 					
 					$this->t->parse('change_owner','block_change_owner',True);
 				}
