@@ -12,7 +12,7 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: class.bonews.inc.php 19910 2005-11-20 16:13:31Z nelius_weiss $ */
+	/* $Id: class.bonews.inc.php 22671 2006-10-18 06:15:59Z ralfbecker $ */
 
 	class bonews
 	{
@@ -349,27 +349,35 @@
 			foreach($news['mailto'] as $cat_id)
 			{
 				$filter = 'tid=n,cat_id=' . $cat_id;
-						$members = array_merge($members,$GLOBALS['egw']->contacts->read('','',$fields,'',$filter));
-					}
+				$members = array_merge($members,$GLOBALS['egw']->contacts->read('','',$fields,'',$filter));
+			}
 
 			// then, prepare to send mail
-					$mail =& CreateObject('phpgwapi.send');
+			$mail =& CreateObject('phpgwapi.send');
 
-					// build subject
-					$subject = lang('News') . ': ' . $news['subject'];
+			// build subject
+			$subject = lang('News') . ': ' . $news['subject'];
+
+			// build body
+			$body  = '';
+			$body .= lang('URL') . ": http://" . $GLOBALS['egw_info']['server']['hostname'] . "<br/>";
+			$body .= lang('Subject') . ': ' . $news['subject'] . "<br/>";
+			$body .= lang('Submitted By') . ': ' . $GLOBALS['egw']->common->grab_owner_name($news['submittedby']) . "<br/>";
+			$body .= lang('Date') . ': ' . $GLOBALS['egw']->common->show_date($news['date']) . "<br/><br/>";
+			$body .= lang('Content') . ":<br/>";
 
-					// build body
-					$body  = '';
-					$body .= lang('Subject') . ': ' . $news['subject'] . "<br/>";
-			$body .= lang('Submitted By') . $GLOBALS['egw']->common->grab_owner_name($news['submittedby']) . "<br/>";
-					$body .= lang('Date') . ': ' . $GLOBALS['egw']->common->show_date($news['date']) . "<br/><br/>";
-					$body .= lang('Content') . ":<br/>";
 			$body .= $news['content'] . "<br/><br/>";
 
+			$tempdata = explode ( "," , $GLOBALS['egw']->common->grab_owner_name($news['submittedby']));
+			$tempfromname = "";
+			foreach($tempdata as $tempname) 
+			{
+				$tempfromname .= ' ' . $tempname;
+			}
 			$mail->Subject = $subject;
 			$mail->Body = $body;
 			$mail->From = $GLOBALS['egw_info']['user']['preferences']['news_admin']['EmailFrom'];
-			$mail->FromName = $GLOBALS['egw']->common->grab_owner_name($news['submittedby']);
+			$mail->FromName = $tempfromname;
 			$replyto = $GLOBALS['egw_info']['user']['preferences']['news_admin']['EmailReplyto'];
 			$mail->AddReplyTo($replyto);
 			$mail->Sender = $replyto;   // the Return-Path
