@@ -9,10 +9,10 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: notify_simple.php,v 1.4 2003/08/28 14:12:34 ralfbecker Exp $ */
+  /* $Id: notify_simple.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$egw_info = array();
+	$GLOBALS['egw_info']['flags'] = array(
 		'noheader' => True,
 		'nonavbar' => True,
 		'disable_Template_class' => True,
@@ -21,6 +21,6 @@
 	include('./header.inc.php');
 
 	echo '<html><body>';
-	$GLOBALS['phpgw']->hooks->process('notifywindow_simple',array('email'));
+	$GLOBALS['egw']->hooks->process('notifywindow_simple',array('email'));
 	echo '</body></html>';
 ?>
