@@ -6,6 +6,7 @@
 	* shared functions for other account repository managers                   *
 	* Copyright (C) 2000 - 2002 Joseph Engo                                    *
 	* Copyright (C) 2003 Joseph Engo, Bettina Gille                            *
+	* Caching and documentation added by RalfBecker-AT-outdoor-training.de     *
 	* -------------------------------------------------------------------------*
 	* This library is part of the eGroupWare API                               *
 	* http://www.egroupware.org                                                * 
@@ -22,28 +23,29 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.accounts.inc.php,v 1.19.2.3 2004/08/25 20:04:48 lkneschke Exp $ */
 
-	if (empty($GLOBALS['phpgw_info']['server']['account_repository']))
+	/* $Id: class.accounts.inc.php 20295 2006-02-15 12:31:25Z  $ */
+
+	if (empty($GLOBALS['egw_info']['server']['account_repository']))
 	{
-		if (!empty($GLOBALS['phpgw_info']['server']['auth_type']))
+		if (!empty($GLOBALS['egw_info']['server']['auth_type']))
 		{
-			$GLOBALS['phpgw_info']['server']['account_repository'] = $GLOBALS['phpgw_info']['server']['auth_type'];
+			$GLOBALS['egw_info']['server']['account_repository'] = $GLOBALS['egw_info']['server']['auth_type'];
 		}
 		else
 		{
-			$GLOBALS['phpgw_info']['server']['account_repository'] = 'sql';
+			$GLOBALS['egw_info']['server']['account_repository'] = 'sql';
 		}
 	}
-	include_once(PHPGW_API_INC . '/class.accounts_' . $GLOBALS['phpgw_info']['server']['account_repository'] . '.inc.php');
+	include_once(EGW_API_INC . '/class.accounts_' . $GLOBALS['egw_info']['server']['account_repository'] . '.inc.php');
 
 	/*
-	  Dont know where to put this (seek3r)
-	  This is where it belongs (jengo)
-	  This is where it ended up (milosch)
-	  Moved again at least temporarily since sql and ldap use it.
+		Dont know where to put this (seek3r)
+		This is where it belongs (jengo)
+		This is where it ended up (milosch)
+		Moved again at least temporarily since sql and ldap use it.
 	*/
-	$GLOBALS['phpgw_info']['server']['global_denied_users'] = array(
+	$GLOBALS['egw_info']['server']['global_denied_users'] = array(
 		'root'     => True, 'bin'      => True, 'daemon'   => True,
 		'adm'      => True, 'lp'       => True, 'sync'     => True,
 		'shutdown' => True, 'halt'     => True, 'ldap'     => True,
@@ -62,7 +64,7 @@
 		'backup'    => True
 	);
 
-	$GLOBALS['phpgw_info']['server']['global_denied_groups'] = array(
+	$GLOBALS['egw_info']['server']['global_denied_groups'] = array(
 		'root'      => True, 'bin'       => True, 'daemon'    => True,
 		'sys'       => True, 'adm'       => True, 'tty'       => True,
 		'disk'      => True, 'lp'        => True, 'mem'       => True,
@@ -79,11 +81,12 @@
 		'ldap'      => True, 'backup'    => True
 	);
 
-	/*!
-	 @class_start accounts
-	 @abstract Class for handling user and group accounts
-	*/
-
+	/**
+	 * Class for handling user and group accounts
+	 *
+	 * The class can be instanciated for a certain account, if no account is specified the user of the session is used.
+	 * Some functions operate on that user!
+	 */
 	class accounts extends accounts_
 	{
 		var $memberships    = array();
@@ -92,17 +95,28 @@
 		// enables the session-cache
 		var $use_session_cache = True;
 
-		/**************************************************************************\
-		* Standard constructor for setting $this->account_id                       *
-		* This constructor sets the account id, if string is sent, converts to id  *
-		* I might move this to the accounts_shared if it stays around              *
-		\**************************************************************************/
+		/**
+		 * Standard constructor for setting $this->account_id
+		 *
+		 * This constructor sets the account id, if string is sent, converts to id
+		 *
+		 * @param int/string $account_id account to instanciate the class for, default user of the session
+		 * @param string $account_type type ('u' or 'g') to set $this->account_type if given
+		 */
 		function accounts($account_id = '', $account_type='')
 		{
 			// enable the caching in the session onyl for ldap
-			$this->use_session_cache = $GLOBALS['phpgw_info']['server']['account_repository'] == 'ldap';
+			$this->use_session_cache = $GLOBALS['egw_info']['server']['account_repository'] == 'ldap';
 
-			$this->db = $GLOBALS['phpgw']->db;
+			if (is_object($GLOBALS['egw_setup']->db))
+			{
+				$this->db = clone($GLOBALS['egw_setup']->db);
+			}
+			else
+			{
+				$this->db = clone($GLOBALS['egw']->db);
+			}
+			$this->db->set_app('phpgwapi');	// to load the right table-definitions for insert, select, update, ...
 
 			if($account_id != '')
 			{
@@ -140,48 +154,50 @@
 		}
 
 		/**
-		* Sets up the account-data cache
-		*
-		* The cache is shared between all instances of the account-class and it can be save in the session,
-		* if use_session_cache is set to True
-		*/
+		 * Sets up the account-data cache
+		 *
+		 * The cache is shared between all instances of the account-class and it can be save in the session,
+		 * if use_session_cache is set to True
+		 */
 		function setup_cache()
 		{
 			if ($this->use_session_cache &&		// are we supposed to use a session-cache
-				!@$GLOBALS['phpgw_info']['accounts']['session_cache_setup'] &&	// is it already setup
+				!@$GLOBALS['egw_info']['accounts']['session_cache_setup'] &&	// is it already setup
 				// is the account-class ready (startup !)
-				is_object($GLOBALS['phpgw']->session) && $GLOBALS['phpgw']->session->account_id)
+				is_object($GLOBALS['egw']->session) && $GLOBALS['egw']->session->account_id)
 			{
 				// setting up the session-cache
-				$GLOBALS['phpgw_info']['accounts']['cache'] = $GLOBALS['phpgw']->session->appsession('accounts_cache','phpgwapi');
-				$GLOBALS['phpgw_info']['accounts']['session_cache_setup'] = True;
-				//echo "accounts::setup_cache() cache=<pre>".print_r($GLOBALS['phpgw_info']['accounts']['cache'],True)."</pre>\n";
+				$GLOBALS['egw_info']['accounts']['cache'] = $GLOBALS['egw']->session->appsession('accounts_cache','phpgwapi');
+				$GLOBALS['egw_info']['accounts']['session_cache_setup'] = True;
+				//echo "accounts::setup_cache() cache=<pre>".print_r($GLOBALS['egw_info']['accounts']['cache'],True)."</pre>\n";
 			}
 			if (!isset($this->cache))
 			{
-				$this->cache = &$GLOBALS['phpgw_info']['accounts']['cache'];
+				$this->cache = &$GLOBALS['egw_info']['accounts']['cache'];
 			}
+			if (!is_array($this->cache)) $this->cache = array();
 		}
 
 		/**
-		* Saves the account-data cache in the session
-		*
-		* Gets called from common::phpgw_final()
-		*/
+		 * Saves the account-data cache in the session
+		 *
+		 * Gets called from common::phpgw_final()
+		 */
 		function save_session_cache()
 		{
 			if ($this->use_session_cache &&		// are we supposed to use a session-cache
-				$GLOBALS['phpgw_info']['accounts']['session_cache_setup'] &&	// is it already setup
+				$GLOBALS['egw_info']['accounts']['session_cache_setup'] &&	// is it already setup
 				// is the account-class ready (startup !)
-				is_object($GLOBALS['phpgw']->session))
+				is_object($GLOBALS['egw']->session))
 			{
-				$GLOBALS['phpgw']->session->appsession('accounts_cache','phpgwapi',$GLOBALS['phpgw_info']['accounts']['cache']);
+				$GLOBALS['egw']->session->appsession('accounts_cache','phpgwapi',$GLOBALS['egw_info']['accounts']['cache']);
 			}
 		}
 
 		/**
 		 * Searches / lists accounts: users and/or groups
 		 *
+		 * @param array with the following keys:
 		 * @param $param['type'] string/int 'accounts', 'groups', 'owngroups' (groups the user is a member of), 'both'
 		 *	or integer group-id for a list of members of that group
 		 * @param $param['start'] int first account to return (returns offset or max_matches entries) or all if not set
@@ -229,7 +245,7 @@
 					}
 					elseif ($param['type'] == 'owngroups')
 					{
-						$group = -1;
+						$group = true;
 						$param['type'] = 'groups';
 					}
 					$start = $param['start'];
@@ -261,13 +277,13 @@
 					}
 					if ($group)
 					{
-						$members = $group > 0 ? $GLOBALS['phpgw']->acl->get_ids_for_location($group, 1, 'phpgw_group') :
-							$GLOBALS['phpgw']->acl->get_location_list_for_id('phpgw_group', 1,$GLOBALS['phpgw_info']['user']['account_id']);
+						$members = is_int($group) ? $GLOBALS['egw']->acl->get_ids_for_location($group, 1, 'phpgw_group') :
+							$GLOBALS['egw']->acl->get_location_list_for_id('phpgw_group', 1,$GLOBALS['egw_info']['user']['account_id']);
 						if (!$members) $members = array();
 						$valid = !$app ? $members : array_intersect($valid,$members);	// use the intersection
 					}
 					//echo "<p>limiting result to app='app' and/or group=$group valid-ids=".print_r($valid,true)."</p>\n";
-					$offset = $param['offset'] ? $param['offset'] : $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+					$offset = $param['offset'] ? $param['offset'] : $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 					$stop = $start + $offset;
 					$n = 0;
 					$account_search[$serial]['data'] = array();
@@ -292,7 +308,11 @@
 			return $account_search[$serial]['data'];
 		}
 
-
+		/**
+		 * Searches / lists accounts: users and/or groups
+		 *
+		 * @deprecated use search
+		 */
 		function get_list($_type='both',$start = '',$sort = '', $order = '', $query = '', $offset = '',$query_type='')
 		{
 			//echo "<p>accounts::get_list(".print_r($_type,True).",start='$start',sort='$sort',order='$order',query='$query',offset='$offset')</p>\n";
@@ -335,6 +355,11 @@
 			return $account_list[$serial]['data'];
 		}
 
+		/**
+		 * test if the account this class is instanciated for is expired
+		 *
+		 * @return boolean true=expired (no more login possible), false otherwise
+		 */
 		function is_expired()
 		{
 			if ($this->data['expires'] != -1 && $this->data['expires'] < time())
@@ -348,31 +373,50 @@
 		}
 
 		/**
-		* Invalidate the cache (or parts of it) after change in $account_id
-		*
-		* Atm simplest approach - delete it all ;-)
-		*/
+		 * Invalidate the cache (or parts of it) after change in $account_id
+		 *
+		 * Atm simplest approach - delete it all ;-)
+		 */
 		function cache_invalidate($account_id)
 		{
 			//echo "<p>accounts::cache_invalidate($account_id)</p>\n";
-			$GLOBALS['phpgw_info']['accounts']['cache'] = array();
+			$GLOBALS['egw_info']['accounts']['cache'] = array();
+			
+			if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			{
+				$GLOBALS['egw']->invalidate_session_cache();	// invalidates whole egw-enviroment if stored in the session
+			}
 		}
 
+		/**
+		 * saves the account-data in the internal data-structure of this class to the repository
+		 */
 		function save_repository()
 		{
 			$this->cache_invalidate($this->account_id);
 			accounts_::save_repository();
 		}
 
+		/**
+		 * Deletes the account spezified by $accountid, deletes also all acl-entries for that account
+		 *
+		 * @param int $accountid numeric account-id
+		 */
 		function delete($accountid)
 		{
 			$this->cache_invalidate($accountid);
 			accounts_::delete($accountid);
 			
 			// delete all acl_entries belonging to that user or group
-			$GLOBALS['phpgw']->acl->delete_account($accountid);
+			$GLOBALS['egw']->acl->delete_account($accountid);
 		}
 
+		/**
+		 * Create a new account with the given $account_info
+		 * 
+		 * @param array data for the new account
+		 * @return int new nummeric account-id
+		 */
 		function create($account_info,$default_prefs=True)
 		{
 			$account_id = accounts_::create($account_info,$default_prefs);
@@ -381,6 +425,11 @@
 			return $account_id;
 		}
 
+		/**
+		 * Reads the data of the account this class is instanciated for
+		 *
+		 * @return array with the internal data
+		 */
 		function read_repository()
 		{
 			$this->setup_cache();
@@ -393,6 +442,13 @@
 			return $account_data[$this->account_id] = accounts_::read_repository();
 		}
 
+		/**
+		 * Return data of the account this class is instanciated for
+		 *
+		 * only calls read_repository if no data read so far
+		 *
+		 * @return array with the internal data
+		 */
 		function read()
 		{
 			if (count($this->data) == 0)
@@ -404,6 +460,12 @@
 			return $this->data;
 		}
 
+		/**
+		 * copies the given $data into the internal array
+		 *
+		 * @param array with data
+		 * @return array $this->data = $data
+		 */
 		function update_data($data)
 		{
 			reset($data);
@@ -414,6 +476,13 @@
 			return $this->data;
 		}
 
+		/**
+		 * Get all memberships of an account $accountid / groups the account is a member off
+		 *
+		 * @param int/string $accountid='' numeric account-id or alphanum. account-lid, 
+		 *	default account of the user of this session
+		 * @return array or arrays with keys 'account_id' and 'account_name' for the groups $accountid is a member of
+		 */
 		function membership($accountid = '')
 		{
 			$this->setup_cache();
@@ -426,112 +495,98 @@
 				return $membership_list[$account_id];
 			}
 
-			$security_equals = Array();
-			$security_equals = $GLOBALS['phpgw']->acl->get_location_list_for_id('phpgw_group', 1, $account_id);
-
-			if ($security_equals == False)
+			if(!($gids = $GLOBALS['egw']->acl->get_location_list_for_id('phpgw_group', 1, $account_id)))
 			{
 				return $membership_list[$account_id] = False;
 			}
 
-			$this->memberships = Array();
-
-			for ($idx=0; $idx<count($security_equals); $idx++)
+			$memberships = Array();
+			foreach($gids as $gid)
 			{
-				$groups = (int)$security_equals[$idx];
-				$this->memberships[] = Array('account_id' => $groups, 'account_name' => $this->id2name($groups));
+				$memberships[] = Array('account_id' => $gid, 'account_name' => $this->id2name($gid));
 			}
-
-			return $membership_list[$account_id] = $this->memberships;
+			return $membership_list[$account_id] = $memberships;
 		}
 
+		/**
+		 * Get all members of the group $accountid
+		 *
+		 * @param int/string $accountid='' numeric account-id or alphanum. account-lid, 
+		 *	default account of the user of this session
+		 * @return array or arrays with keys 'account_id' and 'account_name'
+		 */
 		function member($accountid = '')
 		{
+			$this->setup_cache();
+			$member_list = &$this->cache['member_list'];
+
 			$account_id = get_account_id($accountid);
 
-			$security_equals = Array();
-			$acl = CreateObject('phpgwapi.acl');
-			$security_equals = $acl->get_ids_for_location($account_id, 1, 'phpgw_group');
-			unset($acl);
-
-			if ($security_equals == False)
+			if (isset($member_list[$account_id]))
 			{
-				return False;
+				return $member_list[$account_id];
 			}
 
-			for ($idx=0; $idx<count($security_equals); $idx++)
+			if (!($uids = $GLOBALS['egw']->acl->get_ids_for_location($account_id, 1, 'phpgw_group')))
 			{
-				$name = $this->id2name((int)$security_equals[$idx]);
-				$this->members[] = Array('account_id' => (int)$security_equals[$idx], 'account_name' => $name);
+				return $member_list[$account_id] = False;
 			}
 
-			return $this->members;
+			$members = array();
+			foreach ($uids as $uid)
+			{
+				$members[] = Array('account_id' => $uid, 'account_name' => $this->id2name($uid));
+			}
+			return $member_list[$account_id] = $members;
 		}
 
-		/*!
-		@function get_nextid
-		@abstract Using the common functions next_id and last_id, find the next available account_id
-		@param $account_type (optional, default to 'u')
-		*/
-		// NOTE: to my knowledge this is not used any more RalfBecker 2004/06/15
+		/**
+		 * Using the common functions next_id and last_id, find the next available account_id
+		 *
+		 * NOTE: only used for the creation of LDAP accounts
+		 *
+		 * @param $string $account_type='u' (optional, default to 'u')
+		 * @return int/boolean interger account_id or false if none is free anymore
+		 */
 		function get_nextid($account_type='u')
 		{
-			$min = $GLOBALS['phpgw_info']['server']['account_min_id'] ? $GLOBALS['phpgw_info']['server']['account_min_id'] : 0;
-			$max = $GLOBALS['phpgw_info']['server']['account_max_id'] ? $GLOBALS['phpgw_info']['server']['account_max_id'] : 0;
+			$min = $GLOBALS['egw_info']['server']['account_min_id'] ? $GLOBALS['egw_info']['server']['account_min_id'] : 0;
+			$max = $GLOBALS['egw_info']['server']['account_max_id'] ? $GLOBALS['egw_info']['server']['account_max_id'] : 0;
 
 			if ($account_type == 'g')
 			{
 				$type = 'groups';
+				$sign = -1;
 			}
 			else
 			{
 				$type = 'accounts';
+				$sign = 1;
 			}
-			$nextid = (int)$GLOBALS['phpgw']->common->last_id($type,$min,$max);
-
 			/* Loop until we find a free id */
-			$free = 0;
-			while (!$free)
+			do
 			{
-				$account_lid = '';
-				//echo '<br>calling search for id: '.$nextid;
-				if ($this->exists($nextid))
-				{
-					$nextid = (int)$GLOBALS['phpgw']->common->next_id($type,$min,$max);
-				}
-				else
-				{
-					$account_lid = $this->id2name($nextid);
-					/* echo '<br>calling search for lid: '.$account_lid . '(from account_id=' . $nextid . ')'; */
-					if ($this->exists($account_lid))
-					{
-						$nextid = (int)$GLOBALS['phpgw']->common->next_id($type,$min,$max);
-					}
-					else
-					{
-						$free = True;
-					}
-				}
-			}
-			if	($GLOBALS['phpgw_info']['server']['account_max_id'] &&
-				($nextid > $GLOBALS['phpgw_info']['server']['account_max_id']))
+				$account_id = (int) $GLOBALS['egw']->common->next_id($type,$min,$max);
+			} 
+			while ($account_id && $this->exists($sign * $account_id));	// check need to include the sign!
+
+			if	(!$account_id || $GLOBALS['egw_info']['server']['account_max_id'] &&
+				$account_id > $GLOBALS['egw_info']['server']['account_max_id'])
 			{
 				return False;
 			}
-			/* echo '<br>using'.$nextid;exit; */
-			return $nextid;
+			return $account_id;
 		}
 
-
 		/**
-		* splits users and groups from a array of id's or the accounts with run-rights for a given app-name
-		*
-		* @param $app_users array of user-id's or app-name (if you use app-name the result gets cached!)
-		* @param $use string what should be returned only an array with id's of either 'accounts' or 'groups'.
-		*	Or an array with arrays for 'both' under the keys 'groups' and 'accounts' or 'merge' for accounts
-		*	and groups merged into one array
-		* @return see $use
-		*/
+		 * splits users and groups from a array of id's or the accounts with run-rights for a given app-name
+		 *
+		 * @param array $app_users array of user-id's or app-name (if you use app-name the result gets cached!)
+		 * @param string $use what should be returned only an array with id's of either 'accounts' or 'groups'.
+		 *	Or an array with arrays for 'both' under the keys 'groups' and 'accounts' or 'merge' for accounts
+		 *	and groups merged into one array
+		 * @return array/boolean see $use, false on error (wront $use)
+		 */
 		function split_accounts($app_users,$use='both')
 		{
 			if (!is_array($app_users))
@@ -543,7 +598,7 @@
 				{
 					return $cache;
 				}
-				$app_users = $GLOBALS['phpgw']->acl->get_ids_for_location('run',1,$app_users);
+				$app_users = $GLOBALS['egw']->acl->get_ids_for_location('run',1,$app_users);
 			}
 			$accounts = array(
 				'accounts' => array(),
@@ -551,11 +606,11 @@
 			);
 			foreach($app_users as $id)
 			{
-				$type = $GLOBALS['phpgw']->accounts->get_type($id);
+				$type = $this->get_type($id);
 				if($type == 'g')
 				{
 					$accounts['groups'][$id] = $id;
-					foreach((array)$GLOBALS['phpgw']->acl->get_ids_for_location($id,1,'phpgw_group') as $id)
+					foreach((array)$GLOBALS['egw']->acl->get_ids_for_location($id,1,'phpgw_group') as $id)
 					{
 						$accounts['accounts'][$id] = $id;
 					}
@@ -592,6 +647,8 @@
 
 		/**
 		 * phpgw compatibility function, better use split_accounts
+		 *
+		 * @deprecated  use split_accounts
 		 */
 		function return_members($accounts)
 		{
@@ -603,6 +660,13 @@
 			);
 		}
 
+		/**
+		 * convert an alphanumeric account-value (account_lid, account_email) to the account_id
+		 *
+		 * @param string $name value to convert
+		 * @param string $which='account_lid' type of $name: account_lid (default), account_email
+		 * @return int/false numeric account_id or false on error ($name not found)
+		 */
 		function name2id($name,$which='account_lid')
 		{
 			$this->setup_cache();
@@ -621,6 +685,13 @@
 			return $name_list[$which][$name] = accounts_::name2id($name,$which);
 		}
 
+		/**
+		 * convert an numeric account_id to any other value of that account (account_lid, account_email, ...)
+		 *
+		 * @param int $account_id numerica account_id
+		 * @param string $which='account_lid' type to convert to: account_lid (default), account_email, ...
+		 * @return string/false converted value or false on error ($account_id not found)
+		 */
 		function id2name($account_id,$which='account_lid')
 		{
 			$this->setup_cache();
@@ -638,29 +709,30 @@
 			return $id_list[$account_id][$which] = accounts_::id2name($account_id,$which);
 		}
 
+		/**
+		 * get the type of an account: 'u' = user, 'g' = group
+		 *
+		 * @param int/string $accountid numeric account-id or alphanum. account-lid, 
+		 *	if !$accountid account of the user of this session
+		 * @return string/false 'u' = user, 'g' = group or false on error ($accountid not found)
+		 */
 		function get_type($accountid)
 		{
-			$this->setup_cache();
-			$account_type = &$this->cache['account_type'];
-
 			$account_id = get_account_id($accountid);
-
-			if (isset($this->account_type) && $account_id == $this->account_id)
-			{
-				return $this->account_type;
-			}
-
-			if(@isset($account_type[$account_id]) && @$account_type[$account_id])
-			{
-				return $account_type[$account_id];
-			}
-			elseif($account_id == '')
-			{
-				return False;
-			}
-			return $account_type[$account_id] = accounts_::get_type($account_id);
+			
+			return $account_id > 0 ? 'u' : ($account_id < 0 ? 'g' : false);
 		}
 
+		/**
+		 * Gets account-name (lid), firstname and lastname of an account $accountid
+		 *
+		 * @param int/string $accountid='' numeric account-id or alphanum. account-lid, 
+		 *	if !$accountid account of the user of this session
+		 * @param string &$lid on return: alphanumeric account-name (lid)
+		 * @param string &$fname on return: first name
+		 * @param string &$lname on return: last name
+		 * @return boolean true if $accountid was found, false otherwise
+		 */	 
 		function get_account_name($accountid,&$lid,&$fname,&$lname)
 		{
 			$this->setup_cache();
@@ -675,6 +747,9 @@
 				return $account_name[$account_id] !== False;
 			}
 			$Ok = accounts_::get_account_name($accountid,$lid,$fname,$lname);
+			
+			if (empty($fname)) $fname = $lid;
+			if (empty($lname)) $lname = $this->get_type($accountid) == 'g' ? lang('Group') : lang('user');
 
 			$account_name[$account_id] = array(
 				'lid' => $lid,
@@ -684,6 +759,14 @@
 			return $Ok;
 		}
 
+		/**
+		 * Reads account-data for a given $account_id from the repository AND sets the class-vars with it
+		 *
+		 * Same effect as instanciating the class with that account, dont do it with $GLOBALS['egw']->account !!!
+		 *
+		 * @param int $accountid numeric account-id 
+		 * @return array with keys lid, firstname, lastname, fullname, type
+		 */
 		function get_account_data($account_id)
 		{
 			$this->account_id = $account_id;
