@@ -24,7 +24,7 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.accounts_ldap.inc.php,v 1.146.2.5 2005/04/12 09:54:46 ralfbecker Exp $ */
+	/* $Id: class.accounts_ldap.inc.php 22104 2006-07-12 22:00:30Z ralfbecker $ */
 
 	class accounts_
 	{
@@ -36,15 +36,28 @@
 		var $group_context = '';
 		var $total;
 
+		var $requiredObjectClasses = array(
+			'user' => array(
+				'top','person','organizationalperson','inetorgperson','posixaccount','shadowaccount','phpgwaccount'
+			),
+			'group' => array(
+				'top','posixgroup','phpgwaccount',
+				// some newer ldap require namedObject here, as none of the above is a structural object there
+				// this gets now autodetected
+				//'namedObject'
+			)
+		);
+
 		function accounts_()
 		{
-			$this->ds = $GLOBALS['phpgw']->common->ldapConnect();
-			if(!@is_object($GLOBALS['phpgw']->translation))
+			$this->ds = $GLOBALS['egw']->common->ldapConnect();
+			if(!@is_object($GLOBALS['egw']->translation))
 			{
-				$GLOBALS['phpgw']->translation = CreateObject('phpgwapi.translation');
+				$GLOBALS['egw']->translation =& CreateObject('phpgwapi.translation');
 			}
-			$this->user_context  = $GLOBALS['phpgw_info']['server']['ldap_context'];
-			$this->group_context = $GLOBALS['phpgw_info']['server']['ldap_group_context'];
+			$this->user_context  = $GLOBALS['egw_info']['server']['ldap_context'];
+			$this->group_context = $GLOBALS['egw_info']['server']['ldap_group_context'] ? 
+				$GLOBALS['egw_info']['server']['ldap_group_context'] : $GLOBALS['egw_info']['server']['ldap_context'];
 		}
 
 		function read_repository()
@@ -54,7 +67,7 @@
 			/* search the dn for the given uid */
 			if(($acct_type == 'g') && $this->group_context)
 			{
-				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . (int)$this->account_id);
+				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . abs((int)$this->account_id));
 			}
 			else
 			{
@@ -65,27 +78,27 @@
 			/* Now dump it into the array; take first entry found */
 			if($acct_type =='g')
 			{
-				$this->data['account_id']   = $allValues[0]['gidnumber'][0];
+				$this->data['account_id']   = -$allValues[0]['gidnumber'][0];
 				$this->data['account_lid']  = $allValues[0]['cn'][0];
-				$this->data['firstname']    = $GLOBALS['phpgw']->translation->convert($allValues[0]['cn'][0],'utf-8');
+				$this->data['firstname']    = $GLOBALS['egw']->translation->convert($allValues[0]['cn'][0],'utf-8');
 				$this->data['lastname']     = lang('Group');
 			}
 			else
 			{
 				$this->data['account_id']  = $allValues[0]['uidnumber'][0];
-				$this->data['account_primary_group'] = $allValues[0]['gidnumber'][0];
+				$this->data['account_primary_group'] = -$allValues[0]['gidnumber'][0];
 				$this->data['account_lid'] = $allValues[0]['uid'][0];
-				$this->data['firstname']   = $GLOBALS['phpgw']->translation->convert($allValues[0]['givenname'][0],'utf-8');
-				$this->data['lastname']    = $GLOBALS['phpgw']->translation->convert($allValues[0]['sn'][0],'utf-8');
+				$this->data['firstname']   = $GLOBALS['egw']->translation->convert($allValues[0]['givenname'][0],'utf-8');
+				$this->data['lastname']    = $GLOBALS['egw']->translation->convert($allValues[0]['sn'][0],'utf-8');
 				if(isset($allValues[0]['mail'][0]))
 				{
 					$this->data['email'] = $allValues[0]['mail'][0];
 				}
 			}
 			$this->data['account_dn']  = $allValues[0]['dn'];
-			$this->data['fullname']    = $GLOBALS['phpgw']->translation->convert($allValues[0]['cn'][0],'utf-8');
+			$this->data['fullname']    = $GLOBALS['egw']->translation->convert($allValues[0]['cn'][0],'utf-8');
 
-			if ($GLOBALS['phpgw_info']['server']['ldap_extra_attributes'])
+			if ($GLOBALS['egw_info']['server']['ldap_extra_attributes'])
 			{
 				$this->data['homedirectory']  = $allValues[0]['homedirectory'][0];
 				$this->data['loginshell'] = $allValues[0]['loginshell'][0];
@@ -103,13 +116,12 @@
 
 		function save_repository()
 		{
-			#_debug_array($this->data);
 			$acct_type = $this->get_type($this->account_id);
 
 			/* search the dn for the given u/gidnumber */
 			if(($acct_type == 'g') && $this->group_context)
 			{
-				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . (int)$this->account_id);
+				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . abs((int)$this->account_id));
 			}
 			else
 			{
@@ -122,30 +134,30 @@
 			if($acct_type == 'u')
 			{
 				// data for posixaccount
-				$newData['cn'] = $GLOBALS['phpgw']->translation->convert(sprintf("%s %s",
+				$newData['cn'] = $GLOBALS['egw']->translation->convert(sprintf("%s %s",
 					$this->data['firstname'],
-					$this->data['lastname']),$GLOBALS['phpgw']->translation->charset(),'utf-8'
+					$this->data['lastname']),$GLOBALS['egw']->translation->charset(),'utf-8'
 				);
-				$newData['uid'] = $GLOBALS['phpgw']->translation->convert(
+				$newData['uid'] = $GLOBALS['egw']->translation->convert(
 					$this->data['account_lid'],
-					$GLOBALS['phpgw']->translation->charset(),'utf-8'
+					$GLOBALS['egw']->translation->charset(),'utf-8'
 				);
 				if($this->data['lastname'])
 				{
-					$newData['sn'] = $GLOBALS['phpgw']->translation->convert(
+					$newData['sn'] = $GLOBALS['egw']->translation->convert(
 						$this->data['lastname'],
-						$GLOBALS['phpgw']->translation->charset(),'utf-8'
+						$GLOBALS['egw']->translation->charset(),'utf-8'
 					);
 				}
 
 				if($this->data['firstname'])
 				{
-					$newData['givenname'] = $GLOBALS['phpgw']->translation->convert(
+					$newData['givenname'] = $GLOBALS['egw']->translation->convert(
 						$this->data['firstname'],
-						$GLOBALS['phpgw']->translation->charset(),'utf-8'
+						$GLOBALS['egw']->translation->charset(),'utf-8'
 					);
 				}
-				if ($GLOBALS['phpgw_info']['server']['ldap_extra_attributes'])
+				if ($GLOBALS['egw_info']['server']['ldap_extra_attributes'])
 				{
 					$newData['homedirectory'] = $this->data['homedirectory'];
 					$newData['loginshell']    = $this->data['loginshell'];
@@ -158,7 +170,7 @@
 				}
 				if($this->data['account_primary_group'])
 				{
-					$newData['gidnumber'] = $this->data['account_primary_group'];
+					$newData['gidnumber'] = abs($this->data['account_primary_group']);
 				}
 				if($this->data['lastlogin'])
 				{
@@ -189,23 +201,32 @@
 					$newData['mail'] = $this->data['email'];
 				}
 
+				// check that we have all required objectclasses
+				unset($allValues[0]['objectclass']['count']);
+				// convert all values to lowercase
+				$currentObjectClasses = array_flip(array_change_key_case(array_flip($allValues[0]['objectclass'])));
+				$missingObjectClasses = array_diff($this->requiredObjectClasses['user'],$currentObjectClasses);
+				if(count($missingObjectClasses) > 0)
+				{
+					$newData['objectclass'] = array_merge($currentObjectClasses, $missingObjectClasses);
+				}
 				$newAccountID = $newData['uid'];
 				$oldAccountID = $newData['uid'];
 			}
 			else
 			{
 				// data for posixgroup
-				$newData['cn'] = $GLOBALS['phpgw']->translation->convert(
+				$newData['cn'] = $GLOBALS['egw']->translation->convert(
 					$this->data['account_lid'],
-					$GLOBALS['phpgw']->translation->charset(), 'utf-8'
+					$GLOBALS['egw']->translation->charset(), 'utf-8'
 				);
-				$newData['gidnumber'] = $this->account_id;
+				$newData['gidnumber'] = abs($this->account_id);
 				$newGroupID = $newData['cn'];
 				$oldGroupID = $newData['cn'];
 			}
-			if($this->data['type'])
+			if($this->data['account_type'])
 			{
-				$newData['phpgwaccounttype'] = $this->data['type'];
+				$newData['phpgwaccounttype'] = $this->data['account_type'];
 			}
 
 			/*
@@ -220,7 +241,7 @@
 			{
 				$test = $allValues[0]['uid'][0];
 			}
-			if($GLOBALS['phpgw']->translation->convert($test,'utf-8') != $this->data['account_lid'])
+			if($GLOBALS['egw']->translation->convert($test,'utf-8') != $this->data['account_lid'])
 			{
 				$oldData = $allValues[0];
 				$oldDN   = $oldData['dn'];
@@ -258,14 +279,15 @@
 				if($this->data['account_type'] == 'g' && $this->group_context )
 				{
 					$newDN = 'cn='.$this->data['account_lid'].','.$this->group_context;
-					$members = $this->member($this->account_id);
 					$newData['memberuid'] = array();
-					for($i=0;$i<count($members);$i++)
+					if (($members = $this->member($this->account_id)))
 					{
-						$currname = $this->id2name($members[$i]['account_id']);
-						if(!in_array($currname,$entry['memberuid']))
+						foreach($members as $member)
 						{
-							$newData['memberuid'][] = $currname;
+							if (!in_array($member['account_name'],$newData['memberuid']))
+							{
+								$newData['memberuid'][] = $member['account_name'];
+							}
 						}
 					}
 				}
@@ -279,28 +301,31 @@
 
 				// add the new account
 				#_debug_array($newData);
-				ldap_add($this->ds, $newDN, $newData);
+				if (!@ldap_add($this->ds, $newDN, $newData) && $this->data['account_type'] == 'g')
+				{
+					// try again with namedObject added, in case we have the newer schema which eg. SuSE uses
+					// in which our required objectclasses for a group, have no structural object
+					$newData['objectclass'][] = 'namedObject';
+					ldap_add($this->ds, $newDN, $newData);
+				}
 			}
-			/* Normal behavior for save_repository
-			   update Account */
+			/* Normal behavior for save_repository update Account */
 			else
 			{
 				// add the list group members
-				if($this->data['account_type'] == 'g' && $this->group_context )
+				if($this->data['account_type'] == 'g' && ($members = $this->member($this->account_id)))
 				{
-					$members = $this->member($this->account_id);
-					#_debug_array($members);
 					$newData['memberuid'] = array();
-					for($i=0;$i<count($members);$i++)
+					foreach($members as $member)
 					{
-						$currname = $this->id2name($members[$i]['account_id']);
-						if(!in_array($currname,$newData['memberuid']))
+						if (!in_array($member['account_name'],$newData['memberuid']))
 						{
-							$newData['memberuid'][] = $currname;
+							$newData['memberuid'][] = $member['account_name'];
 						}
 					}
 				}
 				// modify the DN
+				//echo "<p>ldap_modify(,'{$allValues[0]['dn']}',".print_r($newData,true).")</p>\n";
 				ldap_modify($this->ds, $allValues[0]['dn'], $newData);
 			}
 
@@ -362,7 +387,7 @@
 				foreach($this->data['account_groups'] as $key => $value)
 				{
 					// search for the group
-					$filter    = 'gidnumber=' . (int)$value;
+					$filter    = 'gidnumber=' . abs((int)$value);
 					$justThese = array('memberuid');
 					$sri = ldap_search($this->ds, $this->group_context, $filter, $justThese);
 					if($sri)
@@ -400,23 +425,24 @@
 		{
 			$account_id = get_account_id($accountid);
 			$account_lid = $this->id2name((int)$account_id);
-
-			$filter = 'gidnumber=' . (int)$account_id;
-			$sri = ldap_search($this->ds, $this->group_context, $filter);
+			
+			if ($account_id < 0)
+			{
+				$filter = 'gidnumber=' . abs((int)$account_id);
+				$context = $this->group_context;
+			}
+			else
+			{
+				$filter = 'uid=' . (string)$account_lid;
+				$context = $this->user_context;
+				$wasAccount = True;
+			}
+			
+			$sri = ldap_search($this->ds, $context, $filter);
 			if($sri)
 			{
 				$allValues = ldap_get_entries($this->ds, $sri);
-			}
-
-			if(!$allValues[0]['dn'])
-			{
-				$sri = ldap_search($this->ds, $this->user_context, 'uid=' . (string)$account_lid);
-				if($sri)
-				{
-					$allValues = ldap_get_entries($this->ds, $sri);
-					$accountID = $allValues['0']['uid'][0];
-					$wasAccount = True;
-				}
+				$accountID = $allValues['0']['uid'][0];
 			}
 
 			if ($allValues[0]['dn'])
@@ -427,7 +453,7 @@
 			if($wasAccount)
 			{
 				// remove the user from any group he is member of
-				$filter    = "(&(objectclass=posixgroup)(memberuid=" . (int)$accountID . "))";
+				$filter    = "(&(objectclass=posixgroup)(memberuid=" . $accountID . "))";
 				$justThese = array('memberuid','gidnumber');
 				$sri = ldap_search($this->ds, $this->group_context, $filter, $justThese);
 				if($sri)
@@ -453,12 +479,12 @@
 			}
 		}
 
-		function get_list($_type='both', $start = '',$sort = '', $order = '', $query = '', $offset = '',$query_type='')
+		function get_list($_type='both', $start = '',$sort = '', $order = '', $query = '', $offset = '', $query_type='')
 		{
 			//print "\$_type=$_type, \$start=$start , \$sort=$sort, \$order=$order, \$query=$query, \$offset=$offset, \$query_type=$query_type<br>";
 			$query = strtolower($query);
 
-			if($_type == 'accounts' || $_type == 'both')
+			if($_type != 'groups')
 			{
 				$filter = "(&(uidnumber=*)(phpgwaccounttype=u)";
 				if (!empty($query) && $query != '*')
@@ -497,21 +523,21 @@
 				{
 					settype($allVals,'array');
 					$test = @$allVals['uid'][0];
-					if (!$GLOBALS['phpgw_info']['server']['global_denied_users'][$test] && $allVals['uid'][0])
+					if (!$GLOBALS['egw_info']['server']['global_denied_users'][$test] && $allVals['uid'][0])
 					{
 						$accounts[] = Array(
 							'account_id'        => $allVals['uidnumber'][0],
 							'account_lid'       => $allVals['uid'][0],
 							'account_type'      => $allVals['phpgwaccounttype'][0],
-							'account_firstname' => $GLOBALS['phpgw']->translation->convert($allVals['givenname'][0],'utf-8'),
-							'account_lastname'  => $GLOBALS['phpgw']->translation->convert($allVals['sn'][0],'utf-8'),
+							'account_firstname' => $GLOBALS['egw']->translation->convert($allVals['givenname'][0],'utf-8'),
+							'account_lastname'  => $GLOBALS['egw']->translation->convert($allVals['sn'][0],'utf-8'),
 							'account_status'    => $allVals['phpgwaccountstatus'][0],
 							'account_email'     => $allVals['mail'][0],
 						);
 					}
 				}
 			}
-			if ($_type == 'groups' || $_type == 'both')
+			if ($_type != 'accounts')
 			{
 				if(empty($query) || $query == '*')
 				{
@@ -527,14 +553,14 @@
 				{
 					settype($allVals,'array');
 					$test = $allVals['cn'][0];
-					if (!$GLOBALS['phpgw_info']['server']['global_denied_groups'][$test] && $allVals['cn'][0])
+					if (!$GLOBALS['egw_info']['server']['global_denied_groups'][$test] && $allVals['cn'][0])
 					{
 						$accounts[] = Array(
-							'account_id'        => $allVals['gidnumber'][0],
+							'account_id'        => -$allVals['gidnumber'][0],
 							'account_lid'       => $allVals['cn'][0],
 							'account_type'      => $allVals['phpgwaccounttype'][0],
-							'account_firstname' => $GLOBALS['phpgw']->translation->convert($allVals['givenname'][0],'utf-8'),
-							'account_lastname'  => $GLOBALS['phpgw']->translation->convert($allVals['sn'][0],'utf-8'),
+							'account_firstname' => $GLOBALS['egw']->translation->convert($allVals['givenname'][0],'utf-8'),
+							'account_lastname'  => $GLOBALS['egw']->translation->convert($allVals['sn'][0],'utf-8'),
 							'account_status'    => $allVals['phpgwaccountstatus'][0],
 							'account_email'     => $allVals['mail'][0],
 						);
@@ -542,26 +568,26 @@
 				}
 			}
 			// sort the array
-			$arrayFunctions = CreateObject('phpgwapi.arrayfunctions');
+			$arrayFunctions =& CreateObject('phpgwapi.arrayfunctions');
 			if(empty($order))
 			{
 				$order = 'account_lid';
 			}
 			$sortedAccounts = $arrayFunctions->arfsort($accounts,explode(',',$order),$sort);
 			$this->total = count($accounts);
-
 			// return only the wanted accounts
-
 			if (is_array($sortedAccounts))
 			{
 				reset($sortedAccounts);
-				if(is_int($start) && is_int($offset))
+				if(is_numeric($start) && is_numeric($offset))
 				{
 					return array_slice($sortedAccounts, $start, $offset);
 				}
-				elseif(is_int($start))
+				elseif(is_numeric($start))
 				{
-					return array_slice($sortedAccounts, $start, $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']);
+					if (!($maxmatchs = $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'])) $maxmatchs = 15;
+	
+					return array_slice($sortedAccounts, $start, $maxmatchs);
 				}
 				else
 				{
@@ -580,7 +606,7 @@
 	
 				if (@$allValues[0]['gidnumber'][0])
 				{
-					return (int)$allValues[0]['gidnumber'][0];
+					return -(int)$allValues[0]['gidnumber'][0];
 				}
 			}
 			$to_ldap = array(
@@ -603,10 +629,10 @@
 
 		function id2name($account_id,$which='account_lid')
 		{
-			if ($which == 'account_lid' || $which == 'account_type')	// groups only support account_lid and account_type
+			if (($which == 'account_lid' || $which == 'account_type') && $account_id < 0)	// groups only support account_lid and account_type
 			{
 				$allValues = array();
-				$sri = ldap_search($this->ds, $this->group_context, '(&(gidnumber=' . (int)$account_id . ')(phpgwaccounttype=g))');
+				$sri = ldap_search($this->ds, $this->group_context, '(&(gidnumber=' . abs((int)$account_id) . ')(phpgwaccounttype=g))');
 				$allValues = ldap_get_entries($this->ds, $sri);
 	
 				$attr = $which == 'account_lid' ? 'cn' : 'phpgwaccounttype';
@@ -635,28 +661,6 @@
 			return False;
 		}
 
-		function get_type($account_id)
-		{
-			$allValues = array();
-			$sri = ldap_search($this->ds, $this->user_context, '(&(uidnumber=' . (int)$account_id . ')(phpgwaccounttype=u))');
-			$allValues = ldap_get_entries($this->ds, $sri);
-
-			if ($allValues[0]['phpgwaccounttype'][0])
-			{
-				return $allValues[0]['phpgwaccounttype'][0];
-			}
-
-			$allValues = array();
-			$sri = ldap_search($this->ds, $this->group_context, '(&(gidnumber=' . (int)$account_id . ')(phpgwaccounttype=g))');
-			$allValues = ldap_get_entries($this->ds, $sri);
-
-			if ($allValues[0]['phpgwaccounttype'][0])
-			{
-				return $allValues[0]['phpgwaccounttype'][0];
-			}
-			return False;
-		}
-
 		/*
 		 * returns nonzero if $account exists in LDAP: 0: nowhere 1: user accounts, 2: group accounts, 3: both
 		 * $account can be an account_id (LDAP: uidnumber) or an account_lid (LDAP: uid) (is determinded by ettype($account) == 'integer')
@@ -668,13 +672,12 @@
 			$users  = array();
 			$groups = array();
 
-			if(is_int($account))
+			if(is_numeric($account))
 			{
 				$ldapgroup = 'gidnumber';
 				$ldapacct  = 'uidnumber';
-				$account   = (int)$account;
 				/* If data is cached, use it. */
-				if(@isset($by_id[$account]) && @$by_id[$account])
+				if(isset($by_id[$account]))
 				{
 					return $by_id[$account];
 				}
@@ -690,11 +693,11 @@
 				}
 			}
 
-			$acct_type = $this->get_type($account);
+			$acct_type = $this->get_type($account) ? $this->get_type($account) : $this->account_type;
 
 			if ($acct_type == 'g' && $this->group_context)
 			{
-				$sri = ldap_search($this->ds, $this->group_context, $ldapgroup . '=' . $account);
+				$sri = ldap_search($this->ds, $this->group_context, $ldapgroup . '=' . abs($account));
 				$groups = ldap_get_entries($this->ds, $sri);
 			}
 			$sri = ldap_search($this->ds, $this->user_context, $ldapacct . '=' . $account);
@@ -719,7 +722,6 @@
 				$by_lid[$account] = $in;
 				$by_id[$this->name2id($account)] = $in;
 			}
-
 			return $in;
 		}
 
@@ -733,7 +735,7 @@
 			}
 			else
 			{
-				$account_id = $account_info['account_id'];
+				$account_id = abs($account_info['account_id']);
 			}
 			$entry['userpassword']              = $account_info['account_passwd'];
 			$entry['phpgwaccounttype']          = $account_info['account_type'];
@@ -749,10 +751,10 @@
 			}
 			$allValues = ldap_get_entries($this->ds, $sri);
 
-			if ($GLOBALS['phpgw_info']['server']['ldap_extra_attributes'] && $account_info['account_type'] != 'g')
+			if ($GLOBALS['egw_info']['server']['ldap_extra_attributes'] && $account_info['account_type'] != 'g')
 			{
-				$entry['homedirectory'] = $account_info['homedirectory'] && $account_info['homedirectory'] != $GLOBALS['phpgw_info']['server']['ldap_account_home'] ? $account_info['homedirectory'] : $GLOBALS['phpgw_info']['server']['ldap_account_home'].SEP.$account_info['account_lid'];
-				$entry['loginshell'] = $account_info['loginshell'] ? $account_info['loginshell'] : $GLOBALS['phpgw_info']['server']['ldap_account_shell'];
+				$entry['homedirectory'] = $account_info['homedirectory'] && $account_info['homedirectory'] != $GLOBALS['egw_info']['server']['ldap_account_home'] ? $account_info['homedirectory'] : $GLOBALS['egw_info']['server']['ldap_account_home'].SEP.$account_info['account_lid'];
+				$entry['loginshell'] = $account_info['loginshell'] ? $account_info['loginshell'] : $GLOBALS['egw_info']['server']['ldap_account_shell'];
 			}
 			elseif($account_info['account_type'] != 'g')
 			{
@@ -788,22 +790,13 @@
 
 				if ($account_info['account_type'] == 'g')
 				{
-					$tmpentry['objectclass'][0] = 'top';
-					$tmpentry['objectclass'][1] = 'posixGroup';
-					$tmpentry['objectclass'][2] = 'phpgwAccount';
+					$tmpentry['objectclass'] = $this->requiredObjectClasses['group'];
 				}
 				else
 				{
+					$tmpentry['objectclass'] = $this->requiredObjectClasses['user'];
 					$tmpentry['uidnumber']      = $account_id;
-					$tmpentry['objectclass'][0] = 'top';
-					$tmpentry['objectclass'][1] = 'person';
-					$tmpentry['objectclass'][2] = 'organizationalPerson';
-					$tmpentry['objectclass'][3] = 'inetOrgPerson';
-					$tmpentry['userpassword']   = $GLOBALS['phpgw']->common->encrypt_password($account_info['account_passwd'],False);
-					/* $tmpentry['objectclass'][4] = 'account'; Causes problems with some LDAP servers */
-					$tmpentry['objectclass'][4] = 'posixAccount';
-					$tmpentry['objectclass'][5] = 'shadowAccount';
-					$tmpentry['objectclass'][6] = 'phpgwAccount';
+					$tmpentry['userpassword']   = $GLOBALS['egw']->common->encrypt_password($account_info['account_passwd'],False);
 					$tmpentry['phpgwaccountstatus']    = $account_info['account_status'];
 					$tmpentry['phpgwaccounttype']      = $account_info['account_type'];
 					$tmpentry['phpgwaccountexpires']   = $account_info['account_expires'];
@@ -818,61 +811,53 @@
 					$dn = 'cn='.$account_info['account_lid'] . ',' . $this->group_context;
 					unset($entry['homedirectory']);
 					unset($entry['loginshell']);
-					$entry['objectclass'][0] = 'top';
-					$entry['objectclass'][1] = 'posixGroup';
-					$entry['objectclass'][2] = 'phpgwAccount';
-					$entry['cn']             = $GLOBALS['phpgw']->translation->convert($account_info['account_lid'],$GLOBALS['phpgw']->translation->charset(),'utf-8');
+					unset($entry['userpassword']);
+					$entry['objectclass'] = $this->requiredObjectClasses['group'];
+					$entry['cn']             = $GLOBALS['egw']->translation->convert($account_info['account_lid'],$GLOBALS['egw']->translation->charset(),'utf-8');
 					$entry['gidnumber']      = $account_id;
-					#$entry['userpassword']   = $GLOBALS['phpgw']->common->encrypt_password($account_info['account_passwd']);
-					$entry['description']    = 'phpgw-created group';
+					$entry['description']    = 'eGW-created group';
 				}
 				else
 				{
 					$dn = 'uid=' . $account_info['account_lid'] . ',' . $this->user_context;
 
-					$entry['cn'] = $GLOBALS['phpgw']->translation->convert(
+					$entry['cn'] = $GLOBALS['egw']->translation->convert(
 						sprintf(
 							"%s %s",
 							$account_info['account_firstname'],
 							$account_info['account_lastname']
 						),
-						$GLOBALS['phpgw']->translation->charset(),
+						$GLOBALS['egw']->translation->charset(),
 						'utf-8'
 					);
 
-					$entry['sn'] = $GLOBALS['phpgw']->translation->convert(
-						$account_info['account_lastname'],
-						$GLOBALS['phpgw']->translation->charset(),
+					$entry['sn'] = $GLOBALS['egw']->translation->convert(
+						$account_info['account_lastname'] ? $account_info['account_lastname'] : 'not set',
+						$GLOBALS['egw']->translation->charset(),
 						'utf-8'
 					);
 
 					if($account_info['account_firstname'])
 					{
-						$entry['givenname'] = $GLOBALS['phpgw']->translation->convert(
+						$entry['givenname'] = $GLOBALS['egw']->translation->convert(
 							$account_info['account_firstname'],
-							$GLOBALS['phpgw']->translation->charset(),
+							$GLOBALS['egw']->translation->charset(),
 							'utf-8'
 						);
 					}
 					if($account_info['account_email'])
 					{
-						$entry['mail'] = $GLOBALS['phpgw']->translation->convert(
+						$entry['mail'] = $GLOBALS['egw']->translation->convert(
 							$account_info['account_email'],
-							$GLOBALS['phpgw']->translation->charset(),
+							$GLOBALS['egw']->translation->charset(),
 							'utf-8'
 						);
 					}
 					$entry['uid']            = $account_info['account_lid'];
 					$entry['uidnumber']      = $account_id;
-					$entry['gidnumber']      = $account_info['account_primary_group'];
-					$entry['userpassword']   = $GLOBALS['phpgw']->common->encrypt_password($account_info['account_passwd']);
-					$entry['objectclass'][0] = 'top';
-					$entry['objectclass'][1] = 'person';
-					$entry['objectclass'][2] = 'organizationalPerson';
-					$entry['objectclass'][3] = 'inetOrgPerson';
-					$entry['objectclass'][4] = 'posixAccount';
-					$entry['objectclass'][5] = 'shadowAccount';
-					$entry['objectclass'][6] = 'phpgwAccount';
+					$entry['gidnumber']      = abs($account_info['account_primary_group']);
+					$entry['userpassword']   = $GLOBALS['egw']->common->encrypt_password($account_info['account_passwd']);
+					$entry['objectclass'] = $this->requiredObjectClasses['user'];
 					if($account_info['account_status'])
 					{
 						$entry['phpgwaccountstatus']    = $account_info['account_status'];
@@ -884,9 +869,23 @@
 				#_debug_array($entry);
 
 				// stop processing if ldap_add fails
-				if(!ldap_add($this->ds, $dn, $entry))
+				if(!@ldap_add($this->ds, $dn, $entry))
 				{
-					return false;
+					if ($account_info['account_type'] != 'g')
+					{
+						return false;
+					}
+					// try again with namedObject added, in case we have the newer schema which eg. SuSE uses
+					// in which our required objectclasses for a group, have no structural object
+					if ($account_info['account_type'] == 'g')
+					{
+						$entry['objectclass'][] = 'namedObject';
+					
+						if (!@ldap_add($this->ds, $dn, $entry))
+						{
+							return false;
+						}
+					}
 				}
 			}
 			// print ldap_error($this->ds);
@@ -898,7 +897,7 @@
 				foreach($account_info['account_groups'] as $key => $value)
 				{
 					// search for the group
-					$filter    = 'gidnumber=' . (int)$value;
+					$filter    = 'gidnumber=' . abs($value);
 					$justThese = array('memberuid');
 					$sri = ldap_search($this->ds, $this->group_context, $filter, $justThese);
 					if($sri)
@@ -932,27 +931,34 @@
 				}
 			}
 
-			if($account_id && is_object($GLOBALS['phpgw']->preferences) && $default_prefs)
+			if($account_id && is_object($GLOBALS['egw']->preferences) && $default_prefs)
 			{
-				$GLOBALS['phpgw']->preferences->create_defaults($account_id);
+				$GLOBALS['egw']->preferences->create_defaults($account_id);
 			}
 
-			return $account_id;
+			if($account_info['account_type'] == 'g')
+			{
+				return -$account_id;
+			}
+			else
+			{
+				return $account_id;
+			}
 		}
 
 		function auto_add($accountname, $passwd, $default_prefs = False, $default_acls = False, $expiredate = 0, $account_status = 'A')
 		{
 			if ($expiredate == 0)
 			{
-				if(isset($GLOBALS['phpgw_info']['server']['auto_create_expire']) == True)
+				if(isset($GLOBALS['egw_info']['server']['auto_create_expire']) == True)
 				{
-					if($GLOBALS['phpgw_info']['server']['auto_create_expire'] == 'never')
+					if($GLOBALS['egw_info']['server']['auto_create_expire'] == 'never')
 					{
 						$expires = -1;
 					}
 					else
 					{
-						$expiredate = time() + $GLOBALS['phpgw_info']['server']['auto_create_expire'];
+						$expiredate = time() + $GLOBALS['egw_info']['server']['auto_create_expire'];
 					}
 				}
 			}
@@ -967,14 +973,14 @@
 				$expires = mktime(2,0,0,date('n',$expiredate), (int)date('d',$expiredate), date('Y',$expiredate));
 			}
 
-			$default_group_id  = $this->name2id($GLOBALS['phpgw_info']['server']['default_group_lid']);
+			$default_group_id  = $this->name2id($GLOBALS['egw_info']['server']['default_group_lid']);
 			if (!$default_group_id)
 			{
-				$default_group_id = (int) $this->name2id('Default');
+				$default_group_id = abs((int)$this->name2id('Default'));
 			}
 			$primary_group = $GLOBALS['auto_create_acct']['primary_group'] &&
 				$this->get_type((int)$GLOBALS['auto_create_acct']['primary_group']) == 'g' ?
-				(int) $GLOBALS['auto_create_acct']['primary_group'] : $default_group_id;
+				(int)$GLOBALS['auto_create_acct']['primary_group'] : $default_group_id;
 
 			$acct_info = array(
 				'account_lid'       => $accountname,
@@ -992,9 +998,9 @@
 			{
 				$acct_info['account_email'] = $GLOBALS['auto_create_acct']['email'];
 			}
-			elseif(isset($GLOBALS['phpgw_info']['server']['mail_suffix']) == True && $GLOBALS['phpgw_info']['server']['mail_suffix'] != '')
+			elseif(isset($GLOBALS['egw_info']['server']['mail_suffix']) == True && $GLOBALS['egw_info']['server']['mail_suffix'] != '')
 			{
-				$acct_info['account_email'] = $accountname . '@' . $GLOBALS['phpgw_info']['server']['mail_suffix'];
+				$acct_info['account_email'] = $accountname . '@' . $GLOBALS['egw_info']['server']['mail_suffix'];
 			}
 
 			$this->db->transaction_begin();
@@ -1007,47 +1013,43 @@
 			{
 				if($primary_group)
 				{
-					$this->db->query("INSERT INTO phpgw_acl (acl_appname, acl_location, acl_account, acl_rights) VALUES('phpgw_group', "
-						. $primary_group . ", " . $accountid . ", 1)",__LINE__,__FILE__);
+					$GLOBALS['egw']->acl->add_repository('phpgw_group', $primary_group,$accountid,1);
 				}
 
-				/* FIXME - we are assuming the auth method is capable of password changing
-				 * $this->db->query("INSERT INTO phpgw_acl (acl_appname, acl_location, acl_account, acl_rights)VALUES('preferences', 'changepassword', ".$accountid.", 1)",__LINE__,__FILE__);
-				 */
-
-				/* if we have an mail address set it in the uesrs' email preference */
+				/* if we have an mail address set it in the users' email preference */
 				if (isset($GLOBALS['auto_create_acct']['email']) && $GLOBALS['auto_create_acct']['email'] != '')
 				{
-					$GLOBALS['phpgw']->acl->acl($accountid);        /* needed als preferences::save_repository calls acl */
-					$GLOBALS['phpgw']->preferences->preferences($accountid);
-					$GLOBALS['phpgw']->preferences->read_repository();
-					$GLOBALS['phpgw']->preferences->add('email','address',$GLOBALS['auto_create_acct']['email']);
-					$GLOBALS['phpgw']->preferences->save_repository();
+					$GLOBALS['egw']->acl->acl($accountid);        /* needed als preferences::save_repository calls acl */
+					$GLOBALS['egw']->preferences->preferences($accountid);
+					$GLOBALS['egw']->preferences->read_repository();
+					$GLOBALS['egw']->preferences->add('email','address',$GLOBALS['auto_create_acct']['email']);
+					$GLOBALS['egw']->preferences->save_repository();
 				}
 				/* use the default mail domain to set the uesrs' email preference  */
-				elseif(isset($GLOBALS['phpgw_info']['server']['mail_suffix']) && $GLOBALS['phpgw_info']['server']['mail_suffix'] != '')
+				elseif(isset($GLOBALS['egw_info']['server']['mail_suffix']) && $GLOBALS['egw_info']['server']['mail_suffix'] != '')
 				{
-					$GLOBALS['phpgw']->acl->acl($accountid);        /* needed als preferences::save_repository calls acl */
-					$GLOBALS['phpgw']->preferences->preferences($accountid);
-					$GLOBALS['phpgw']->preferences->read_repository();
-					$GLOBALS['phpgw']->preferences->add('email','address', $accountname . '@' . $GLOBALS['phpgw_info']['server']['mail_suffix']);
-					$GLOBALS['phpgw']->preferences->save_repository();
+					$GLOBALS['egw']->acl->acl($accountid);        /* needed als preferences::save_repository calls acl */
+					$GLOBALS['egw']->preferences->preferences($accountid);
+					$GLOBALS['egw']->preferences->read_repository();
+					$GLOBALS['egw']->preferences->add('email','address', $accountname . '@' . $GLOBALS['egw_info']['server']['mail_suffix']);
+					$GLOBALS['egw']->preferences->save_repository();
 				}
 
 				/* commit the new account transaction */
 				$this->db->transaction_commit();
 
-				/* does anyone know what the heck this is required for? */
+				// call hook to notify interested apps about the new account
 				$GLOBALS['hook_values']['account_lid']	= $acct_info['account_lid'];
 				$GLOBALS['hook_values']['account_id']	= $accountid;
 				$GLOBALS['hook_values']['new_passwd']	= $acct_info['account_passwd'];
 				$GLOBALS['hook_values']['account_status'] = $acct_info['account_status'];
 				$GLOBALS['hook_values']['account_firstname'] = $acct_info['account_firstname'];
 				$GLOBALS['hook_values']['account_lastname'] = $acct_info['account_lastname'];
-				$GLOBALS['phpgw']->hooks->process($GLOBALS['hook_values']+array(
-					'location' => 'addaccount'
+				$GLOBALS['egw']->hooks->process($GLOBALS['hook_values']+array(
+					'location' => 'addaccount',
+					// at login-time only the hooks from the following apps will be called
+					'order' => array('felamimail','fudforum'),
 				),False,True);  // called for every app now, not only enabled ones
-
 			} /* end account setup */
 			else /* if no account id abort the account creation */
 			{
@@ -1068,7 +1070,7 @@
 			/* search the dn for the given uid */
 			if(($acct_type == 'g') && $this->group_context)
 			{
-				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . (int)$account_id);
+				$sri = ldap_search($this->ds, $this->group_context, 'gidnumber=' . abs((int)$account_id));
 			}
 			else
 			{
@@ -1078,15 +1080,15 @@
 
 			if($acct_type =='g')
 			{
-				$lid   = $GLOBALS['phpgw']->translation->convert($allValues[0]['cn'][0],'utf-8');
-				$fname = $GLOBALS['phpgw']->translation->convert($allValues[0]['cn'][0],'utf-8');
+				$lid   = $GLOBALS['egw']->translation->convert($allValues[0]['cn'][0],'utf-8');
+				$fname = $GLOBALS['egw']->translation->convert($allValues[0]['cn'][0],'utf-8');
 				$lname = lang('Group');
 			}
 			else
 			{
-				$lid   = $GLOBALS['phpgw']->translation->convert($allValues[0]['uid'][0],'utf-8');
-				$fname = $GLOBALS['phpgw']->translation->convert($allValues[0]['givenname'][0],'utf-8');
-				$lname = $GLOBALS['phpgw']->translation->convert($allValues[0]['sn'][0],'utf-8');
+				$lid   = $GLOBALS['egw']->translation->convert($allValues[0]['uid'][0],'utf-8');
+				$fname = $GLOBALS['egw']->translation->convert($allValues[0]['givenname'][0],'utf-8');
+				$lname = $GLOBALS['egw']->translation->convert($allValues[0]['sn'][0],'utf-8');
 			}
 			return !empty($lid);
 		}
@@ -1100,4 +1102,25 @@
 
 			return $allValues[0]['dn'];
 		}
+
+		/**
+		 * Update the last login timestamps and the IP
+		 *
+		 * @param int $account_id
+		 * @param string $ip
+		 * @return int lastlogin time
+		 */
+		function update_lastlogin($_account_id, $ip)
+		{
+			$entry['phpgwaccountlastlogin']     = time();
+			$entry['phpgwaccountlastloginfrom'] = $ip;
+
+			$sri = ldap_search($this->ds, $GLOBALS['egw_info']['server']['ldap_context'], 'uidnumber=' . (int)$_account_id);
+			$allValues = ldap_get_entries($this->ds, $sri);
+
+			$dn = $allValues[0]['dn'];
+			@ldap_modify($this->ds, $dn, $entry);
+				
+			return $allValues[0]['phpgwaccountlastlogin'][0];
+		}
 	}
