@@ -6,9 +6,9 @@
 	* Authentication based on LDAP Server                                      *
 	* Copyright (C) 2000, 2001 Joseph Engo                                     *
 	* Copyright (C) 2002, 2003 Lars Kneschke                                   *
-	* -------------------------------------------------------------------------*
+	* ------------------------------------------------------------------------ *
 	* This library is part of the eGroupWare API                               *
-	* http://www.egroupware.org/api                                            * 
+	* http://www.egroupware.org/api                                            *
 	* ------------------------------------------------------------------------ *
 	* This library is free software; you can redistribute it and/or modify it  *
 	* under the terms of the GNU Lesser General Public License as published by *
@@ -23,12 +23,19 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.auth_ldap.inc.php,v 1.29.4.2 2004/12/14 02:13:59 dawnlinux Exp $ */
-  
+	/* $Id: class.auth_ldap.inc.php 20295 2006-02-15 12:31:25Z  $ */
+
 	class auth_
 	{
 		var $previous_login = -1;
 
+		/**
+		 * authentication against LDAP
+		 *
+		 * @param string $username username of account to authenticate
+		 * @param string $passwd corresponding password
+		 * @return boolean true if successful authenticated, false otherwise
+		 */
 		function authenticate($username, $passwd)
 		{
 			if (ereg('[()|&=*,<>!~]',$username))
@@ -36,40 +43,40 @@
 				return False;
 			}
 
-			if(!$ldap = @ldap_connect($GLOBALS['phpgw_info']['server']['ldap_host']))
+			if(!$ldap = @ldap_connect($GLOBALS['egw_info']['server']['ldap_host']))
 			{
-				$GLOBALS['phpgw']->log->message('F-Abort, Failed connecting to LDAP server for authenication, execution stopped');
-				$GLOBALS['phpgw']->log->commit();
+				$GLOBALS['egw']->log->message('F-Abort, Failed connecting to LDAP server for authenication, execution stopped');
+				$GLOBALS['egw']->log->commit();
 				return False;
 			}
 
-			if($GLOBALS['phpgw_info']['server']['ldap_version3'])
+			if($GLOBALS['egw_info']['server']['ldap_version3'])
 			{
 				ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
 			}
 
 			/* Login with the LDAP Admin. User to find the User DN.  */
-			if(!@ldap_bind($ldap, $GLOBALS['phpgw_info']['server']['ldap_root_dn'], $GLOBALS['phpgw_info']['server']['ldap_root_pw']))
+			if(!@ldap_bind($ldap, $GLOBALS['egw_info']['server']['ldap_root_dn'], $GLOBALS['egw_info']['server']['ldap_root_pw']))
 			{
 				return False;
 			}
 			/* find the dn for this uid, the uid is not always in the dn */
 			$attributes	= array('uid','dn','givenName','sn','mail','uidNumber','gidNumber');
-			
-			$filter = $GLOBALS['phpgw_info']['server']['ldap_search_filter'] ? $GLOBALS['phpgw_info']['server']['ldap_search_filter'] : '(uid=%user)';
-			$filter = str_replace(array('%user','%domain'),array($username,$GLOBALS['phpgw_info']['user']['domain']),$filter);
 
-			if ($GLOBALS['phpgw_info']['server']['account_repository'] == 'ldap')
+			$filter = $GLOBALS['egw_info']['server']['ldap_search_filter'] ? $GLOBALS['egw_info']['server']['ldap_search_filter'] : '(uid=%user)';
+			$filter = str_replace(array('%user','%domain'),array($username,$GLOBALS['egw_info']['user']['domain']),$filter);
+
+			if ($GLOBALS['egw_info']['server']['account_repository'] == 'ldap')
 			{
 				$filter = "(&$filter(phpgwaccountstatus=A))";
 			}
 
-			$sri = ldap_search($ldap, $GLOBALS['phpgw_info']['server']['ldap_context'], $filter, $attributes);
+			$sri = ldap_search($ldap, $GLOBALS['egw_info']['server']['ldap_context'], $filter, $attributes);
 			$allValues = ldap_get_entries($ldap, $sri);
 
 			if ($allValues['count'] > 0)
 			{
-				if($GLOBALS['phpgw_info']['server']['case_sensitive_username'] == true)
+				if($GLOBALS['egw_info']['server']['case_sensitive_username'] == true)
 				{
 					if($allValues[0]['uid'][0] != $username)
 					{
@@ -79,7 +86,7 @@
 				/* we only care about the first dn */
 				$userDN = $allValues[0]['dn'];
 				/*
-				generate a bogus password to pass if the user doesn't give us one 
+				generate a bogus password to pass if the user doesn't give us one
 				this gets around systems that are anonymous search enabled
 				*/
 				if (empty($passwd))
@@ -89,10 +96,10 @@
 				/* try to bind as the user with user suplied password */
 				if (@ldap_bind($ldap, $userDN, $passwd))
 				{
-					if ($GLOBALS['phpgw_info']['server']['account_repository'] != 'ldap')
+					if ($GLOBALS['egw_info']['server']['account_repository'] != 'ldap')
 					{
-						$account = CreateObject('phpgwapi.accounts',$username,'u');
-						if (!$account->account_id && $GLOBALS['phpgw_info']['server']['auto_create_acct'])
+						$account =& CreateObject('phpgwapi.accounts',$username,'u');
+						if (!$account->account_id && $GLOBALS['egw_info']['server']['auto_create_acct'])
 						{
 							// create a global array with all availible info about that account
 							$GLOBALS['auto_create_acct'] = array();
@@ -105,7 +112,7 @@
 							) as $ldap_name => $acct_name)
 							{
 								$GLOBALS['auto_create_acct'][$acct_name] =
-									$GLOBALS['phpgw']->translation->convert($allValues[0][$ldap_name][0],'utf-8');
+									$GLOBALS['egw']->translation->convert($allValues[0][$ldap_name][0],'utf-8');
 							}
 							return True;
 						}
@@ -119,61 +126,44 @@
 			return False;
 		}
 
-		function change_password($old_passwd, $new_passwd, $_account_id='') 
+		/**
+		 * changes password in LDAP
+		 *
+		 * @param string $old_passwd must be cleartext or empty to not to be checked
+		 * @param string $new_passwd must be cleartext
+		 * @param int $account_id account id of user whose passwd should be changed
+		 * @return boolean true if password successful changed, false otherwise
+		 */
+		function change_password($old_passwd, $new_passwd, $account_id=0)
 		{
-			if ('' == $_account_id)
+			if (!$account_id)
 			{
-				$username = $GLOBALS['phpgw_info']['user']['account_lid'];
+				$username = $GLOBALS['egw_info']['user']['account_lid'];
 			}
 			else
 			{
-				$username = $GLOBALS['phpgw']->accounts->id2name($_account_id);
+				$username = $GLOBALS['egw']->accounts->id2name($account_id);
 			}
-			$filter = $GLOBALS['phpgw_info']['server']['ldap_search_filter'] ? $GLOBALS['phpgw_info']['server']['ldap_search_filter'] : '(uid=%user)';
-			$filter = str_replace(array('%user','%domain'),array($username,$GLOBALS['phpgw_info']['user']['domain']),$filter);
+			//echo "<p>auth_ldap::change_password('$old_password','$new_passwd',$account_id) username='$username'</p>\n";
 
-			$ds = $GLOBALS['phpgw']->common->ldapConnect();
-			$sri = ldap_search($ds, $GLOBALS['phpgw_info']['server']['ldap_context'], $filter);
+			$filter = $GLOBALS['egw_info']['server']['ldap_search_filter'] ? $GLOBALS['egw_info']['server']['ldap_search_filter'] : '(uid=%user)';
+			$filter = str_replace(array('%user','%domain'),array($username,$GLOBALS['egw_info']['user']['domain']),$filter);
+
+			$ds = $GLOBALS['egw']->common->ldapConnect();
+			$sri = ldap_search($ds, $GLOBALS['egw_info']['server']['ldap_context'], $filter);
 			$allValues = ldap_get_entries($ds, $sri);
-	
+
 			$entry['userpassword'] = $this->encrypt_password($new_passwd);
 			$dn = $allValues[0]['dn'];
-	
-			if (!@ldap_modify($ds, $dn, $entry)) 
+
+			if (!@ldap_modify($ds, $dn, $entry))
 			{
 				return false;
 			}
-			$GLOBALS['phpgw']->session->appsession('password','phpgwapi',$new_passwd);
-	
+			if($old_passwd)	// if old password given (not called by admin) update the password in the session
+			{
+				$GLOBALS['egw']->session->appsession('password','phpgwapi',$new_passwd);
+			}
 			return $entry['userpassword'];
 		}
-
-		function update_lastlogin($_account_id, $ip)
-		{
-			if ($GLOBALS['phpgw_info']['server']['account_repository'] == 'ldap')
-			{
-				$entry['phpgwaccountlastlogin']     = time();
-				$entry['phpgwaccountlastloginfrom'] = $ip;
-	
-				$ds = $GLOBALS['phpgw']->common->ldapConnect();
-				$sri = ldap_search($ds, $GLOBALS['phpgw_info']['server']['ldap_context'], 'uidnumber=' . (int)$_account_id);
-				$allValues = ldap_get_entries($ds, $sri);
-	
-				$dn = $allValues[0]['dn'];
-				$this->previous_login = $allValues[0]['phpgwaccountlastlogin'][0];
-	
-				@ldap_modify($ds, $dn, $entry);
-			}
-			else
-			{
-				$GLOBALS['phpgw']->db->query("select account_lastlogin from phpgw_accounts where account_id='$_account_id'",__LINE__,__FILE__);
-				$GLOBALS['phpgw']->db->next_record();
-				$this->previous_login = $GLOBALS['phpgw']->db->f('account_lastlogin');
-	
-				$GLOBALS['phpgw']->db->query("update phpgw_accounts set account_lastloginfrom='"
-					. "$ip', account_lastlogin='" . time()
-					. "' where account_id='$_account_id'",__LINE__,__FILE__);
-			}
-		}
 	}
-?>
