@@ -20,7 +20,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.contacts_ldap.inc.php,v 1.31.2.1 2005/08/30 20:57:03 wolffc Exp $ */
+  /* $Id: class.contacts_ldap.inc.php 21449 2006-04-25 15:02:50Z ralfbecker $ */
 
 	/*!
 	 @class contacts
@@ -39,7 +39,7 @@
 		var $ldap = '';
 		var $nextid = '';
 		var $std_table = '';
-		var $ext_table = 'phpgw_addressbook_extra';
+		var $ext_table = 'egw_addressbook_extra';
 
 		var $account_id;
 		var $adr_types;
@@ -144,14 +144,14 @@
 
 		function contacts_()
 		{
-			$this->db = $GLOBALS['phpgw']->db;
-			$this->ldap = $GLOBALS['phpgw']->common->ldapConnect(
-				$GLOBALS['phpgw_info']['server']['ldap_contact_host'],
-				$GLOBALS['phpgw_info']['server']['ldap_contact_dn'],
-				$GLOBALS['phpgw_info']['server']['ldap_contact_pw']
+			$this->db = clone($GLOBALS['egw']->db);
+			$this->ldap = $GLOBALS['egw']->common->ldapConnect(
+				$GLOBALS['egw_info']['server']['ldap_contact_host'],
+				$GLOBALS['egw_info']['server']['ldap_contact_dn'],
+				$GLOBALS['egw_info']['server']['ldap_contact_pw']
 			);
-			$this->account_id = $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->grants     = $GLOBALS['phpgw']->acl->get_grants('addressbook');
+			$this->account_id = $GLOBALS['egw_info']['user']['account_id'];
+			$this->grants     = $GLOBALS['egw']->acl->get_grants('addressbook');
 
 			/* Used to flag an address as being:
 			   domestic OR  international(default)
@@ -185,7 +185,7 @@
 				}
 			}
 
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 			$return_fields[0]['id']     = $ldap_fields[0]['uidnumber'][0];
@@ -193,13 +193,15 @@
 			$return_fields[0]['tid']    = $ldap_fields[0]['phpgwcontacttypeid'][0];
 			$return_fields[0]['owner']  = $ldap_fields[0]['phpgwcontactowner'][0];
 			$return_fields[0]['access'] = $ldap_fields[0]['phpgwcontactaccess'][0];
-			$return_fields[0]['cat_id'] = $ldap_fields[0]['phpgwcontactcatid'][0];
+			// create from the multiple cat_id's in ldap a comma-separated value as in sql
+			unset($ldap_fields[0]['phpgwcontactcatid']['count']);
+			$return_fields[0]['cat_id'] = implode(',',$ldap_fields[0]['phpgwcontactcatid']);
 			$return_fields[0]['rights'] = (int)$this->grants[$return_fields[0]['owner']];
 			if(@is_array($stock_fieldnames))
 			{
 				foreach($stock_fieldnames as $name => $value)
 				{
-					$return_fields[0][$name] = utf8_decode($ldap_fields[0][$value][0]);
+					$return_fields[0][$name] = $GLOBALS['egw']->translation->convert(($ldap_fields[0][$value][0]),'utf-8');
 				}
 			}
 
@@ -209,7 +211,10 @@
 				$one_type = $return_fields[0]['adr_one_type'];
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if(strstr(\$one_type,\$name)) { \$return_fields[0][\"one_\$name\"] = \"on\"; }");
+					if(strstr($one_type,$name))
+					{
+						$return_fields[0]['one_'.$name] = 'on';
+					}
 				}
 			}
 			if($return_fields[0]['adr_two_type'])
@@ -217,7 +222,10 @@
 				$two_type = $return_fields[0]['adr_two_type'];
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if(strstr(\$two_type,\$name)) { \$return_fields[0][\"two_\$name\"] = \"on\"; }");
+					if (strstr($two_type,$name))
+					{
+						$return_fields[0]['two_'.$name] = 'on';
+					}
 				}
 			}
 
@@ -256,7 +264,7 @@
 				$id = 1;
 			}
 
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 			$return_fields[0]['id']     = $ldap_fields[0]['uidnumber'][0];
@@ -264,14 +272,16 @@
 			$return_fields[0]['tid']    = $ldap_fields[0]['phpgwcontacttypeid'][0];
 			$return_fields[0]['owner']  = $ldap_fields[0]['phpgwcontactowner'][0];
 			$return_fields[0]['access'] = $ldap_fields[0]['phpgwcontactaccess'][0];
-			$return_fields[0]['cat_id'] = $ldap_fields[0]['phpgwcontactcatid'][0];
+			// create from the multiple cat_id's in ldap a comma-separated value as in sql
+			unset($ldap_fields[0]['phpgwcontactcatid']['count']);
+			$return_fields[0]['cat_id'] = implode(',',$ldap_fields[0]['phpgwcontactcatid']);
 			$return_fields[0]['rights'] = (int)$this->grants[$return_fields[0]['owner']];
 
 			if(@is_array($stock_fieldnames))
 			{
 				foreach($stock_fieldnames as $name => $value)
 				{
-					$return_fields[0][$name] = utf8_decode($ldap_fields[0][$value][0]);
+					$return_fields[0][$name] = $GLOBALS['egw']->translation->convert(($ldap_fields[0][$value][0]),'utf-8');
 				}
 			}
 
@@ -281,7 +291,10 @@
 				$one_type = $return_fields[0]['adr_one_type'];
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if(strstr(\$one_type,\$name)) { \$return_fields[0][\"one_\$name\"] = \"on\"; }");
+					if(strstr($one_type,$name))
+					{
+						$return_fields[0]['one_'.$name] = 'on';
+					}
 				}
 			}
 			if($return_fields[0]['adr_two_type'])
@@ -289,7 +302,10 @@
 				$two_type = $return_fields[0]['adr_two_type'];
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if(strstr(\$two_type,\$name)) { \$return_fields[0][\"two_\$name\"] = \"on\"; }");
+					if (strstr($two_type,$name))
+					{
+						$return_fields[0]['two_'.$name] = 'on';
+					}
 				}
 			}
 
@@ -304,11 +320,30 @@
 			return $return_fields;
 		}
 
-		/* send this the range, query, sort, order and whatever fields you want to see */
-		function read($start=0,$limit=0,$fields='',$query='',$filter='',$sort='',$order='', $lastmod=-1,$cquery='')
+		/**
+		 * Searches for contacts meating certain criteria and evtl. return only a range of them
+		 *
+		 * @param int $start=0 starting number of the range, if $limit != 0
+		 * @param int $limit=0 max. number of entries to return, 0=all
+		 * @param array $fields=null fields to return or null for all stock fields
+		 * @param string $query='' search pattern or '' for none
+		 * @param string $filter='' filters with syntax like <name>=<value>,<name2>=<value2> OR <name3>=<value3>,<name4>=!'' for not empty
+		 * @param string $sort='' sorting: ASC or DESC
+		 * @param string $order='' column to order, default ('') n_family,n_given,email ASC
+		 * @param int $lastmod=-1 return only values modified after given timestamp, default (-1) return all
+		 * @param string $cquery='' return only entries starting with given character, default ('') all
+		 * @return array of contacts
+		 */
+		function read($start=0,$limit=0,$fields=null,$query='',$filter='',$sort='',$order='', $lastmod=-1,$cquery='')
 		{
-			if(!$start)  { $start  = 0; }
-			if(!$limit)  { $limit  = 0; }
+			if (!$limit)
+			{
+				$limit = -1;	// db::query uses -1 for all
+			}
+			elseif (!$start)
+			{
+				$start  = 0;
+			}
 			if(!$filter) { $filter = 'tid=n'; }
 
 			if(!$fields || empty($fields))
@@ -324,28 +359,24 @@
 			if($filter)
 			{
 				if($DEBUG) { echo 'DEBUG - Inbound filter is: #'.$filter.'#'; }
-				$filterarray = split(',',$filter);
-				if($filterarray[1])
+
+				foreach(explode(',',$filter) as $f)
 				{
-					$i=0;
-					for($i=0;$i<count($filterarray);$i++)
+					list($name,$value) = explode('=',$f,2);
+
+					if ($this->stock_contact_fields[$name])
 					{
-						list($name,$value) = split("=",$filterarray[$i]);
-						if($name)
-						{
-							if($DEBUG) { echo '<br>DEBUG - Filter strings: #'.$this->non_contact_fields[$name].'# => #'.$value.'#'; }
-							$filterfields[$this->non_contact_fields[$name]] = $value;
-						}
+						$filterfields[$this->stock_contact_fields[$name]] = $value;
 					}
-				}
-				else
-				{
-					list($name,$value) = split('=',$filter);
-					if($DEBUG)
+					elseif ($this->non_contact_fields[$name])
 					{
-						echo '<br>DEBUG - Filter strings: #'.$this->non_contact_fields[$name].'# => #'.$value.'#';
+						$filterfields[$this->non_contact_fields[$name]] = $value;
+					}
+					else
+
+					{
+						if ($DEBUG) echo "<p>contacts_ldap::read(filter=$filter): Cant filter for '$name', allowed only: ".implode(', ',array_keys($this->non_contact_fields))."</p>\n";
 					}
-					$filterfields = array($this->non_contact_fields[$name] => $value);
 				}
 			}
 			else
@@ -363,16 +394,25 @@
 			or maybe not like this - i am not sure what i am doing :)
 			*/
 
-			if(@is_array($this->grants))
+			if(@is_array($this->grants) && strpos($filter,'owner')===false )
 			{
-				$filterfields['phpgwcontactowner'] = array();
-				/* this was not listing private entries when show all was selected */
-				/* $filterfields += array('phpgwcontactaccess' => 'public'); */
+				$filterfields['phpgwcontactowner'] = $filterfields['priv'] = array();
+
+				// to not show private entries we add an additional filter access==public or owner==users with private grants
+				// please note: private grants are not yet supported by the addressbook UI and the SQL backend
+				$filterfields['priv'][]=array('phpgwcontactaccess' => 'public');
+
 				if($DEBUG) { echo '<br>DEBUG - My user id is: ' . $this->account_id; }
 				foreach($this->grants as $user => $right)
 				{
 					if($DEBUG) { echo '<br>DEBUG - Grant from owner: ' . $user; }
 					$filterfields['phpgwcontactowner'][] = array('phpgwcontactowner' => $user);
+					
+					// add users we have a private grants from
+					if ($right & EGW_ACL_PRIVATE)
+					{
+						$filterfields['priv'][]=array('phpgwcontactowner' => $user);
+					}
 				}
 			}
 			/*
@@ -415,28 +455,29 @@
 				if(is_array($query))
 				{
 					// must be fixed somehow Milosch????
-					$myfilter = $this->makefilter($filterfields,$query,'',$DEBUG);
+					$myfilter = $this->makefilter($filterfields,$GLOBALS['egw']->common->ldap_addslashes($query),'',$DEBUG);
 				}
 				else
 				{
 					// don't search about any fields any more
 					$search_filter = array(
-						'fn'		=> 'cn',
-						'n_given'	=> 'givenname',
-						'n_family'	=> 'sn',
-						'email'		=> 'mail',
-						'org_name'	=> 'o',
-						'org_unit'	=> 'ou'
+						'fn'       => 'cn',
+						'n_given'  => 'givenname',
+						'n_family' => 'sn',
+						'email'    => 'mail',
+						'org_name' => 'o',
+						'org_unit' => 'ou'
 					);
-					$myfilter = $this->makefilter($filterfields,$search_filter,$query,$DEBUG);
+					$myfilter = $this->makefilter($filterfields,$search_filter,$GLOBALS['egw']->common->ldap_addslashes($query),$DEBUG);
 				}
 			}
 			else
 			{
 				$myfilter = $this->makefilter($filterfields,'','',$DEBUG);
 			}
+			$myfilter = $GLOBALS['egw']->translation->convert($myfilter,$GLOBALS['egw']->translation->system_charset,'utf-8');
 
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], $myfilter);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], $myfilter);
 
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 			/* _debug_array($ldap_fields);exit; */
@@ -445,40 +486,35 @@
 			/* echo '<br>total="'.$this->total_records.'"'; */
 			if($DEBUG) { echo '<br>Query returned "'.$this->total_records.'" records.'; }
 
-			/* Use shared sorting routines, based on sort and order */
+			/* Use usort to sort the complete result, since ldap_search can not do that */
 			@set_time_limit(0); /* Try not to die, this can take some time on slow machines... */
-			if($sort == 'ASC')
-			{
-				$ldap_fields = $this->asortbyindex($ldap_fields, $this->stock_contact_fields[$order]);
-			}
-			else
-			{
-				$ldap_fields = $this->arsortbyindex($ldap_fields, $this->stock_contact_fields[$order]);
-			}
+			$order_array = "array('";
+			if(!empty($order)) $order_array .= $this->stock_contact_fields[$order] . "','";
+			$order_array .= $this->stock_contact_fields['n_family'] . "', '"
+				. $this->stock_contact_fields['n_given'] . "', '"
+				. $this->stock_contact_fields['email'] . "')";
+			# remove the "count" field from the array, because usort screws up associative arrays
+			unset($ldap_fields['count']);
+			# sort the array
+			$function = 'return contacts::_cmp(' . $order_array . ",'" . $sort . "'," . '$a, $b);';
+			usort($ldap_fields, create_function('$a, $b', $function));
 
 			/*
 			This logic allows you to limit rows, or not.
 			The export feature, for example, does not limit rows.
 			This way, it can retrieve all rows at once.
 			*/
-			if($start && $limit)
-			{
-				$limit = $start + $limit;
-			}
-			elseif($start && !$limit)
-			{
-				$limit = $start;
-			}
-			elseif(!$start && !$limit)
-			{
-				$limit = $this->total_records;
-			}
-			else
+			//echo "<p align=right>search() start=$start, limit=$limit, total=$this->total_records</p>\n";
+			if($limit == -1)	// return all
 			{
 				$start = 0;
-				$limit = $limit;
+				$limit = $this->total_records;
+			}
+			else	// return range from $start to (excluding) $start+$limit
+			{
+				if ($this->total_records < $start) $start = 0;
+				$limit = $start + $limit;
 			}
-			/* echo '('.$start.','.$limit.')'; */
 
 			@reset($ldap_fields);
 			$j = 0;
@@ -491,14 +527,16 @@
 					$return_fields[$j]['tid']    = $ldap_fields[$i]['phpgwcontacttypeid'][0];
 					$return_fields[$j]['owner']  = $ldap_fields[$i]['phpgwcontactowner'][0];
 					$return_fields[$j]['access'] = $ldap_fields[$i]['phpgwcontactaccess'][0];
-					$return_fields[$j]['cat_id'] = $ldap_fields[$i]['phpgwcontactcatid'][0];
+					// create from the multiple cat_id's in ldap a comma-separated value as in sql
+					unset($ldap_fields[$i]['phpgwcontactcatid']['count']);
+					$return_fields[$j]['cat_id'] = implode(',',$ldap_fields[$i]['phpgwcontactcatid']);
 					$return_fields[$j]['rights'] = (int)$this->grants[$return_fields[$j]['owner']];
 
 					if(@is_array($stock_fieldnames))
 					{
 						foreach($stock_fieldnames as $f_name => $f_value)
 						{
-							$return_fields[$j][$f_name] = utf8_decode($ldap_fields[$i][$f_value][0]);
+							$return_fields[$j][$f_name] = $GLOBALS['egw']->translation->convert(($ldap_fields[$i][$f_value][0]),'utf-8');
 						}
 					}
 					$this->db->query("SELECT contact_name,contact_value FROM $this->ext_table WHERE contact_id='"
@@ -519,13 +557,17 @@
 		/* Used by read() above to build the ldap filter string */
 		function makefilter($qarray,$extra='',$query='', $DEBUG=False)
 		{
+			if($DEBUG) echo "<p>contacts_ldap::makefilter(".print_r($qarray,true).",'$extra','$query')</p>\n";
+
 			if(!@is_array($qarray))
 			{
 				return $qarray;
 			}
 
 			$first = $last = "*";
-			if(strstr($query,"*"))
+			// this can only be the case, if $query is a character-query.
+			// normal queries don't allow wildcards and escape them
+			if(strstr($query,"*") && !strstr($query,"\*"))
 			{
 				if(substr($query,-1) == "*")
 				{
@@ -594,18 +636,34 @@
 					/* exact value (filtering based on tid, etc...) */
 					if($name == 'phpgwcontactcatid')
 					{
-						if (!is_object($GLOBALS['phpgw']->categories))
+						if (!is_object($GLOBALS['egw']->categories))
 						{
-							$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+							$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories');
 						}
-						$cats = $GLOBALS['phpgw']->categories->return_all_children((int)$value);
+						$cats = $GLOBALS['egw']->categories->return_all_children((int)$value);
 
-						$aquery .= '(|';
-						foreach($cats as $cat)
+						/* new code to find cats stored as multiple values only (!)
+						if (count($cats) > 1)
 						{
-							$aquery .= '(' . $name . '=*,' . $cat . ',*)(' . $name . '=' . $cat . ')';
+							$aquery .= '(|('.$name.'='.implode(')('.$name.'=',$cats).'))';
 						}
-						$aquery .= ')';
+						else
+						{
+							$aquery .= '('.$name.'='.(int)$cats[0].')';
+						}
+						*/
+						// old code finds cats stored as multiple values or as comma-separated fields with leading and training comma (old format)
+						// but generates a more complex query, so I think it should be removed in the next release by the new code
+ 						$aquery .= '(|';
+ 						foreach($cats as $cat)
+ 						{
+ 							$aquery .= '(' . $name . '=*,' . $cat . ',*)(' . $name . '=' . $cat . ')';
+ 						}
+ 						$aquery .= ')';
+					}
+					elseif ($value == "!''")	// query for not empty
+					{
+						$aquery .= '(' . $name . '=*)';
 					}
 					else
 					{
@@ -643,10 +701,9 @@
 				echo '<br>AND query:  "' . $aquery . '"';
 				echo '<br>OR query:   "' . $oquery . '"';
 				echo '<br>Full query: "' . $fquery . '"';
-				echo '<br>Will search in "' . $GLOBALS['phpgw_info']['server']['ldap_contact_context'] . '"';
+				echo '<br>Will search in "' . $GLOBALS['egw_info']['server']['ldap_contact_context'] . '"';
 			}
 
-//			echo $fquery;
 			return $fquery;
 		}
 
@@ -660,12 +717,17 @@
 					$fields[$extra] = $$extra;
 				}
 			}
+			// store cat_id in ldap as multiple values (php array) and not as comma separated value
+			if (isset($fields['cat_id']) && count(explode(',',$fields['cat_id'])) > 1)
+			{
+				$fields['cat_id'] = explode(',',$fields['cat_id']);
+			}
 			if(empty($fields['tid']))
 			{
 				$fields['tid'] = 'n';
 			}
 
-			if(!$GLOBALS['phpgw_info']['server']['ldap_contact_context'])
+			if(!$GLOBALS['egw_info']['server']['ldap_contact_context'])
 			{
 				return False;
 			}
@@ -673,16 +735,16 @@
 			list($stock_fields,$stock_fieldnames,$extra_fields) = $this->split_stock_and_extras($fields);
 
 			$free = 0;
-			$this->nextid = $GLOBALS['phpgw']->common->last_id('contacts');
+			$this->nextid = $GLOBALS['egw']->common->last_id('contacts');
 			/* Loop until we find a free id */
 			while(!$free)
 			{
 				$ldap_fields = '';
-				$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'uidnumber='.$this->nextid);
+				$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'uidnumber='.$this->nextid);
 				$ldap_fields = ldap_get_entries($this->ldap, $sri);
 				if($ldap_fields[0]['dn'][0])
 				{
-					$this->nextid = $GLOBALS['phpgw']->common->next_id('contacts');
+					$this->nextid = $GLOBALS['egw']->common->next_id('contacts');
 				}
 				else
 				{
@@ -697,7 +759,7 @@
 				{
 					if($stock_fields[$name] != '')
 					{
-						$ldap_fields[$value] = utf8_encode($stock_fields[$name]);
+						$ldap_fields[$value] = $GLOBALS['egw']->translation->convert($stock_fields[$name],$GLOBALS['egw']->translation->system_charset,'utf-8');
 					}
 				}
 			}
@@ -705,7 +767,7 @@
 			$time = gettimeofday();
 			$ldap_fields['uid'] = time().$time['usec'].':'.$ldap_fields['givenname'];
 
-			$dn = 'uid=' . $ldap_fields['uid'].',' . $GLOBALS['phpgw_info']['server']['ldap_contact_context'];
+			$dn = 'uid=' . $ldap_fields['uid'].',' . $GLOBALS['egw_info']['server']['ldap_contact_context'];
 			$ldap_fields['phpgwcontacttypeid']    = $fields['tid'];
 			$ldap_fields['phpgwcontactowner']     = $owner;
 			if(!isset($fields['access']))
@@ -719,7 +781,7 @@
 			$ldap_fields['objectclass'][0] = 'organizationalPerson';
 			$ldap_fields['objectclass'][1] = 'inetOrgPerson';
 			$ldap_fields['objectclass'][2] = 'phpgwContact';
-			//$ldap_fields['last_mod'] = $GLOBALS['phpgw']->datetime->gmtnow;
+			//$ldap_fields['last_mod'] = $GLOBALS['egw']->datetime->gmtnow;
 
 			$err = $this->validate($ldap_fields);
 			if(@is_array($err) && @isset($err[0]))
@@ -830,15 +892,20 @@
 					$stock_fields[$extra] = $fields[$extra];
 				}
 			}
+			// store cat_id in ldap as multiple values (php array) and not as comma separated value
+			if (isset($fields['cat_id']) && count(explode(',',$fields['cat_id'])) > 1)
+			{
+				$fields['cat_id'] = explode(',',$fields['cat_id']);
+			}
 			$nonfields = $this->non_contact_fields;
 
-			if(!$GLOBALS['phpgw_info']['server']['ldap_contact_context'])
+			if(!$GLOBALS['egw_info']['server']['ldap_contact_context'])
 			{
 				return False;
 			}
 
 			/* First make sure that id number exists */
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'uidnumber=' . (int)$id);
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 			if($ldap_fields[0]['dn'])
@@ -945,12 +1012,12 @@
 						if($ldap_fields[0][$fvalue] && $stock_fields[$fname] && $ldap_fields[0][$fvalue][0] != $stock_fields[$fname] )
 						{
 							//echo "<br>".$fname." => ".$fvalue." was there";
-							$err = ldap_modify($this->ldap,$dn,array($fvalue => utf8_encode($stock_fields[$fname])));
+							$err = ldap_modify($this->ldap,$dn,array($fvalue => $GLOBALS['egw']->translation->convert($stock_fields[$fname],$GLOBALS['egw']->translation->system_charset,'utf-8')));
 						}
 						elseif(!$ldap_fields[0][$fvalue] && $stock_fields[$fname])
 						{
 							//echo "<br>".$fname." not there - '".$fvalue."'";
-							$err = ldap_mod_add($this->ldap,$dn,array($fvalue => utf8_encode($stock_fields[$fname])));
+							$err = ldap_mod_add($this->ldap,$dn,array($fvalue => $GLOBALS['egw']->translation->convert($stock_fields[$fname],$GLOBALS['egw']->translation->system_charset,'utf-8')));
 						}
 						elseif($ldap_fields[0][$fvalue] && !$stock_fields[$fname])
 						{
@@ -966,7 +1033,7 @@
 					}
 				}
 
-				//something here to update the last_mod from $GLOBALS['phpgw']->datetime->gmtnow
+				//something here to update the last_mod from $GLOBALS['egw']->datetime->gmtnow
 
 				foreach($extra_fields as $x_name => $x_value)
 				{
@@ -1003,7 +1070,7 @@
 				return False;
 			}
 
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'phpgwcontactowner='.$old_owner);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'phpgwcontactowner='.$old_owner);
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 			$entry = '';
@@ -1019,12 +1086,12 @@
 		/* This is where the real work of delete() is done, shared class file contains calling function */
 		function delete_($id)
 		{
-			if(!$GLOBALS['phpgw_info']['server']['ldap_contact_context'])
+			if(!$GLOBALS['egw_info']['server']['ldap_contact_context'])
 			{
 				return False;
 			}
 
-			$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'uidnumber='.$id);
+			$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'uidnumber='.$id);
 			$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 			if($ldap_fields[0]['dn'])
@@ -1043,14 +1110,14 @@
 		// This is for the admin script deleteaccount.php
 		function delete_all($owner=0)
 		{
-			if(!$GLOBALS['phpgw_info']['server']['ldap_contact_context'])
+			if(!$GLOBALS['egw_info']['server']['ldap_contact_context'])
 			{
 				return False;
 			}
 
 			if($owner)
 			{
-				$sri = ldap_search($this->ldap, $GLOBALS['phpgw_info']['server']['ldap_contact_context'], 'phpgwcontactowner='.$owner);
+				$sri = ldap_search($this->ldap, $GLOBALS['egw_info']['server']['ldap_contact_context'], 'phpgwcontactowner='.$owner);
 				$ldap_fields = ldap_get_entries($this->ldap, $sri);
 
 				$entry = '';
