@@ -38,11 +38,11 @@
 	* @class contacts_
 	* @abstract Contact Management System
 	* @author jengo/Milosch
-	* @version $Revision: 21368 $
+	* @version $Revision: 22506 $
 	* @license LGPL
 	*/
 
-	/* $Id: class.contacts_sql.inc.php 21368 2006-04-14 09:53:05Z ralfbecker $ */
+	/* $Id: class.contacts_sql.inc.php 22506 2006-09-27 04:16:09Z ralfbecker $ */
 
 	class contacts_
 	{
@@ -427,7 +427,7 @@
 			}
 			else
 			{
-				$ordermethod = "ORDER BY n_family,n_given,email ASC";
+				$ordermethod = "ORDER BY n_family,n_given,org_name ASC";
 			}
 
 			if ($DEBUG && $ordermethod)
