@@ -8,7 +8,7 @@
 	* any later version.                                                       *
 	\**************************************************************************/
 
-	/* $Id: class.egw_db.inc.php 21499 2006-04-30 18:25:11Z ralfbecker $ */
+	/* $Id: class.egw_db.inc.php 22915 2006-12-08 10:17:15Z ralfbecker $ */
 
 	/**
 	 * Database abstraction library
@@ -1157,6 +1157,9 @@
 						return $value ? 1 : 0;
 					}
 					return $value ? 'true' : 'false';
+				case 'float':
+				case 'decimal':
+					return (double) $value;
 			}
 			if (!$this->Link_ID && !$this->connect())
 			{
