@@ -21,7 +21,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.http_dav_client.inc.php,v 1.4 2004/05/05 12:03:19 reinerj Exp $ */
+  /* $Id: class.http_dav_client.inc.php 16311 2004-08-09 13:46:03Z reinerj $ */
 
   /*At the moment much of this is simply a wrapper around the NET_HTTP_Client class,
   with some other methods for parsing the returned XML etc
@@ -586,7 +586,7 @@
 	//		$this->http_client->addHeader('Keep-Alive','timeout=20, state="Accept,Accept-Language"');
 			$this->http_client->addHeader('Accept-Encoding','chunked');
 			$this->http_client->setProtocolVersion( '1.1' );
-			$this->http_client->addHeader( 'user-agent', 'Mozilla/5.0 (compatible; PHPGroupware dav_client/1; Linux)');
+			$this->http_client->addHeader( 'user-agent', 'Mozilla/5.0 (compatible; eGroupWare dav_client/1; Linux)');
 			return $this->http_client->Connect($dav_host,$dav_port);
 		}
 		function set_debug($debug)
