@@ -15,7 +15,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 	
-	/* $Id: class.schema_proc.inc.php 21307 2006-04-09 10:58:20Z ralfbecker $ */
+	/* $Id: class.schema_proc.inc.php 23136 2006-12-27 12:24:09Z ralfbecker $ */
 
 	/**
 	 * eGW's ADOdb based schema-processor
@@ -553,7 +553,7 @@
 					// identify the sequence name, ADOdb uses a different name or it might be renamed
 					$columns = $this->dict->MetaColumns($sTableName);
 					$seq_name = 'seq_'.$sTableName;
-					if (preg_match("/nextval\('([^']+)'::text\)/",$columns[strtoupper($sColumnName)]->default_value,$matches)) 
+					if (preg_match("/nextval\('([^']+)'::(text|regclass)\)/",$columns[strtoupper($sColumnName)]->default_value,$matches)) 
 					{
 						$seq_name = $matches[1];
 					}
