@@ -22,7 +22,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.translation.inc.php 21965 2006-06-24 17:47:41Z ralfbecker $ */
+	/* $Id: class.translation.inc.php 22888 2006-12-06 07:22:59Z ralfbecker $ */
 
 	// define the maximal length of a message_id, all message_ids have to be unique
 	// in this length, our column is varchar 128
@@ -419,6 +419,9 @@
 				case 'macroman':
 					$from = 'iso-8859-1';
 					break;
+				case 'windows-1250':
+					$from = 'iso-8859-2';
+					break;
 			}
 			if (!$to)
 			{
