@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: functions.inc.php 21738 2006-06-07 07:38:10Z nelius_weiss $ */
+  /* $Id: functions.inc.php 23187 2007-01-03 08:06:47Z ralfbecker $ */
 
 	error_reporting(E_ALL & ~E_NOTICE);
 	magic_quotes_runtime(false);
@@ -47,6 +47,8 @@
 		echo '!!! PLEASE CORRECT THIS SITUATION !!!</b></p>';
 	}
 
+	include_once(EGW_API_INC.'/common_functions.inc.php');
+
 	// check if we can restore the eGW enviroment from the php-session
 	if ($GLOBALS['egw_info']['server']['sessions_type'] == 'php4-restore' && $_REQUEST['sessionid'])
 	{
@@ -89,7 +91,6 @@
 			unset($_SESSION['egw_object_cache']);
 		}
 	}
-	include(EGW_API_INC.'/common_functions.inc.php');
 
 	print_debug('sane environment','messageonly','api');
 
