@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php 22669 2006-10-18 05:41:42Z ralfbecker $
+	// $Id: tables_update.inc.php 24022 2007-06-05 14:47:04Z ralfbecker $
 
 	/* Include older eGroupWare update support */
 	include('tables_update_0_9_9.inc.php');
@@ -1214,3 +1214,10 @@
 	{
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.2.106';
 	}
+
+
+	$test[] = '1.2.106';
+	function phpgwapi_upgrade1_2_106()
+	{
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.2.107';
+	}
