@@ -1,15 +1,15 @@
 <?php
-  /**************************************************************************\
-  * phpGroupWare - Preferences - categories                                  *
-  * http://www.phpgroupware.org                                              *
-  * Written by Bettina Gille [ceb@phpgroupware.org]                          *
-  * -----------------------------------------------                          *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-  /* $Id: class.bocategories.inc.php,v 1.16.2.1 2005/03/12 16:37:50 ralfbecker Exp $ */
+	/**************************************************************************\
+	* eGroupWare - Preferences - categories                                    *
+	* http://www.egroupware.org                                                *
+	* Written by Bettina Gille [ceb@phpgroupware.org]                          *
+	* -----------------------------------------------                          *
+	*  This program is free software; you can redistribute it and/or modify it *
+	*  under the terms of the GNU General Public License as published by the   *
+	*  Free Software Foundation; either version 2 of the License, or (at your  *
+	*  option) any later version.                                              *
+	\**************************************************************************/
+	/* $Id: class.bocategories.inc.php 20532 2006-03-10 10:00:41Z ralfbecker $ */
 
 	class bocategories
 	{
@@ -22,14 +22,14 @@
 
 		function bocategories($cats_app='')
 		{
-			$this->cats           = CreateObject('phpgwapi.categories','',$cats_app);
+			$this->cats           =& CreateObject('phpgwapi.categories','',$cats_app);
 
 			$this->read_sessiondata($cats_app);
 
-			$start  = $GLOBALS['HTTP_POST_VARS']['start']  ? $GLOBALS['HTTP_POST_VARS']['start']  : $GLOBALS['HTTP_GET_VARS']['start'];
-			$query  = $GLOBALS['HTTP_POST_VARS']['query']  ? $GLOBALS['HTTP_POST_VARS']['query']  : $GLOBALS['HTTP_GET_VARS']['query'];
-			$sort   = $GLOBALS['HTTP_POST_VARS']['sort']   ? $GLOBALS['HTTP_POST_VARS']['sort']   : $GLOBALS['HTTP_GET_VARS']['sort'];
-			$order  = $GLOBALS['HTTP_POST_VARS']['order']  ? $GLOBALS['HTTP_POST_VARS']['order']  : $GLOBALS['HTTP_GET_VARS']['order'];
+			$start  = $_POST['start']  ? $_POST['start']  : $_GET['start'];
+			$query  = $_POST['query']  ? $_POST['query']  : $_GET['query'];
+			$sort   = $_POST['sort']   ? $_POST['sort']   : $_GET['sort'];
+			$order  = $_POST['order']  ? $_POST['order']  : $_GET['order'];
 
 			if(!empty($start) || $start == '0' || $start == 0)
 			{
@@ -52,19 +52,18 @@
 
 		function save_sessiondata($data, $cats_app)
 		{
-			$colum = $cats_app . '_cats';
-			$GLOBALS['phpgw']->session->appsession('session_data',$column,$data);
+			$GLOBALS['egw']->session->appsession($cats_app . '_cats','preferences',$data);
 		}
 
 		function read_sessiondata($cats_app)
 		{
-			$colum = $cats_app . '_cats';
-			$data = $GLOBALS['phpgw']->session->appsession('session_data',$column);
+			$data = $GLOBALS['egw']->session->appsession($cats_app . '_cats','preferences');
 
 			$this->start  = $data['start'];
 			$this->query  = $data['query'];
 			$this->sort   = $data['sort'];
 			$this->order  = $data['order'];
+			$this->referer = $data['referer'];
 		}
 
 		function get_list($global_cats)
@@ -97,7 +96,7 @@
 		{
 			$data['type']   = $data['type'] ? $data['type'] : '';
 			$data['cat_id'] = $data['cat_id'] ? $data['cat_id'] : '';
-			return $this->cats->exists($data['type'],$data['cat_name'],$data['cat_id']);
+			return $this->cats->exists($data['type'],$data['cat_name'],$data['type'] == 'subs' ? 0 : $data['cat_id'],$data['type'] != 'subs' ? 0 : $data['cat_id']);
 		}
 
 		function formatted_list($format,$type,$cat_parent,$global_cats)
