@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - Registration                                              *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare - Registration                                                *
+	* http://www.egroupware.org                                                *
 	* This application written by Joseph Engo <jengo@phpgroupware.org>         *
 	* --------------------------------------------                             *
 	* Funding for this program was provided by http://www.checkwithmom.com     *
@@ -12,12 +12,12 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_admin.inc.php,v 1.8 2003/08/28 14:30:35 ralfbecker Exp $ */
+	/* $Id: hook_admin.inc.php 19547 2005-11-02 11:45:52Z ralfbecker $ */
 
 	$title = $appname;
 	$file = Array(
-		'Site Configuration'	=> $GLOBALS['phpgw']->link('/index.php', 'menuaction=admin.uiconfig.index&appname=' . $appname),
-		'Manage Fields'      => $GLOBALS['phpgw']->link ('/index.php', 'menuaction=' . $appname . '.uimanagefields.admin')
+		'Site Configuration'	=> $GLOBALS['egw']->link('/index.php', 'menuaction=admin.uiconfig.index&appname=' . $appname),
+		'Manage Fields'      => $GLOBALS['egw']->link ('/index.php', 'menuaction=' . $appname . '.uimanagefields.admin')
 	);
 
 	display_section($appname,$title,$file);
