@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: ldapmodify.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: ldapmodify.php 22830 2006-11-12 19:14:33Z ralfbecker $ */
 
 	$GLOBALS['egw_info'] = array(
 		'flags' => array(
@@ -104,7 +104,7 @@
 			if(!$GLOBALS['egw_info']['server']['global_denied_groups'][$info[$i]['cn'][0]] &&
 				!$account_info[$i][$info[$i]['cn'][0]])
 			{
-				$group_info[-$info[$i]['gidnumber'][0]] = $info[$i];
+				$group_info[$info[$i]['gidnumber'][0]] = $info[$i];
 			}
 		}
 	}
