@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Block_SO.inc.php,v 1.5 2004/02/10 14:56:33 ralfbecker Exp $ */
+	/* $Id: class.Block_SO.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class Block_SO
 	{
@@ -26,8 +26,15 @@
 		var $state;
 		var $version;
 		
-		function Block_SO()
+		function Block_SO($args=array())
 		{
+			if (is_array($args))
+			{
+				foreach($args as $name => $value)
+				{
+					$this->$name = $value;
+				}
+			}
 		}
 
 		function set_version($version)
