@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Categories_BO.inc.php,v 1.18.2.1 2005/03/15 15:20:16 ralfbecker Exp $ */
+	/* $Id: class.Categories_BO.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class Categories_BO
 	{
@@ -19,7 +19,7 @@
 		function Categories_BO()
 		{
 			//all sitemgr BOs should be instantiated via a globalized Common_BO object,
-			$this->so = CreateObject('sitemgr.Categories_SO', True);
+			$this->so =& CreateObject('sitemgr.Categories_SO', True);
 		}
 
 		//since we need this information several times we store it once,
@@ -27,7 +27,7 @@
 		function setcurrentcats()
 		{
 			$this->currentcats = $this->getpermittedcats(CURRENT_SITE_ID,'active',True);
-//			echo "<p>Categories_BO::setcurrentcats() site_id=".CURRENT_SITE_ID.", currentcats=".print_r($this->currentcats,True)."</p>\n";
+//      echo "<p>Categories_BO::setcurrentcats() site_id=".CURRENT_SITE_ID.", currentcats=".print_r($this->currentcats,True)."</p>\n";
 			$this->readablecats = $this->getpermittedcatsRead();
 		}
 
@@ -61,7 +61,7 @@
 			if (!$cat_id)
 			{
 				$cat_id = CURRENT_SITE_ID;
-			}	
+			} 
 			if ($cat_id != CURRENT_SITE_ID)
 			{
 				$this->check($cat_id);
@@ -130,7 +130,7 @@
 			return $permitted_list;
 		}
 
-		function addCategory($name, $description, $parent=False)		
+		function addCategory($name, $description, $parent=False)    
 		{
 			if (!$parent)
 			{
@@ -141,6 +141,7 @@
 			{
 				$cat_id = $this->so->addCategory($name, $description, $parent);
 				$this->currentcats[] = $cat_id;
+				$this->NotifyUsers($lang, $cat_id,$state,$cat_name);
 				return $cat_id;
 			}
 			else
@@ -189,7 +190,7 @@
 			{
 				$parent = CURRENT_SITE_ID;
 			}
-			$cat_info = CreateObject('sitemgr.Category_SO', True);
+			$cat_info =& CreateObject('sitemgr.Category_SO', True);
 			$cat_info->id = $cat_id;
 			$cat_info->name = $cat_name;
 			$cat_info->description = $cat_description;
@@ -198,10 +199,10 @@
 			$cat_info->parent = $parent;
 			$cat_info->old_parent = $old_parent ? $old_parent : $parent;
 			$cat_info->index_page_id = $index_page_id;
-
 			if ($GLOBALS['Common_BO']->acl->can_write_category($cat_id))
 			{
-				if ($this->so->saveCategory($cat_info));
+				$this->NotifyUsers($lang, $cat_id,$state,$cat_name);
+				if ($this->so->saveCategory($cat_info))
 				{
 					if ($this->so->saveCategoryLang($cat_id, $cat_name, $cat_description, $lang))
 					{
@@ -216,6 +217,7 @@
 
 		function saveCategoryLang($cat_id, $cat_name, $cat_description, $lang)
 		{
+			$this->NotifyUsers($lang, $cat_id, -1, $cat_name);
 			if ($this->so->saveCategoryLang($cat_id, $cat_name, $cat_description, $lang))
 			{
 				return true;
@@ -325,7 +327,7 @@
 
 		function saveCategoryPermsfromparent($cat_id)
 		{
-			$cat=$this->getCategory($cat_id);
+			$cat=$this->getCategory($cat_id,false,true);
 			$parent=$cat->parent;
 			if ($parent)
 			{
@@ -364,7 +366,7 @@
 			{
 				echo '<p><center><b>'.lang('Attempt to access information outside current website').': cat_id='.htmlspecialchars($cat_id).'</b></center>';
 				//echo "Backtrace:<pre>".print_r(debug_backtrace(),True)."</pre>\n";
-				$GLOBALS['phpgw']->common->phpgw_exit(True);
+				$GLOBALS['egw']->common->egw_exit(True);
 			}
 		}
 
@@ -383,5 +385,21 @@
 				$this->so->reactivate($cat_id);
 			}
 		}
+
+		function NotifyUsers($lang, $cat_id,$state,$cat_name)
+		{
+			$bo=CreateObject("sitemgr.notification_bo");
+			$bo->notify_users($GLOBALS['Common_BO']->sites->current_site['site_id'], 
+				$cat_id,
+				$state,
+				$lang,
+				$GLOBALS['Common_BO']->sites->current_site['sitelanguages']['0'],
+				array('category_id'=>$cat_id,'lang'=>$lang),
+				array(
+					array('text'=>"Category name:",'translate'=>True),
+					" ",$cat_name
+				)
+			);
+		}
 	}
 ?>
