@@ -9,24 +9,23 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.5 2004/02/14 14:35:48 ralfbecker Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array
-	(
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
 			'currentapp' => 'sitemgr',
 			'noheader'   => True,
 			'nonavbar'   => True,
 			'noapi'      => False
-	);
+	));
 	include('../header.inc.php');
+	
+	$CommonUI =& CreateObject('sitemgr.Common_UI');
 
-	$CommonUI = CreateObject('sitemgr.Common_UI');
-
-	if (!$CommonUI->do_sites_exist && $GLOBALS['phpgw_info']['user']['apps']['admin'])
+	if (!$CommonUI->do_sites_exist && $GLOBALS['egw_info']['user']['apps']['admin'])
 	{
-		$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=>'sitemgr.Sites_UI.edit'));
+		$GLOBALS['egw']->redirect_link('/index.php',array('menuaction'=>'sitemgr.Sites_UI.edit'));
 	}
 	$CommonUI->DisplayIFrame();
 
-	$GLOBALS['phpgw']->common->phpgw_footer();
-?>
+	$GLOBALS['egw']->common->egw_footer();
