@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - Notes                                                     *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare - Sitemgr guestbook                                           *
+	* http://www.egroupware.org                                                *
 	* --------------------------------------------                             *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php,v 1.1 2003/06/15 06:36:58 totschnig Exp $ */
+	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	$setup_info['sitemgr_module_guestbook']['name']      = 'sitemgr_module_guestbook';
 	$setup_info['sitemgr_module_guestbook']['title']     = 'Guestbook for SiteMgr';
@@ -20,9 +20,14 @@
 	);
 	$setup_info['sitemgr_module_guestbook']['enable']    = 1;
 
-	/* Dependacies for this app to work */
+	/* Dependencies for this app to work */
 	$setup_info['sitemgr_module_guestbook']['depends'][] = array(
 		'appname'  => 'sitemgr',
-		'versions' => Array('0.9.15')
+		'versions' => Array('1.0.0','1.0.1')
+	);
+	/* Dependencies for this app to work */
+	$setup_info['sitemgr']['depends'][] = array(
+		'appname'  => 'phpgwapi',
+		'versions' => Array('1.0.1')
 	);
 ?>
