@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php 22148 2006-07-22 11:15:06Z nelius_weiss $ */
+	/* $Id: index.php 22650 2006-10-16 20:55:25Z nelius_weiss $ */
 
 	$site_id=0;
 	/**
@@ -41,10 +41,14 @@
 			
 			if($GLOBALS['egw_info']['server']['allow_cookie_auth'])
 			{
-				$eGW_remember = unserialize(stripslashes($_COOKIE['eGW_remember']));
-				if($eGW_remember['login'] && $eGW_remember['passwd'] && $eGW_remember['passwd_type'])
+				$eGW_remember = explode('::::',stripslashes($_COOKIE['eGW_remember']));
+				if($eGW_remember[0] && $eGW_remember[1] && $eGW_remember[2])
 				{
-					$anon_account = $eGW_remember;
+					$anon_account = array(
+						'login' => $eGW_remember[0],
+						'passwd' => $eGW_remember[1],
+						'passwd_type' => $eGW_remember[2],
+					);
 				}
 			}
 			if (!$anon_account['login'])
