@@ -10,10 +10,10 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: soap.php,v 1.9.2.1 2005/09/10 10:33:25 ralfbecker Exp $ */
+	/* $Id: soap.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$egw_info = array();
+	$GLOBALS['egw_info']['flags'] = array(
 		'disable_Template_class' => True,
 		'currentapp' => 'login',
 		'noheader'   => True,
@@ -23,16 +23,31 @@
 
 	$GLOBALS['server'] = CreateObject('phpgwapi.soap_server');
 	/* _debug_array($GLOBALS['server']);exit; */
-	/* include(PHPGW_API_INC . '/soaplib.soapinterop.php'); */
+	/* include(EGW_API_INC . '/soaplib.soapinterop.php'); */
 
-	if (!$GLOBALS['phpgw_info']['server']['soap_enabled'])
+	if (!$GLOBALS['egw_info']['server']['soap_enabled'])
 	{
 		$GLOBALS['server']->make_fault(9999,'soap service is not enabled in the eGroupWare system configuration');
 		$GLOBALS['server']->service($GLOBALS['server']->fault());
 		exit;
 	}
 
-	/* Note: this command only available under Apache */
+	/* Note: this command only available natively in Apache (Netscape/iPlanet/SunONE in php >= 4.3.3) */
+	if(!function_exists('getallheaders'))
+	{
+		function getallheaders()
+		{
+			settype($headers,'array');
+			foreach($_SERVER as $h => $v)
+			{
+				if(ereg('HTTP_(.+)',$h,$hp))
+				{
+					$headers[$hp[1]] = $v;
+				}
+			}
+			return $headers;
+		}
+	}
 	$headers = getallheaders();
 
 	if(ereg('Basic',$headers['Authorization']))
@@ -43,11 +58,11 @@
 		$auth = base64_decode(trim($tmp));
 		list($sessionid,$kp3) = split(':',$auth);
 
-		if($GLOBALS['phpgw']->session->verify($sessionid,$kp3))
+		if($GLOBALS['egw']->session->verify($sessionid,$kp3))
 		{
 			$GLOBALS['server']->authed = True;
 		}
-		elseif($GLOBALS['phpgw']->session->verify_server($sessionid,$kp3))
+		elseif($GLOBALS['egw']->session->verify_server($sessionid,$kp3))
 		{
 			$GLOBALS['server']->authed = True;
 		}
