@@ -11,78 +11,77 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: init.php,v 1.17.2.2 2005/02/09 17:29:05 ralfbecker Exp $
+	// $Id: init.php 20295 2006-02-15 12:31:25Z  $
 
 	require('lib/defaults.php');
 
-	$sessionid = isset($_GET['sessionid']) ? $_GET['sessionid'] : (isset($_COOKIE['sessionid']) ? $_COOKIE['sessionid'] : '');
-
-	if (!$sessionid)
+	/**
+	 * Check if we allow anon access and with which creditials
+	 * 
+	 * @param array &$anon_account anon account_info with keys 'login', 'passwd' and optional 'passwd_type'
+	 * @return boolean true if we allow anon access, false otherwise
+	 */
+	function wiki_check_anon_access(&$anon_account)
 	{
-		// uncomment the next line if wiki should use a eGW domain different from the first one defined in your header.inc.php
-		// and of cause change the name accordingly ;-)
-		// $GLOBALS['phpgw_info']['server']['default_domain'] = 'developers';
-
-		$GLOBALS['phpgw_info']['flags'] = array(
-			'disable_Template_class' => True,
-			'login' => True,
-			'currentapp' => 'login',
-			'noheader'  => True,
-		);
-		include('../header.inc.php');
-		$GLOBALS['phpgw_info']['flags']['currentapp'] = 'wiki';
-
-		$c = CreateObject('phpgwapi.config','wiki');
+		$c =& CreateObject('phpgwapi.config','wiki');
 		$c->read_repository();
-		$config = $c->config_data;
+		$config =& $c->config_data;
 		unset($c);
 
 		if ($config['allow_anonymous'] && $config['anonymous_username'])
 		{
-			$sessionid = $GLOBALS['phpgw']->session->create($config['anonymous_username'],$config['anonymous_password'], 'text');
-		}
-		if (!$sessionid)
-		{
-			$GLOBALS['phpgw']->redirect('../login.php'.
-				(isset($_SERVER['QUERY_STRING']) && !empty($_SERVER['QUERY_STRING']) ?
-				'?phpgw_forward='.urlencode('/wiki/index.php?'.$_SERVER['QUERY_STRING']):''));
-			$GLOBALS['phpgw']->phpgw_exit();
-		}
-		// we redirect to the same page again, as we cant reset some of the defines in the API
-		if ($_GET['action'] != 'xml')	// for the xml-export, we cant do that and dont care for these settings
-		{
-			$GLOBALS['phpgw']->redirect_link('/wiki/index.php',urldecode($_SERVER['QUERY_STRING']));
+			$anon_account = array(
+				'login'  => $config['anonymous_username'],
+				'passwd' => $config['anonymous_password'],
+				'passwd_type' => 'text',
+			);
+			return true;
 		}
+		return false;
 	}
-	else
-	{
-		include('../header.inc.php');
+		
+	// uncomment the next line if wiki should use a eGW domain different from the first one defined in your header.inc.php
+	// and of cause change the name accordingly ;-)
+	// $GLOBALS['egw_info']['user']['domain'] = $GLOBALS['egw_info']['server']['default_domain'] = 'developers';
 
-		$c = CreateObject('phpgwapi.config','wiki');
-		$c->read_repository();
-		$config = $c->config_data;
+	$GLOBALS['egw_info']['flags'] = array(
+		'disable_Template_class' => True,
+		'noheader'  => True,
+		'currentapp' => 'wiki',
+		'autocreate_session_callback' => 'wiki_check_anon_access',
+	);
+	include('../header.inc.php');
+
+	$c =& CreateObject('phpgwapi.config','wiki');
+	$c->read_repository();
+	if (!isset($c->config_data['ExpireLen']))
+	{
+		$c->config_data['ExpireLen'] = $ExpireLen;
+		$c->save_repository();
 	}
-	// if we get here, we have a sessionid
+	$config = $c->config_data;
+	unset($c);
 
 	// anonymous sessions have no navbar !!!
-	$GLOBALS['phpgw_info']['flags']['nonavbar'] = $config['allow_anonymous'] &&
-		$config['anonymous_username'] == $GLOBALS['phpgw_info']['user']['account_lid'];
+	$GLOBALS['egw_info']['flags']['nonavbar'] = $config['allow_anonymous'] &&
+		$config['anonymous_username'] == $GLOBALS['egw_info']['user']['account_lid'];
 
 	$HomePage = (isset($config[wikihome])?$config[wikihome]:'eGroupWare');
 	$InterWikiPrefix = (isset($config[InterWikiPrefix])?$config[InterWikiPrefix]:'EGroupWare');
 	$EnableFreeLinks = (isset($config[Enable_Free_Links])?$config[Enable_Free_Links]:1);
 	$EnableWikiLinks = (isset($config[Enable_Wiki_Links])?$config[Enable_Wiki_Links]:1);
 	$EditWithPreview = (isset($config[Edit_With_Preview])?$config[Edit_With_Preview]:1);
+	$ExpireLen = $config['ExpireLen'];
 
-	$UserName = $GLOBALS['phpgw_info']['user']['account_lid'];
-	if (!($action == 'save' && !$Preview) && $action != 'admin' && !($action == 'prefs' && $Save) && $action != 'xml')
+	$UserName = $GLOBALS['egw_info']['user']['account_lid'];
+	if (!($_GET['action'] == 'save' && !$_POST['Preview']) && $_GET['action'] != 'admin' && !($_GET['action'] == 'prefs' && $_POST['Save']) && $_GET['action'] != 'xml')
 	{
-		$GLOBALS['phpgw']->common->phpgw_header();
+		$GLOBALS['egw']->common->egw_header();
 	}
 
 	define('TemplateDir', 'template');
 
-	$Charset = $GLOBALS['phpgw']->translation->charset();
+	$Charset = $GLOBALS['egw']->translation->charset();
 	if (strtolower($Charset) == 'iso-8859-1')	// allow all iso-8859-1 extra-chars
 	{
 		$UpperPtn = "[A-Z\xc0-\xde]";
@@ -92,14 +91,14 @@
 			$UpperPtn . $AlphaPtn . '*(\\/' . $UpperPtn . $AlphaPtn . '*)?';
 	}
 
-	$WikiLogo = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/default/images/logo.png';
+	$WikiLogo = $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/templates/default/images/logo.png';
 	// use eGW's temp dir
-	$TempDir = $GLOBALS['phpgw_info']['server']['temp_dir'];
+	$TempDir = $GLOBALS['egw_info']['server']['temp_dir'];
 
 	require('lib/url.php');
 	require('lib/messages.php');
 
-	$pagestore = CreateObject('wiki.sowiki');
+	$pagestore =& CreateObject('wiki.sowiki');
 
 	$FlgChr = chr(255);                     // Flag character for parse engine.
 
