@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: tables_update.inc.php 21547 2006-05-15 12:22:25Z regis_glc $ */
+	/* $Id: tables_update.inc.php 22972 2006-12-10 21:00:40Z regis_glc $ */
 
 	$test[] = '1.0.1';
 	function workflow_upgrade1_0_1()
@@ -372,4 +372,11 @@
                 return $GLOBALS['setup_info']['workflow']['currentver'];
         }
 
+	$test[] = '1.2.01.006';
+	function workflow_upgrade1_2_01_006()
+	{
+		#updating the current version
+		$GLOBALS['setup_info']['workflow']['currentver'] = '1.2.01.007';
+		return $GLOBALS['setup_info']['workflow']['currentver'];
+	}
 ?>
